;*****************************************************************************
;  FP-13 Dynamic vertical slit SMWIR Xtalk test. This is version 2 which uses
;  a baseline subtraction in addition to the shutter closed subtraction.
;  Calculate influence coefficients.
;
;  INPUTS:
;  1) inpath -- path to directory with dumped files from a specific UAID.
;  
;  v1.0 - 02/21/2008 - Jeff McIntire
;*****************************************************************************

PRO fp_13_SMWIR_dyn_read_dn_2, inpath

; Get list of .dmp files from specified path. 
spawn, 'ls -C1 ' + inpath + '*.dmp', list_files
IF N_ELEMENTS(list_files) EQ 0 THEN goto,skipout
nfile=N_ELEMENTS(list_files)

n_bands=8					; # of bands.
n_collects=2					; # of collects.
;n_collects=3					; # of collects.
n_subset=2					; # subsets (I bands both indices; M bands only use the first index).
n_ham=2						; # HAM sides.
n_gain=2					; # of gain states (always 1 for single gain, 0=high and 1=low for dual gain).
max_scan=256					; Total # scans.
band_skip=fltarr(nfile)				; Records which files have no data.
shutter=fltarr(n_collects)			; Shutter order per collect.
sender_band=fltarr(n_collects)			; Sender band.

bandname=['I3','I4','M10','M11','M12','M13','M8','M9']
outfile=' '					; Output file name, which is reasigned.

; DN values per collect (32 possible detectors and 100 frames maximum).
dn_col_ev=dblarr(n_collects,n_bands,n_ham,32,n_subset,100,4)
dn_so=dblarr(n_collects,n_bands,n_ham,32,n_subset,100)
dn_bl=dblarr(n_collects,n_bands,n_ham,32,n_subset)
dn=dblarr(n_collects,n_bands,n_ham,32,n_subset,100)
L=dblarr(n_collects,n_bands,n_ham,32,n_subset,100)

; Derivatives of dn and radiance with respect to frame. 
d_dn=dblarr(n_collects,n_bands,n_ham,32,n_subset,100)
d_dn_max=dblarr(n_collects,n_bands,n_ham,32,n_subset)
d_dn_min=dblarr(n_collects,n_bands,n_ham,32,n_subset)
d_dn_mean=dblarr(n_collects,n_bands,n_ham,n_subset)
d_dn_range=dblarr(n_collects,n_bands,n_ham,32,n_subset)
d_L=dblarr(n_collects,n_bands,n_ham,32,n_subset,100)
d_L_max=dblarr(n_collects,n_bands,n_ham,32,n_subset)
d_L_min=dblarr(n_collects,n_bands,n_ham,32,n_subset)
d_L_mean=dblarr(n_collects,n_bands,n_ham,n_subset)
d_L_range=dblarr(n_collects,n_bands,n_ham,32,n_subset)

;*****************************************************************************
;  Read gains from a file to an array.
;*****************************************************************************

openr,lun,'/home/jmcintire/VIIRS_Data/FP_13_Data/SMWIR/gain_SMWIR.dat',/get_lun

n_lines=File_Lines('/home/jmcintire/VIIRS_Data/FP_13_Data/SMWIR/gain_SMWIR.dat')
IF n_lines EQ 0 THEN goto,skipout

awa=''
b_name=strarr(n_lines)			; Band name.
ham_side=intarr(n_lines)		; HAM side.
detector=intarr(n_lines)		; Detector.
subframe=intarr(n_lines)		; Subframe.
g=fltarr(n_lines)			; Gain.	

FOR ix=0L, n_lines-1 DO BEGIN
	readf,lun,awa
	a1=strsplit(awa,String(9B),/Extract)
	b_name(ix)=a1(0)
	ham_side(ix)=a1(2)-1
	detector(ix)=a1(3)-1
	subframe(ix)=a1(4)-1
	g(ix)=a1(6)
ENDFOR

close,lun,/file,/all
free_lun,lun

n_subset=2
gain=fltarr(n_bands,n_ham,32,n_gain,n_subset)
FOR i=0L, n_lines-1 DO BEGIN
	IF b_name[i] EQ 'I3' THEN BEGIN
		gain[0,ham_side[i],detector[i],1,subframe[i]]=g[i]
	ENDIF
	IF b_name[i] EQ 'I4' THEN BEGIN
		gain[1,ham_side[i],detector[i],1,subframe[i]]=g[i]
	ENDIF
	IF b_name[i] EQ 'M10' THEN BEGIN
		gain[2,ham_side[i],detector[i],1,subframe[i]]=g[i]
	ENDIF
	IF b_name[i] EQ 'M11' THEN BEGIN
		gain[3,ham_side[i],detector[i],1,subframe[i]]=g[i]
	ENDIF
	IF b_name[i] EQ 'M12' THEN BEGIN
		gain[4,ham_side[i],detector[i],1,subframe[i]]=g[i]
	ENDIF
	IF b_name[i] EQ 'M13' AND g[i] GT 100 THEN BEGIN 	;High gain.
		gain[5,ham_side[i],detector[i],1,subframe[i]]=g[i]
	ENDIF
	IF b_name[i] EQ 'M13' AND g[i] LT 100 THEN BEGIN 	;Low gain.
		gain[5,ham_side[i],detector[i],0,subframe[i]]=g[i]
	ENDIF
	IF b_name[i] EQ 'M8' THEN BEGIN
		gain[6,ham_side[i],detector[i],1,subframe[i]]=g[i]
	ENDIF
	IF b_name[i] EQ 'M9' THEN BEGIN
		gain[7,ham_side[i],detector[i],1,subframe[i]]=g[i]
	ENDIF
ENDFOR

;*****************************************************************************
;  Read in the dump files.
;*****************************************************************************

FOR ifile=0, nfile-1 DO BEGIN

	print,list_files[ifile]
	nlines=File_Lines(list_files[ifile])
	band_skip[ifile]=0
	IF nlines EQ 0 THEN BEGIN
		band_skip[ifile]=1
		goto,skip
	ENDIF

	; Determine if it is M or I band.
	a2=strsplit(list_files[ifile],'/',/Extract)
	a3=N_ELEMENTS(a2)
	a4=strmid(a2[a3-1],strpos(a2[a3-1],'_',/Reverse_Search)+1,1)

	; Determine the relative collect #.
	IF ifile LT 8 THEN a5=0
	IF ifile GE 8 AND ifile LT 16 THEN a5=1
	IF ifile GE 16 THEN a5=2

	; Determine the uaid and actual collect #.
	a6=strmid(a2[a3-1],strpos(a2[a3-1],'/',/Reverse_Search)+1,8)
	a7=fix(strmid(a2[a3-1],strpos(a2[a3-1],'/',/Reverse_Search)+14,3))

	; Output file name.
	outfile='/home/jmcintire/VIIRS_Data/FP_13_Data/SMWIR/Dynamic/'+ $
		strmid(a2[a3-1],strpos(a2[a3-1],'/',/Reverse_Search)+1,8)

	read_dmpd,list_files[ifile],uaid,collect,scan,ham,apid,band,dnb_s,det,dsect,frame,offset,gain_type,dns

	max_det=max(det)		; Total # detectors.

	; Translate the band name to a number.
	IF band[0] EQ 'I3' THEN b=0
	IF band[0] EQ 'I4' THEN b=1
	IF band[0] EQ 'M10' THEN b=2
	IF band[0] EQ 'M11' THEN b=3
	IF band[0] EQ 'M12' THEN b=4
	IF band[0] EQ 'M13' THEN b=5
	IF band[0] EQ 'M8' THEN b=6
	IF band[0] EQ 'M9' THEN b=7

;*****************************************************************************
;  Write DN values to an array for earth view.
;*****************************************************************************

	IF a4 EQ 'I' THEN max_frame=200		; Total # frames (I band).
	IF a4 EQ 'M' THEN max_frame=100		; Total # frames (M band).
	IF a4 EQ 'I' THEN n_subset=2		; Total # subsets (I band).
	IF a4 EQ 'M' THEN n_subset=1		; Total # subsets (M band).

	dn_frame_ev=dblarr(n_ham,max_det,n_subset,max_scan,max_frame)
	iscan=0
	idet=0
	iframe=0
	subset=0
	FOR i=0L, nlines-1 DO BEGIN
		IF scan[i] EQ iscan+1 AND det[i] EQ idet+1 THEN BEGIN
			dn_frame_ev[ham[i],idet,subset,iscan,iframe]=dns[i]
			iframe=iframe+1
			IF iframe EQ max_frame THEN BEGIN
				idet=idet+1
				iframe=0
				IF idet EQ max_det THEN BEGIN
					idet=0
					iscan=iscan+1
				ENDIF
			ENDIF
		ENDIF
		IF a4 EQ 'I' THEN BEGIN
			IF subset EQ 0 THEN BEGIN
				subset=1
				goto,skip_over_1
			ENDIF
			IF subset EQ 1 THEN subset=0
			skip_over_1:
		ENDIF
	ENDFOR

;*****************************************************************************
;  Switch auto low gain to high gain by multiplying by the ratio of the gain states.
;*****************************************************************************

	IF b EQ 5 AND a5 NE 2 THEN BEGIN
		FOR idet=0, 15 DO BEGIN
			FOR iham=0, n_ham-1 DO BEGIN
				FOR is=0, 0 DO BEGIN
					FOR iscan=0, max_scan-1 DO BEGIN
						FOR iframe=0, 99 DO BEGIN
							IF dn_frame_ev[iham,idet,is,iscan,iframe] GT 4000 THEN BEGIN
								dn_frame_ev[iham,idet,is,iscan,iframe]= $	
									dn_frame_ev[iham,idet,is,iscan,iframe]* $
									gain[b,iham,idet,1,is]/gain[b,iham,idet,0,is]
							ENDIF
						ENDFOR
					ENDFOR
				ENDFOR
			ENDFOR
		ENDFOR
	ENDIF

;*****************************************************************************
;  Take average of every fourth scan (total of 4 averages).
;*****************************************************************************

	dn_scan_avg=dblarr(n_ham,max_det,n_subset,max_frame,4)
	FOR iham=0, n_ham-1 DO BEGIN
		FOR idet=0, max_det-1 DO BEGIN
			FOR isubset=0, n_subset-1 DO BEGIN
				FOR iframe=0, max_frame-1 DO BEGIN
					FOR iscan=0, max_scan-1, 4 DO BEGIN
						dn_scan_avg[iham,idet,isubset,iframe,0]= $
							dn_scan_avg[iham,idet,isubset,iframe,0]+ $
							dn_frame_ev[iham,idet,isubset,iscan,iframe]
						dn_scan_avg[iham,idet,isubset,iframe,1]= $
							dn_scan_avg[iham,idet,isubset,iframe,1]+ $
							dn_frame_ev[iham,idet,isubset,iscan+1,iframe]
						dn_scan_avg[iham,idet,isubset,iframe,2]= $
							dn_scan_avg[iham,idet,isubset,iframe,2]+ $
							dn_frame_ev[iham,idet,isubset,iscan+2,iframe]
						dn_scan_avg[iham,idet,isubset,iframe,3]= $
							dn_scan_avg[iham,idet,isubset,iframe,3]+ $
							dn_frame_ev[iham,idet,isubset,iscan+3,iframe]
					ENDFOR
					FOR i=0, 3 DO BEGIN
						IF dn_scan_avg[iham,idet,isubset,iframe,i] EQ -999 THEN BEGIN
							dn_scan_avg[iham,idet,isubset,iframe,i]=0
						ENDIF
						dn_scan_avg[iham,idet,isubset,iframe,i]= $
							dn_scan_avg[iham,idet,isubset,iframe,i]/64
					ENDFOR
				ENDFOR
			ENDFOR
		ENDFOR
	ENDFOR

;*****************************************************************************
;  Find the shutter order.
;*****************************************************************************

	; Get the appropriate sender band.
	IF a6 EQ 'U3102099' THEN sender_band[a5]=6
	IF a6 EQ 'U3102103' THEN sender_band[a5]=2
	IF a6 EQ 'U3102105' THEN sender_band[a5]=0
	IF a6 EQ 'U3102117' THEN sender_band[a5]=7
	IF a6 EQ 'U3102121' THEN sender_band[a5]=4
	IF a6 EQ 'U3102149' THEN sender_band[a5]=1
	IF a6 EQ 'U3102162' THEN sender_band[a5]=5
	IF a6 EQ 'U3102166' THEN sender_band[a5]=5
	IF a6 EQ 'U3102167' THEN sender_band[a5]=5

	order=fltarr(4)
	IF b EQ sender_band[a5] THEN BEGIN
		FOR iham=0, n_ham-1 DO BEGIN
			FOR idet=0, max_det-1 DO BEGIN
				IF max(dn_scan_avg[iham,idet,0,*,0]) GT 1000 THEN BEGIN
					order[0]=1
				ENDIF
				IF max(dn_scan_avg[iham,idet,0,*,1]) GT 1000 THEN BEGIN
					order[1]=1
				ENDIF
				IF max(dn_scan_avg[iham,idet,0,*,2]) GT 1000 THEN BEGIN
					order[2]=1
				ENDIF
				IF max(dn_scan_avg[iham,idet,0,*,3]) GT 1000 THEN BEGIN
					order[3]=1
				ENDIF
			ENDFOR
		ENDFOR
	ENDIF

	IF b EQ 0 THEN shutter[a5]=-1
	IF order[0] EQ 1 AND order[1] EQ 1 THEN shutter[a5]=1
	IF order[0] EQ 1 AND order[3] EQ 1 THEN shutter[a5]=2
	IF order[1] EQ 1 AND order[2] EQ 1 THEN shutter[a5]=3
	IF order[2] EQ 1 AND order[3] EQ 1 THEN shutter[a5]=4

	; For when the shutter order cannot be reconstructed properly.
	IF a6 EQ 'U3102121' AND a5 EQ 1 THEN shutter[a5]=2
	IF a6 EQ 'U3102162' AND a5 EQ 1 THEN shutter[a5]=4
	IF a6 EQ 'U3102166' AND a5 EQ 0 THEN shutter[a5]=1
	IF a6 EQ 'U3102166' AND a5 EQ 1 THEN shutter[a5]=1
	IF a6 EQ 'U3102166' AND a5 EQ 2 THEN shutter[a5]=1
	IF a6 EQ 'U3102167' AND a5 EQ 0 THEN shutter[a5]=1
	IF a6 EQ 'U3102167' AND a5 EQ 1 THEN shutter[a5]=2
	IF a6 EQ 'U3102167' AND a5 EQ 2 THEN shutter[a5]=4

;*****************************************************************************
;  Write the dn values to arrays for use later in the program.
;*****************************************************************************

	dn_ib=dblarr(n_ham,max_det,n_subset,max_frame,4)
	IF b LE 1 THEN BEGIN
		FOR idet=0, 31 DO BEGIN
			FOR iham=0, n_ham-1 DO BEGIN
				FOR i=0, 3 DO BEGIN
					iframe_2=0
					FOR iframe=0, 99 DO BEGIN
						dn_ib[iham,idet,0,iframe,i]=dn_scan_avg[iham,idet,0,iframe_2,i]
						dn_ib[iham,idet,1,iframe,i]=dn_scan_avg[iham,idet,1,iframe_2+1,i]
						iframe_2=iframe_2+2
					ENDFOR
				ENDFOR
			ENDFOR
		ENDFOR
	ENDIF

	FOR iham=0, n_ham-1 DO BEGIN
		FOR idet=0, max_det-1 DO BEGIN
			IF b LE 1 THEN n_subset=2
			IF b GT 1 THEN n_subset=1

			FOR isubset=0, n_subset-1 DO BEGIN
				FOR iframe=0, 99 DO BEGIN
					FOR i=0, 3 DO BEGIN
						IF b LE 1 THEN BEGIN
							dn_col_ev[a5,b,iham,idet,isubset,iframe,i]= $
								dn_ib[iham,idet,isubset,iframe,i]
						ENDIF ELSE BEGIN
							dn_col_ev[a5,b,iham,idet,isubset,iframe,i]= $
								dn_scan_avg[iham,idet,isubset,iframe,i]
						ENDELSE
					ENDFOR
				ENDFOR
			ENDFOR
		ENDFOR
	ENDFOR

	skip:
ENDFOR

;*****************************************************************************
;  Subtract the shutter closed scans.
;*****************************************************************************

FOR collect=0, n_collects-1 DO BEGIN
	IF shutter[collect] EQ 1 THEN alpha=[1,1,-1,-1]
	IF shutter[collect] EQ 2 THEN alpha=[1,-1,-1,1]
	IF shutter[collect] EQ 3 THEN alpha=[-1,1,1,-1]
	IF shutter[collect] EQ 4 THEN alpha=[-1,-1,1,1]

	FOR b=0, n_bands-1 DO BEGIN
		IF b LE 1 THEN m_det=32
		IF b GT 1 THEN m_det=16

		FOR idet=0, m_det-1 DO BEGIN
			IF b LE 1 THEN n_subset=2
			IF b GT 1 THEN n_subset=1

			FOR isubset=0, n_subset-1 DO BEGIN
				FOR iframe=0, 99 DO BEGIN
					FOR iham=0, n_ham-1 DO BEGIN
						dn_so[collect,b,iham,idet,isubset,iframe]= $
							+alpha[0]*dn_col_ev[collect,b,iham,idet,isubset,iframe,0] $
							+alpha[1]*dn_col_ev[collect,b,iham,idet,isubset,iframe,1] $
							+alpha[2]*dn_col_ev[collect,b,iham,idet,isubset,iframe,2] $
							+alpha[3]*dn_col_ev[collect,b,iham,idet,isubset,iframe,3]
					ENDFOR
				ENDFOR
			ENDFOR
		ENDFOR
	ENDFOR
ENDFOR

;*****************************************************************************
;  Subract the baseline average (use frames 30 or more from peak).
;*****************************************************************************

FOR collect=0, n_collects-1 DO BEGIN
	FOR b=0, n_bands-1 DO BEGIN
		IF b LE 1 THEN m_det=32
		IF b GT 1 THEN m_det=16

		FOR idet=0, m_det-1 DO BEGIN
			IF b LE 1 THEN n_subset=2
			IF b GT 1 THEN n_subset=1

			FOR isubset=0, n_subset-1 DO BEGIN
				FOR iham=0, n_ham-1 DO BEGIN
					FOR iframe=0, 22 DO BEGIN
						dn_bl[collect,b,iham,idet,isubset]= $
							dn_bl[collect,b,iham,idet,isubset]+ $
							dn_so[collect,b,iham,idet,isubset,iframe]
					ENDFOR
					FOR iframe=82, 99 DO BEGIN
						dn_bl[collect,b,iham,idet,isubset]= $
							dn_bl[collect,b,iham,idet,isubset]+ $
							dn_so[collect,b,iham,idet,isubset,iframe]
					ENDFOR
					dn_bl[collect,b,iham,idet,isubset]=dn_bl[collect,b,iham,idet,isubset]/41

					FOR iframe=0, 99 DO BEGIN
						dn[collect,b,iham,idet,isubset,iframe]= $
							dn_so[collect,b,iham,idet,isubset,iframe]- $
							dn_bl[collect,b,iham,idet,isubset]
					ENDFOR
				ENDFOR
			ENDFOR
		ENDFOR
	ENDFOR
ENDFOR

;*****************************************************************************
;  Output DN to files for I and M bands.
;*****************************************************************************

fmt_1='(i3, 5x, a5, 5x, i2, 5x, i4, 5x, d, 5x, d, 5x, d, 5x, d)'
fmt_2='(i3, 5x, a5, 5x, i2, 5x, i4, 5x, d, 5x, d)'

; Output numbers to a data file.
openw,lun,outfile+'_I.dat',/get_lun
openw,lon,outfile+'_M.dat',/get_lun
printf,lun,'Collect  Band  Detector  FRAME  DN(sub=0 HAM=1)  DN(sub=1 HAM=1)  DN(sub=0 HAM=2)  DN(sub=1 HAM=2)'
printf,lon,'Collect  Band  Detector  FRAME  DN(HAM=1)  DN(HAM=2)'
FOR collect=0, n_collects-1 DO BEGIN
	FOR b=0, n_bands-1 DO BEGIN
		ifile=8*collect+b
		IF band_skip[ifile] EQ 1 THEN goto,skip_band
		FOR idet=0, 31 DO BEGIN
			FOR iframe=0, 99 DO BEGIN
				IF b LE 1 THEN printf,lun,format=fmt_1,collect+1,bandname[b],idet+1,iframe+970, $
					dn[collect,b,0,idet,0,iframe],dn[collect,b,0,idet,0,iframe], $
					dn[collect,b,1,idet,1,iframe],dn[collect,b,1,idet,1,iframe]
				IF b GT 1 AND idet EQ 16 THEN goto,skip_det
				IF b GT 1 THEN printf,lon,format=fmt_2,collect+1,bandname[b],idet+1,iframe+970, $
					dn[collect,b,0,idet,0,iframe],dn[collect,b,1,idet,0,iframe]
			ENDFOR
		ENDFOR
		skip_det:
		skip_band:
	ENDFOR
ENDFOR
close,lun,/file,/all
free_lun,lun

;*****************************************************************************
;  Calculate radiance. Determine the derivative of dn and radiance.
;*****************************************************************************

FOR collect=0, n_collects-1 DO BEGIN
	FOR b=0, n_bands-1 DO BEGIN
		ifile_r=8*collect+b
		IF band_skip[ifile_r] EQ 1 THEN goto,skip_band_s

		FOR iham=0, n_ham-1 DO BEGIN
			IF b LE 1 THEN n_subset=2
			IF b GT 1 THEN n_subset=1

			FOR is=0, n_subset-1 DO BEGIN
				IF b LE 1 THEN n_d=32
				IF b GT 1 THEN n_d=16

				FOR id=0, n_d-1 DO BEGIN
					IF collect LE 1 THEN BEGIN
						FOR f=0, 99 DO BEGIN
							L[collect,b,iham,id,is,f]=dn[collect,b,iham,id,is,f]/ $
								gain[b,iham,id,1,is]
						ENDFOR

					; UAID 3102166 and 3102167
					ENDIF ELSE BEGIN
						IF b NE 5 THEN BEGIN
							FOR f=0, 99 DO BEGIN
								L[collect,b,iham,id,is,f]=dn[collect,b,iham,id,is,f]/ $
									gain[b,iham,id,1,is]
							ENDFOR
						ENDIF
						IF b EQ 5 THEN BEGIN
							FOR f=0, 99 DO BEGIN
								L[collect,b,iham,id,is,f]=dn[collect,b,iham,id,is,f]/ $
									gain[b,iham,id,0,is]
							ENDFOR
						ENDIF
					ENDELSE

					FOR f=0, 98 DO BEGIN
						d_dn[collect,b,iham,id,is,f]=dn[collect,b,iham,id,is,f+1]- $
							dn[collect,b,iham,id,is,f]
						d_L[collect,b,iham,id,is,f]=L[collect,b,iham,id,is,f+1]- $
							L[collect,b,iham,id,is,f]
					ENDFOR
					d_dn_max[collect,b,iham,id,is]=max(d_dn[collect,b,iham,id,is,*])
					d_dn_min[collect,b,iham,id,is]=min(d_dn[collect,b,iham,id,is,*])
					d_L_max[collect,b,iham,id,is]=max(d_L[collect,b,iham,id,is,*])
					d_L_min[collect,b,iham,id,is]=min(d_L[collect,b,iham,id,is,*])

					d_dn_range[collect,b,iham,id,is]=(d_dn_max[collect,b,iham,id,is]- $
						d_dn_min[collect,b,iham,id,is])/2
					d_L_range[collect,b,iham,id,is]=(d_L_max[collect,b,iham,id,is]- $
						d_L_min[collect,b,iham,id,is])/2
				ENDFOR
				d_dn_mean[collect,b,iham,is]=sig_mean(d_dn_max[collect,b,iham,*,is],3,1)
				d_L_mean[collect,b,iham,is]=sig_mean(d_L_max[collect,b,iham,*,is],3,1)
			ENDFOR
		ENDFOR
		skip_band_s:
	ENDFOR
ENDFOR

;*****************************************************************************
;  Calculate coefficients.
;*****************************************************************************

n_subset=2
dn_r=fltarr(n_bands,n_ham,32,n_subset,100)
dn_lg=fltarr(n_bands,n_ham,32,n_subset,100)
dn_r_max=fltarr(n_bands,n_ham,32,n_subset)
dn_r_mean_det=fltarr(n_bands,n_ham,n_subset)
ic_dn=fltarr(n_bands,n_ham,32,n_subset)

L_r=fltarr(n_bands,n_ham,32,n_subset,100)
L_lg=fltarr(n_bands,n_ham,32,n_subset,100)
L_r_max=fltarr(n_bands,n_ham,32,n_subset)
L_r_mean_det=fltarr(n_bands,n_ham,n_subset)
ic_L=fltarr(n_bands,n_ham,32,n_subset)

d_L_r_max=fltarr(n_bands,n_ham,32,n_subset)
d_L_r_mean=fltarr(n_bands,n_ham,n_subset)
ic_d_L=fltarr(n_bands,n_ham,32,n_subset)
FOR b=0, n_bands-1 DO BEGIN
	IF b LE 3 OR b GE 6 THEN BEGIN
		dn_r[b,*,*,*,*]=(dn[0,b,*,*,*,*]+dn[1,b,*,*,*,*])/2
		L_r[b,*,*,*,*]=(L[0,b,*,*,*,*]+L[1,b,*,*,*,*])/2
		d_L_r_max[b,*,*,*,*]=(d_L_max[0,b,*,*,*]+d_L_max[1,b,*,*,*])/2
		d_L_r_mean[b,*,*]=(d_L_mean[0,b,*,*]+d_L_mean[1,b,*,*])/2

		; UAID 3102166 and 3102167
	;	dn_lg[b,*,*,*,*]=dn[2,b,*,*,*,*]
	;	L_lg[b,*,*,*,*]=L[2,b,*,*,*,*]
	ENDIF
	IF b EQ 4 OR b EQ 5 THEN BEGIN
		dn_r[b,*,*,*,*]=dn[0,b,*,*,*,*]
		L_r[b,*,*,*,*]=L[0,b,*,*,*,*]
		d_L_r_max[b,*,*,*]=d_L_max[0,b,*,*,*]
		d_L_r_mean[b,*,*]=d_L_mean[0,b,*,*]

		; UAID 3102166
	;	dn_r[b,*,*,*,*]=dn[1,b,*,*,*,*]
	;	L_r[b,*,*,*,*]=L[1,b,*,*,*,*]
	;	d_L_r_max[b,*,*,*]=d_L_max[1,b,*,*,*]
	;	d_L_r_mean[b,*,*]=d_L_mean[1,b,*,*]

		; UAID 3102166 and 3102167
	;	dn_lg[b,*,*,*,*]=dn[2,b,*,*,*,*]
	;	L_lg[b,*,*,*,*]=L[2,b,*,*,*,*]
	ENDIF
ENDFOR

FOR b=0, n_bands-1 DO BEGIN
	IF b LE 1 THEN m_det=32
	IF b GT 1 THEN m_det=16

	FOR idet=0, m_det-1 DO BEGIN
		IF b LE 1 THEN n_subset=2
		IF b GT 1 THEN n_subset=1

		FOR is=0, n_subset-1 DO BEGIN
			FOR ih=0, n_ham-1 DO BEGIN
				dn_r_max[b,ih,idet,is]=max(dn_r[b,ih,idet,is,*])
				L_r_max[b,ih,idet,is]=max(L_r[b,ih,idet,is,*])
			ENDFOR
		ENDFOR
	ENDFOR
	IF sender_band[0] EQ b THEN BEGIN
		IF b LE 1 THEN n_subset=2
		IF b GT 1 THEN n_subset=1

		FOR is=0, n_subset-1 DO BEGIN
			FOR ih=0, n_ham-1 DO BEGIN
				dn_r_mean_det[b,ih,is]=sig_mean(dn_r_max[b,ih,*,is],3,1)
				L_r_mean_det[b,ih,is]=sig_mean(L_r_max[b,ih,*,is],3,1)
			ENDFOR
		ENDFOR
		; Average over subframes for UAID 3102105 and 3102149
	;	IF b EQ 0 THEN BEGIN
	;	IF b EQ 1 THEN BEGIN
	;		FOR ih=0, n_ham-1 DO BEGIN
	;			dn_r_mean_det[b,ih,0]=(dn_r_mean_det[b,ih,0]+dn_r_mean_det[b,ih,1])/2
	;			L_r_mean_det[b,ih,0]=(L_r_mean_det[b,ih,0]+L_r_mean_det[b,ih,1])/2
	;		ENDFOR
	;	ENDIF
	ENDIF
ENDFOR
FOR b=0, n_bands-1 DO BEGIN
	IF b LE 1 THEN m_det=32
	IF b GT 1 THEN m_det=16

	FOR idet=0, m_det-1 DO BEGIN
		IF b LE 1 THEN n_subset=2
		IF b GT 1 THEN n_subset=1

		FOR is=0, n_subset-1 DO BEGIN
			FOR ih=0, n_ham-1 DO BEGIN
				ic_dn[b,ih,idet,is]=dn_r_max[b,ih,idet,is]/dn_r_mean_det[sender_band[0],ih,0]
				ic_L[b,ih,idet,is]=L_r_max[b,ih,idet,is]/L_r_mean_det[sender_band[0],ih,0]
				ic_d_L[b,ih,idet,is]=d_L_r_max[b,ih,idet,is]/d_L_r_mean[sender_band[0],ih,0]
			ENDFOR
		ENDFOR
	ENDFOR
ENDFOR

;*****************************************************************************
;  Output max dn and radiances to a formated file.
;*****************************************************************************

fmt_3='(d, 5x, d, 5x, d, 5x, d, 5x, d, 5x, d, 5x, d, 5x, d, 5x, d, 5x, d)'
fmt_4='(10x, i5, 15x, i5, 5x, d, 5x, d, 5x, d, 5x, d, 15x, i5, 15x, i5, 15x, i5, 15x, i5)'

openw,lun,outfile+'_dn_oob.dat',/get_lun
openw,len,outfile+'_L_oob.dat',/get_lun
openw,len,outfile+'_d_L_oob.dat',/get_lun
place=-999.000
FOR ih=0, n_ham-1 DO BEGIN
	FOR idet=0, 31 DO BEGIN
		IF idet LT 16 THEN printf,lun,format=fmt_3,ic_dn[5,ih,idet,0],ic_dn[4,ih,idet,0], $
			ic_dn[1,ih,idet,0],ic_dn[1,ih,idet,1],ic_dn[0,ih,idet,0],ic_dn[0,ih,idet,1], $
			ic_dn[2,ih,idet,0],ic_dn[3,ih,idet,0],ic_dn[6,ih,idet,0],ic_dn[7,ih,idet,0]
		IF idet GE 16 THEN printf,lun,format=fmt_4,place,place,ic_dn[1,ih,idet,0],ic_dn[1,ih,idet,1], $
			ic_dn[0,ih,idet,0],ic_dn[0,ih,idet,1],place,place,place,place
		IF idet LT 16 THEN printf,lon,format=fmt_3,ic_L[5,ih,idet,0],ic_L[4,ih,idet,0], $
			ic_L[1,ih,idet,0],ic_L[1,ih,idet,1],ic_L[0,ih,idet,0],ic_L[0,ih,idet,1], $
			ic_L[2,ih,idet,0],ic_L[3,ih,idet,0],ic_L[6,ih,idet,0],ic_L[7,ih,idet,0]
		IF idet GE 16 THEN printf,lon,format=fmt_4,place,place,ic_L[1,ih,idet,0],ic_L[1,ih,idet,1], $
			ic_L[0,ih,idet,0],ic_L[0,ih,idet,1],place,place,place,place
		IF idet LT 16 THEN printf,len,format=fmt_3,ic_d_L[5,ih,idet,0],ic_d_L[4,ih,idet,0], $
			ic_d_L[1,ih,idet,0],ic_d_L[1,ih,idet,1],ic_d_L[0,ih,idet,0],ic_d_L[0,ih,idet,1], $
			ic_d_L[2,ih,idet,0],ic_d_L[3,ih,idet,0],ic_d_L[6,ih,idet,0],ic_d_L[7,ih,idet,0]
		IF idet GE 16 THEN printf,len,format=fmt_4,place,place,ic_d_L[1,ih,idet,0],ic_d_L[1,ih,idet,1], $
			ic_d_L[0,ih,idet,0],ic_d_L[0,ih,idet,1],place,place,place,place
	ENDFOR
ENDFOR
close,lun,/file,/all
free_lun,lun

save,/compress,dn,L,d_dn,d_L,ic_dn,ic_L,ic_d_L,filename=outfile+'.sav'

skipout:

END

