;*****************************************************************************
;  FP-13 Dynamic vertical slit LWIR Xtalk test. This is version 2 which graphs
;  the dn and radiance per frame per band. in addition, de-registered graphs
;  are created for both dn and radiance. The first derivative is also plotted
;  in dn and radiance space. 
;  
;  v1.0 - 02/21/2008 - Jeff McIntire
;*****************************************************************************

PRO view_sf_dyn_LWIR_2

close,/all

band_name=['I5 SS1','I5 SS2','M14','M15','M16A','M16B']
nband=n_elements(band_name)
nham=2
ndet=32
nsub=2
nframe=100
ndet_I=32
ndet_M=16
det_I=findgen(ndet_I)
det_M=findgen(ndet_M)
iframe=findgen(2*nframe)

t_name1=['990','1010','1030','1050']
t_name2=['990','1010','1030','1050','1070']
t_name3=['970','990','1010','1030','1050','1070']

uaidname=['3102125','3102154','3102156','3102158','3102160']
bandname=['M14','M16A','M16B','I5','M15']
n_uaid=N_ELEMENTS(uaidname)

m15='M15'
m14='M14'
m16a='M16A'
m16b='M16B'
i5e='I5e'
i5o='I5o'

FOR uaid=0, n_uaid-1 DO BEGIN
	set_multicolor,xsave,ysave,psave,chname,lcol,symbol,red,green,blue
	set_plot,'ps'
	outfname='/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/Dynamic/U'+uaidname[uaid]+'.2.ps'
	device,/landscape,filename=outfname,/color
	!p.multi=[0,3,2]

	infname1='/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/Dynamic/U'+uaidname[uaid]+'.sav'
	check=FILE_SEARCH(infname1)
	IF check EQ '' THEN BEGIN
		print,'No file is found.',infname1
		goto,skip_loop
	ENDIF
	print,'Processing file:',infname1
	restore,infname1

	dn_r=fltarr(nband,nham,ndet,nsub,nframe)
	L_r=fltarr(nband,nham,ndet,nsub,nframe)
	d_dn_r=fltarr(nband,nham,ndet,nsub,nframe)
	d_L_r=fltarr(nband,nham,ndet,nsub,nframe)
	FOR b=0, 4 DO BEGIN
		IF b EQ 0 OR b EQ 4 THEN BEGIN
			dn_r[b,*,*,*,*]=(dn[0,b,*,*,*,*]+dn[1,b,*,*,*,*])/2
			L_r[b,*,*,*,*]=(L[0,b,*,*,*,*]+L[1,b,*,*,*,*])/2
			d_dn_r[b,*,*,*,*]=(d_dn[0,b,*,*,*,*]+d_dn[1,b,*,*,*,*])/2
			d_L_r[b,*,*,*,*]=(d_L[0,b,*,*,*,*]+d_L[1,b,*,*,*,*])/2
		ENDIF
		IF b EQ 1 OR b EQ 2 THEN BEGIN
			dn_r[b,*,*,*,*]=dn[0,b,*,*,*,*]
			L_r[b,*,*,*,*]=L[0,b,*,*,*,*]
			d_dn_r[b,*,*,*,*]=d_dn[0,b,*,*,*,*]
			d_L_r[b,*,*,*,*]=d_L[0,b,*,*,*,*]
		ENDIF
		IF b EQ 3 THEN BEGIN
			dn_r[b,*,*,*,*]=dn[1,b,*,*,*,*]
			L_r[b,*,*,*,*]=L[1,b,*,*,*,*]
			d_dn_r[b,*,*,*,*]=d_dn[1,b,*,*,*,*]
			d_L_r[b,*,*,*,*]=d_L[1,b,*,*,*,*]
		ENDIF
		IF uaid EQ 1 THEN BEGIN
			IF b EQ 1 OR b EQ 2 THEN BEGIN
				dn_r[b,*,*,*,*]=dn[1,b,*,*,*,*]
				L_r[b,*,*,*,*]=L[1,b,*,*,*,*]
				d_dn_r[b,*,*,*,*]=d_dn[1,b,*,*,*,*]
				d_L_r[b,*,*,*,*]=d_L[1,b,*,*,*,*]
			ENDIF
			IF b EQ 3 THEN BEGIN
				dn_r[b,*,*,*,*]=dn[0,b,*,*,*,*]
				L_r[b,*,*,*,*]=L[0,b,*,*,*,*]
				d_dn_r[b,*,*,*,*]=d_dn[0,b,*,*,*,*]
				d_L_r[b,*,*,*,*]=d_L[0,b,*,*,*,*]
			ENDIF
		ENDIF
	ENDFOR

	i=0
	FOR b=0, 4 DO BEGIN
		IF b GT 0 THEN i=1
		plot,iframe[*],dn_r[b,0,0,0,*],xrange=[0,100],yrange=[-20,20],title=band_name[b+i], $
			ytit='dn',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name3,/nodata
		IF b EQ 0 THEN BEGIN
			FOR det=0, ndet_I-1 DO BEGIN
				oplot,iframe[*],dn_r[b,0,det,0,*],color=lcol[det]
			ENDFOR
			plot,iframe[*],dn_r[b,0,0,1,*],xrange=[0,100],yrange=[-20,20],title=band_name[1], $
				ytit='dn',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name3,/nodata
			FOR det=0, ndet_I-1 DO BEGIN
				oplot,iframe[*],dn_r[b,0,det,1,*],color=lcol[det]
			ENDFOR
		ENDIF
		IF b NE 0 THEN BEGIN
			FOR det=0, ndet_M-1 DO BEGIN
				oplot,iframe[*],dn_r[b,0,det,0,*],color=lcol[det]
			ENDFOR
		ENDIF
	ENDFOR
	title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': DN vs frame'
	XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5

	i=0
	FOR b=0, 4 DO BEGIN
		!p.multi=[0,4,4]
		!p.position=0

		IF b GT 0 THEN i=1
		IF b EQ 0 THEN BEGIN
			FOR det=0, ndet_I-1 DO BEGIN
				plot,iframe[*],dn_r[b,0,0,0,*],xrange=[0,100],yrange=[-20,20], $
					title=band_name[b+i]+' det='+strtrim(string(det+1),1), $
					ytit='dn',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name3,/nodata
				oplot,iframe[*],dn_r[b,0,det,0,*],color=lcol[det]

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': DN vs frame'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
			ENDFOR
			FOR det=0, ndet_I-1 DO BEGIN
				plot,iframe[*],dn_r[b,0,0,1,*],xrange=[0,100],yrange=[-20,20], $
					title=band_name[1]+' det='+strtrim(string(det+1),1), $
					ytit='dn',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name3,/nodata
				oplot,iframe[*],dn_r[b,0,det,1,*],color=lcol[det]

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': DN vs frame'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
			ENDFOR
		ENDIF
		IF b NE 0 THEN BEGIN
			FOR det=0, ndet_M-1 DO BEGIN
				plot,iframe[*],dn_r[b,0,det,0,*],xrange=[0,100],yrange=[-20,20], $
					title=band_name[b+i]+' det='+strtrim(string(det+1),1), $
					ytit='dn',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name3,/nodata
				oplot,iframe[*],dn_r[b,0,det,0,*],color=lcol[det]
			ENDFOR
		ENDIF
		title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': DN vs frame'
		XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
	ENDFOR

	k=1
	FOR det=0, ndet_M-1 DO BEGIN

		IF k EQ 1 THEN BEGIN 
			k=0
			goto,skip_k
		ENDIF
		IF k EQ 0 THEN k=1
		skip_k:

		name=['I5 SS1, det '+strtrim(string(2*det+1),1),'I5 SS2, det '+strtrim(string(2*det+1),1), $
			'I5 SS1, det '+strtrim(string(2*det+2),1),'I5 SS2, det '+strtrim(string(2*det+2),1), $
			'M14, det '+strtrim(string(det+1),1),'M15, det '+strtrim(string(det+1),1), $
			'M16A, det '+strtrim(string(det+1),1),'M16B, det '+strtrim(string(det+1),1)]

		;UAID 3102125
		IF uaid EQ 0 THEN BEGIN
			!p.multi=[0,1,1]
			!p.position=0

			FOR j=0, 1 DO BEGIN
				plot,iframe[0:99],dn_r[0,0,0,0,0:99],xrange=[20,80],yrange=[-20,20+j*2000],ytit='dn', $
					xtit='frame',charsize=1.2,charthick=5,xtickname=t_name1,/nodata
				oplot,[53,53],[-2000,3000],linestyle=2,thick=3
				oplot,[47,47],[-2000,3000],linestyle=2,thick=3
				oplot,[41,41],[-2000,3000],linestyle=2,thick=3
				oplot,[35,35],[-2000,3000],linestyle=2,thick=3
				IF k EQ 0 THEN BEGIN
					oplot,[32,32],[-2000,3000],linestyle=2,thick=3
					oplot,[31,31],[-2000,3000],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,[29,29],[-2000,3000],linestyle=2,thick=3
					oplot,[28,28],[-2000,3000],linestyle=2,thick=3
				ENDIF

				IF k EQ 0 THEN BEGIN
					oplot,iframe[0:99],dn_r[0,0,2*det,0,21:99],color=lcol[0],thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det,1,21:99],color=lcol[1],thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det+1,0,22:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det+1,1,22:99],color=lcol[1],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,iframe[0:99],dn_r[0,0,2*det,0,24:99],color=lcol[0],thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det,1,24:99],color=lcol[1],thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det+1,0,25:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det+1,1,25:99],color=lcol[1],linestyle=2,thick=3
				ENDIF
				oplot,iframe[0:99],dn_r[1,0,det,0,0:99],color=lcol[2],thick=3
				oplot,iframe[0:99],dn_r[2,0,det,0,6:99],color=lcol[3],thick=3
				oplot,iframe[0:99],dn_r[3,0,det,0,18:99],color=lcol[4],thick=3
				oplot,iframe[0:99],dn_r[4,0,det,0,12:99],color=lcol[5],thick=3

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': DN vs frame'
				subtitle='Detectors '+strtrim(string(det+1),1)+' (M), '+strtrim(string(2*det+1),1)+ $
					' and '+strtrim(string(2*det+2),1)+' (I)'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.5,0.975,subtitle,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.56,0.15,m14,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.475,0.15,m15,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.385,0.15,m16b,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.30,0.15,m16a,/normal,alignment=0.5,charsize=1,charthick=5
				IF k EQ 0 THEN BEGIN
					XYOUTS,0.265,0.18,i5e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.255,0.15,i5o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				IF k EQ 1 THEN BEGIN
					XYOUTS,0.225,0.15,i5e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.21,0.18,i5o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF

				legend,name,linestyle=[0,0,2,2,0,0,0,0],colors=[0,1,0,1,2,3,5,6], $
					thick=2,charthick=5,/right_legend
			ENDFOR
		ENDIF

		;UAID 3102154
		IF uaid EQ 1 THEN BEGIN
			!p.multi=[0,1,1]
			!p.position=0

			FOR j=0, 1 DO BEGIN
				plot,iframe[0:99],dn_r[0,0,0,0,0:99],xrange=[20,80],yrange=[-20,20+j*2000], $
					ytit='dn',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name1,/nodata
				oplot,[71,71],[-2000,3000],linestyle=2,thick=3
				oplot,[65,65],[-2000,3000],linestyle=2,thick=3
				oplot,[59,59],[-2000,3000],linestyle=2,thick=3
				oplot,[53,53],[-2000,3000],linestyle=2,thick=3
				IF k EQ 0 THEN BEGIN
					oplot,[50,50],[-2000,3000],linestyle=2,thick=3
					oplot,[49,49],[-2000,3000],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,[47,47],[-2000,3000],linestyle=2,thick=3
					oplot,[46,46],[-2000,3000],linestyle=2,thick=3
				ENDIF

				IF k EQ 0 THEN BEGIN
					oplot,iframe[0:99],dn_r[0,0,2*det,0,3:99],color=lcol[0],thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det,1,3:99],color=lcol[1],thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det+1,0,4:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det+1,1,4:99],color=lcol[1],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,iframe[0:99],dn_r[0,0,2*det,0,6:99],color=lcol[0],thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det,1,6:99],color=lcol[1],thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det+1,0,7:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det+1,1,7:99],color=lcol[1],linestyle=2,thick=3
				ENDIF
				oplot,iframe[18:99],dn_r[1,0,det,0,0:99],color=lcol[2],thick=3
				oplot,iframe[12:99],dn_r[2,0,det,0,0:99],color=lcol[3],thick=3
				oplot,iframe[0:99],dn_r[3,0,det,0,0:99],color=lcol[4],thick=3
				oplot,iframe[6:99],dn_r[4,0,det,0,0:99],color=lcol[5],thick=3

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': DN vs frame'
				subtitle='Detectors '+strtrim(string(det+1),1)+' (M), '+strtrim(string(2*det+1),1)+ $
					' and '+strtrim(string(2*det+2),1)+' (I)'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.5,0.975,subtitle,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.82,0.15,m14,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.735,0.15,m15,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.64,0.15,m16b,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.56,0.15,m16a,/normal,alignment=0.5,charsize=1,charthick=5
				IF k EQ 0 THEN BEGIN
					XYOUTS,0.525,0.18,i5e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.51,0.15,i5o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				IF k EQ 1 THEN BEGIN
					XYOUTS,0.48,0.15,i5e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.47,0.18,i5o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF

				legend,name,linestyle=[0,0,2,2,0,0,0,0],colors=[0,1,0,1,2,3,5,6],thick=2,charthick=5
			ENDFOR
		ENDIF

		;UAID 3102156
		IF uaid EQ 2 THEN BEGIN
			!p.multi=[0,1,1]
			!p.position=0

			FOR j=0, 1 DO BEGIN
				plot,iframe[0:99],dn_r[0,0,0,0,0:99],xrange=[20,80],yrange=[-20,20+j*2000], $
					ytit='dn',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name1,/nodata
				oplot,[65,65],[-2000,3000],linestyle=2,thick=3
				oplot,[59,59],[-2000,3000],linestyle=2,thick=3
				oplot,[53,53],[-2000,3000],linestyle=2,thick=3
				oplot,[47,47],[-2000,3000],linestyle=2,thick=3
				IF k EQ 0 THEN BEGIN
					oplot,[44,44],[-2000,3000],linestyle=2,thick=3
					oplot,[43,43],[-2000,3000],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,[41,41],[-2000,3000],linestyle=2,thick=3
					oplot,[40,40],[-2000,3000],linestyle=2,thick=3
				ENDIF

				IF k EQ 0 THEN BEGIN
					oplot,iframe[0:99],dn_r[0,0,2*det,0,9:99],color=lcol[0],thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det,1,9:99],color=lcol[1],thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det+1,0,10:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det+1,1,10:99],color=lcol[1],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,iframe[0:99],dn_r[0,0,2*det,0,12:99],color=lcol[0],thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det,1,12:99],color=lcol[1],thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det+1,0,13:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det+1,1,13:99],color=lcol[1],linestyle=2,thick=3
				ENDIF
				oplot,iframe[12:99],dn_r[1,0,det,0,0:99],color=lcol[2],thick=3
				oplot,iframe[6:99],dn_r[2,0,det,0,0:99],color=lcol[3],thick=3
				oplot,iframe[0:99],dn_r[3,0,det,0,6:99],color=lcol[4],thick=3
				oplot,iframe[0:99],dn_r[4,0,det,0,0:99],color=lcol[5],thick=3

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': DN vs frame'
				subtitle='Detectors '+strtrim(string(det+1),1)+' (M), '+strtrim(string(2*det+1),1)+ $
					' and '+strtrim(string(2*det+2),1)+' (I)'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.5,0.975,subtitle,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.735,0.15,m14,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.65,0.15,m15,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.555,0.15,m16b,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.475,0.15,m16a,/normal,alignment=0.5,charsize=1,charthick=5
				IF k EQ 0 THEN BEGIN
					XYOUTS,0.44,0.18,i5e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.43,0.15,i5o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				IF k EQ 1 THEN BEGIN
					XYOUTS,0.395,0.15,i5e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.385,0.18,i5o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF

				legend,name,linestyle=[0,0,2,2,0,0,0,0],colors=[0,1,0,1,2,3,5,6],thick=2,charthick=5
			ENDFOR
		ENDIF

		;UAID 3102158
		IF uaid EQ 3 THEN BEGIN
			!p.multi=[0,1,1]
			!p.position=0

			FOR j=0, 1 DO BEGIN
				plot,iframe[0:99],dn_r[0,0,0,0,0:99],xrange=[20,100],yrange=[-20,20+j*2000], $
					ytit='dn',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name2,/nodata
				IF k EQ 0 THEN BEGIN
					oplot,[75,75],[-2000,3000],linestyle=2,thick=3
					oplot,[69,69],[-2000,3000],linestyle=2,thick=3
					oplot,[63,63],[-2000,3000],linestyle=2,thick=3
					oplot,[57,57],[-2000,3000],linestyle=2,thick=3
					oplot,[54,54],[-2000,3000],linestyle=2,thick=3
					oplot,[53,53],[-2000,3000],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,[78,78],[-2000,3000],linestyle=2,thick=3
					oplot,[72,72],[-2000,3000],linestyle=2,thick=3
					oplot,[66,66],[-2000,3000],linestyle=2,thick=3
					oplot,[60,60],[-2000,3000],linestyle=2,thick=3
					oplot,[54,54],[-2000,3000],linestyle=2,thick=3
					oplot,[53,53],[-2000,3000],linestyle=2,thick=3
				ENDIF

				IF k EQ 0 THEN BEGIN
					oplot,iframe[1:99],dn_r[0,0,2*det,0,0:99],color=lcol[0],thick=3
					oplot,iframe[1:99],dn_r[0,0,2*det,1,0:99],color=lcol[1],thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det+1,0,0:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det+1,1,0:99],color=lcol[1],linestyle=2,thick=3
					oplot,iframe[22:99],dn_r[1,0,det,0,0:99],color=lcol[2],thick=3
					oplot,iframe[16:99],dn_r[2,0,det,0,0:99],color=lcol[3],thick=3
					oplot,iframe[4:99],dn_r[3,0,det,0,0:99],color=lcol[4],thick=3
					oplot,iframe[10:99],dn_r[4,0,det,0,0:99],color=lcol[5],thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,iframe[1:99],dn_r[0,0,2*det,0,0:99],color=lcol[0],thick=3
					oplot,iframe[1:99],dn_r[0,0,2*det,1,0:99],color=lcol[1],thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det+1,0,0:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det+1,1,0:99],color=lcol[1],linestyle=2,thick=3
					oplot,iframe[25:99],dn_r[1,0,det,0,0:99],color=lcol[2],thick=3
					oplot,iframe[19:99],dn_r[2,0,det,0,0:99],color=lcol[3],thick=3
					oplot,iframe[7:99],dn_r[3,0,det,0,0:99],color=lcol[4],thick=3
					oplot,iframe[13:99],dn_r[4,0,det,0,0:99],color=lcol[5],thick=3
				ENDIF

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': DN vs frame'
				subtitle='Detectors '+strtrim(string(det+1),1)+' (M), '+strtrim(string(2*det+1),1)+ $
					' and '+strtrim(string(2*det+2),1)+' (I)'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.5,0.975,subtitle,/normal,alignment=0.5,charsize=1.6,charthick=5
				IF k EQ 0 THEN BEGIN
					XYOUTS,0.68,0.15,m14,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.615,0.15,m15,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.545,0.15,m16b,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.485,0.15,m16a,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.46,0.18,i5e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.445,0.15,i5o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				IF k EQ 1 THEN BEGIN
					XYOUTS,0.71,0.15,m14,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.65,0.15,m15,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.58,0.15,m16b,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.52,0.15,m16a,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.46,0.15,i5e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.45,0.18,i5o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF

				legend,name,linestyle=[0,0,2,2,0,0,0,0],colors=[0,1,0,1,2,3,5,6],thick=2,charthick=5
			ENDFOR
		ENDIF

		;UAID 3102160
		IF uaid EQ 4 THEN BEGIN
			!p.multi=[0,1,1]
			!p.position=0

			FOR j=0, 1 DO BEGIN
				plot,iframe[0:99],dn_r[0,0,0,0,0:99],xrange=[20,80],yrange=[-20,20+j*2000], $
					ytit='dn',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name1,/nodata
				oplot,[59,59],[-2000,3000],linestyle=2,thick=3
				oplot,[53,53],[-2000,3000],linestyle=2,thick=3
				oplot,[47,47],[-2000,3000],linestyle=2,thick=3
				oplot,[41,41],[-2000,3000],linestyle=2,thick=3
				IF k EQ 0 THEN BEGIN
					oplot,[38,38],[-2000,3000],linestyle=2,thick=3
					oplot,[37,37],[-2000,3000],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,[35,35],[-2000,3000],linestyle=2,thick=3
					oplot,[34,34],[-2000,3000],linestyle=2,thick=3
				ENDIF

				IF k EQ 0 THEN BEGIN
					oplot,iframe[0:99],dn_r[0,0,2*det,0,15:99],color=lcol[0],thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det,1,15:99],color=lcol[1],thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det+1,0,16:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det+1,1,16:99],color=lcol[1],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,iframe[0:99],dn_r[0,0,2*det,0,18:99],color=lcol[0],thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det,1,18:99],color=lcol[1],thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det+1,0,19:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det+1,1,19:99],color=lcol[1],linestyle=2,thick=3
				ENDIF
				oplot,iframe[6:99],dn_r[1,0,det,0,0:99],color=lcol[2],thick=3
				oplot,iframe[0:99],dn_r[2,0,det,0,0:99],color=lcol[3],thick=3
				oplot,iframe[0:99],dn_r[3,0,det,0,12:99],color=lcol[4],thick=3
				oplot,iframe[0:99],dn_r[4,0,det,0,6:99],color=lcol[5],thick=3

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': DN vs frame'
				subtitle='Detectors '+strtrim(string(det+1),1)+' (M), '+strtrim(string(2*det+1),1)+ $
					' and '+strtrim(string(2*det+2),1)+' (I)'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.5,0.975,subtitle,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.65,0.15,m14,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.56,0.15,m15,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.47,0.15,m16b,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.39,0.15,m16a,/normal,alignment=0.5,charsize=1,charthick=5
				IF k EQ 0 THEN BEGIN
					XYOUTS,0.35,0.18,i5e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.34,0.15,i5o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				IF k EQ 1 THEN BEGIN
					XYOUTS,0.31,0.15,i5e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.30,0.18,i5o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF

				legend,name,linestyle=[0,0,2,2,0,0,0,0],colors=[0,1,0,1,2,3,5,6], $
					thick=2,charthick=5,/right_legend
			ENDFOR
		ENDIF
	ENDFOR
	!p.multi=[0,3,2]
	!p.position=0

	i=0
	FOR b=0, 4 DO BEGIN
		IF b GT 0 THEN i=1
		plot,iframe[*],L_r[b,0,0,0,*],xrange=[0,100],yrange=[-.2,.2],title=band_name[b+i],ytit='L',xtit='frame', $
			charsize=1.2,charthick=5,xtickname=t_name3,/nodata
		IF b EQ 0 THEN BEGIN
			FOR det=0, ndet_I-1 DO BEGIN
				oplot,iframe[*],L_r[b,0,det,0,*],color=lcol[det]
			ENDFOR
			plot,iframe[*],L_r[b,0,0,1,*],xrange=[0,100],yrange=[-.2,.2],title=band_name[1], $
				ytit='L',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name3,/nodata
			FOR det=0, ndet_I-1 DO BEGIN
				oplot,iframe[*],L_r[b,0,det,1,*],color=lcol[det]
			ENDFOR
		ENDIF
		IF b NE 0 THEN BEGIN
			FOR det=0, ndet_M-1 DO BEGIN
				oplot,iframe[*],L_r[b,0,det,0,*],color=lcol[det]
			ENDFOR
		ENDIF
	ENDFOR
	title='UAID '+uaidname[uaid]+': L vs frame'
	XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5

	i=0
	FOR b=0, 4 DO BEGIN
		!p.multi=[0,4,4]
		!p.position=0

		IF b GT 0 THEN i=1
		IF b EQ 0 THEN BEGIN
			FOR det=0, ndet_I-1 DO BEGIN
				plot,iframe[*],L_r[b,0,0,0,*],xrange=[0,100],yrange=[-0.5,0.5], $
					title=band_name[b+i]+' det='+strtrim(string(det+1),1), $
					ytit='L',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name3,/nodata
				oplot,iframe[*],L_r[b,0,det,0,*],color=lcol[det]

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': L vs frame'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
			ENDFOR
			FOR det=0, ndet_I-1 DO BEGIN
				plot,iframe[*],L_r[b,0,0,1,*],xrange=[0,100],yrange=[-0.5,0.5], $
					title=band_name[1]+' det='+strtrim(string(det+1),1), $
					ytit='L',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name3,/nodata
				oplot,iframe[*],L_r[b,0,det,1,*],color=lcol[det]

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': L vs frame'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
			ENDFOR
		ENDIF
		IF b NE 0 THEN BEGIN
			FOR det=0, ndet_M-1 DO BEGIN
				plot,iframe[*],L_r[b,0,det,0,*],xrange=[0,100],yrange=[-0.5,0.5], $
					title=band_name[b+i]+' det='+strtrim(string(det+1),1), $
					ytit='L',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name3,/nodata
				oplot,iframe[*],L_r[b,0,det,0,*],color=lcol[det]
			ENDFOR
		ENDIF
		title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': L vs frame'
		XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
	ENDFOR
	
	k=1
	FOR det=0, ndet_M-1 DO BEGIN

		name=['I5 SS1, det '+strtrim(string(2*det+1),1),'I5 SS2, det '+strtrim(string(2*det+1),1), $
			'I5 SS1, det '+strtrim(string(2*det+2),1),'I5 SS2, det '+strtrim(string(2*det+2),1), $
			'M14, det '+strtrim(string(det+1),1),'M15, det '+strtrim(string(det+1),1), $
			'M16A, det '+strtrim(string(det+1),1),'M16B, det '+strtrim(string(det+1),1)]

		IF k EQ 1 THEN BEGIN 
			k=0
			goto,skip_kk
		ENDIF
		IF k EQ 0 THEN k=1
		skip_kk:

		;UAID 3102125
		IF uaid EQ 0 THEN BEGIN
			!p.multi=[0,1,1]
			!p.position=0

			FOR j=0, 1 DO BEGIN
				plot,iframe[0:99],L_r[0,0,0,0,0:99],xrange=[20,80],yrange=[-0.5+j*(-10),0.5+j*18],ytit='L', $
					xtit='frame',charsize=1.2,charthick=5,xtickname=t_name1,/nodata
				oplot,[53,53],[-2000,3000],linestyle=2,thick=3
				oplot,[47,47],[-2000,3000],linestyle=2,thick=3
				oplot,[41,41],[-2000,3000],linestyle=2,thick=3
				oplot,[35,35],[-2000,3000],linestyle=2,thick=3
				IF k EQ 0 THEN BEGIN
					oplot,[32,32],[-2000,3000],linestyle=2,thick=3
					oplot,[31,31],[-2000,3000],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,[29,29],[-2000,3000],linestyle=2,thick=3
					oplot,[28,28],[-2000,3000],linestyle=2,thick=3
				ENDIF

				IF k EQ 0 THEN BEGIN
					oplot,iframe[0:99],L_r[0,0,2*det,0,21:99],color=lcol[0],thick=3
					oplot,iframe[0:99],L_r[0,0,2*det,1,21:99],color=lcol[1],thick=3
					oplot,iframe[0:99],L_r[0,0,2*det+1,0,22:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[0:99],L_r[0,0,2*det+1,1,22:99],color=lcol[1],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,iframe[0:99],L_r[0,0,2*det,0,24:99],color=lcol[0],thick=3
					oplot,iframe[0:99],L_r[0,0,2*det,1,24:99],color=lcol[1],thick=3
					oplot,iframe[0:99],L_r[0,0,2*det+1,0,25:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[0:99],L_r[0,0,2*det+1,1,25:99],color=lcol[1],linestyle=2,thick=3
				ENDIF
				oplot,iframe[0:99],L_r[1,0,det,0,0:99],color=lcol[2],thick=3
				oplot,iframe[0:99],L_r[2,0,det,0,6:99],color=lcol[3],thick=3
				oplot,iframe[0:99],L_r[3,0,det,0,18:99],color=lcol[4],thick=3
				oplot,iframe[0:99],L_r[4,0,det,0,12:99],color=lcol[5],thick=3

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': L vs frame'
				subtitle='Detectors '+strtrim(string(det+1),1)+' (M), '+strtrim(string(2*det+1),1)+ $
					' and '+strtrim(string(2*det+2),1)+' (I)'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.5,0.975,subtitle,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.56,0.15,m14,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.475,0.15,m15,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.385,0.15,m16b,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.30,0.15,m16a,/normal,alignment=0.5,charsize=1,charthick=5
				IF k EQ 0 THEN BEGIN
					XYOUTS,0.265,0.18,i5e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.255,0.15,i5o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				IF k EQ 1 THEN BEGIN
					XYOUTS,0.225,0.15,i5e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.21,0.18,i5o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF

				legend,name,linestyle=[0,0,2,2,0,0,0,0],colors=[0,1,0,1,2,3,5,6], $
					thick=2,charthick=5,/right_legend
			ENDFOR
		ENDIF

		;UAID 3102154
		IF uaid EQ 1 THEN BEGIN
			!p.multi=[0,1,1]
			!p.position=0

			FOR j=0, 1 DO BEGIN
				plot,iframe[0:99],L_r[0,0,0,0,0:99],xrange=[20,80],yrange=[-0.5+j*(-10),0.5+j*18], $
					ytit='L',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name1,/nodata
				oplot,[71,71],[-2000,3000],linestyle=2,thick=3
				oplot,[65,65],[-2000,3000],linestyle=2,thick=3
				oplot,[59,59],[-2000,3000],linestyle=2,thick=3
				oplot,[53,53],[-2000,3000],linestyle=2,thick=3
				IF k EQ 0 THEN BEGIN
					oplot,[50,50],[-2000,3000],linestyle=2,thick=3
					oplot,[49,49],[-2000,3000],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,[47,47],[-2000,3000],linestyle=2,thick=3
					oplot,[46,46],[-2000,3000],linestyle=2,thick=3
				ENDIF

				IF k EQ 0 THEN BEGIN
					oplot,iframe[0:99],L_r[0,0,2*det,0,3:99],color=lcol[0],thick=3
					oplot,iframe[0:99],L_r[0,0,2*det,1,3:99],color=lcol[1],thick=3
					oplot,iframe[0:99],L_r[0,0,2*det+1,0,4:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[0:99],L_r[0,0,2*det+1,1,4:99],color=lcol[1],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,iframe[0:99],L_r[0,0,2*det,0,6:99],color=lcol[0],thick=3
					oplot,iframe[0:99],L_r[0,0,2*det,1,6:99],color=lcol[1],thick=3
					oplot,iframe[0:99],L_r[0,0,2*det+1,0,7:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[0:99],L_r[0,0,2*det+1,1,7:99],color=lcol[1],linestyle=2,thick=3
				ENDIF
				oplot,iframe[18:99],L_r[1,0,det,0,0:99],color=lcol[2],thick=3
				oplot,iframe[12:99],L_r[2,0,det,0,0:99],color=lcol[3],thick=3
				oplot,iframe[0:99],L_r[3,0,det,0,0:99],color=lcol[4],thick=3
				oplot,iframe[6:99],L_r[4,0,det,0,0:99],color=lcol[5],thick=3

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': L vs frame'
				subtitle='Detectors '+strtrim(string(det+1),1)+' (M), '+strtrim(string(2*det+1),1)+ $
					' and '+strtrim(string(2*det+2),1)+' (I)'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.5,0.975,subtitle,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.82,0.15,m14,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.735,0.15,m15,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.64,0.15,m16b,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.56,0.15,m16a,/normal,alignment=0.5,charsize=1,charthick=5
				IF k EQ 0 THEN BEGIN
					XYOUTS,0.525,0.18,i5e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.51,0.15,i5o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				IF k EQ 1 THEN BEGIN
					XYOUTS,0.48,0.15,i5e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.47,0.18,i5o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF

				legend,name,linestyle=[0,0,2,2,0,0,0,0],colors=[0,1,0,1,2,3,5,6],thick=2,charthick=5
			ENDFOR
		ENDIF

		;UAID 3102156
		IF uaid EQ 2 THEN BEGIN
			!p.multi=[0,1,1]
			!p.position=0

			FOR j=0, 1 DO BEGIN
				plot,iframe[0:99],L_r[0,0,0,0,0:99],xrange=[20,80],yrange=[-0.5+j*(-10),0.5+j*18], $
					ytit='L',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name1,/nodata
				oplot,[65,65],[-2000,3000],linestyle=2,thick=3
				oplot,[59,59],[-2000,3000],linestyle=2,thick=3
				oplot,[53,53],[-2000,3000],linestyle=2,thick=3
				oplot,[47,47],[-2000,3000],linestyle=2,thick=3
				IF k EQ 0 THEN BEGIN
					oplot,[44,44],[-2000,3000],linestyle=2,thick=3
					oplot,[43,43],[-2000,3000],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,[41,41],[-2000,3000],linestyle=2,thick=3
					oplot,[40,40],[-2000,3000],linestyle=2,thick=3
				ENDIF

				IF k EQ 0 THEN BEGIN
					oplot,iframe[0:99],L_r[0,0,2*det,0,9:99],color=lcol[0],thick=3
					oplot,iframe[0:99],L_r[0,0,2*det,1,9:99],color=lcol[1],thick=3
					oplot,iframe[0:99],L_r[0,0,2*det+1,0,10:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[0:99],L_r[0,0,2*det+1,1,10:99],color=lcol[1],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,iframe[0:99],L_r[0,0,2*det,0,12:99],color=lcol[0],thick=3
					oplot,iframe[0:99],L_r[0,0,2*det,1,12:99],color=lcol[1],thick=3
					oplot,iframe[0:99],L_r[0,0,2*det+1,0,13:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[0:99],L_r[0,0,2*det+1,1,13:99],color=lcol[1],linestyle=2,thick=3
				ENDIF
				oplot,iframe[12:99],L_r[1,0,det,0,0:99],color=lcol[2],thick=3
				oplot,iframe[6:99],L_r[2,0,det,0,0:99],color=lcol[3],thick=3
				oplot,iframe[0:99],L_r[3,0,det,0,6:99],color=lcol[4],thick=3
				oplot,iframe[0:99],L_r[4,0,det,0,0:99],color=lcol[5],thick=3

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': L vs frame'
				subtitle='Detectors '+strtrim(string(det+1),1)+' (M), '+strtrim(string(2*det+1),1)+ $
					' and '+strtrim(string(2*det+2),1)+' (I)'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.5,0.975,subtitle,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.735,0.15,m14,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.65,0.15,m15,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.555,0.15,m16b,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.475,0.15,m16a,/normal,alignment=0.5,charsize=1,charthick=5
				IF k EQ 0 THEN BEGIN
					XYOUTS,0.44,0.18,i5e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.43,0.15,i5o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				IF k EQ 1 THEN BEGIN
					XYOUTS,0.395,0.15,i5e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.385,0.18,i5o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF

				legend,name,linestyle=[0,0,2,2,0,0,0,0],colors=[0,1,0,1,2,3,5,6],thick=2,charthick=5
			ENDFOR
		ENDIF

		;UAID 3102158
		IF uaid EQ 3 THEN BEGIN
			!p.multi=[0,1,1]
			!p.position=0

			FOR j=0, 1 DO BEGIN
				plot,iframe[0:99],L_r[0,0,0,0,0:99],xrange=[20,100],yrange=[-0.5+j*(-10),0.5+j*18], $
					ytit='L',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name2,/nodata
				IF k EQ 0 THEN BEGIN
					oplot,[75,75],[-2000,3000],linestyle=2,thick=3
					oplot,[69,69],[-2000,3000],linestyle=2,thick=3
					oplot,[63,63],[-2000,3000],linestyle=2,thick=3
					oplot,[57,57],[-2000,3000],linestyle=2,thick=3
					oplot,[54,54],[-2000,3000],linestyle=2,thick=3
					oplot,[53,53],[-2000,3000],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,[78,78],[-2000,3000],linestyle=2,thick=3
					oplot,[72,72],[-2000,3000],linestyle=2,thick=3
					oplot,[66,66],[-2000,3000],linestyle=2,thick=3
					oplot,[60,60],[-2000,3000],linestyle=2,thick=3
					oplot,[54,54],[-2000,3000],linestyle=2,thick=3
					oplot,[53,53],[-2000,3000],linestyle=2,thick=3
				ENDIF

				IF k EQ 0 THEN BEGIN
					oplot,iframe[1:99],L_r[0,0,2*det,0,0:99],color=lcol[0],thick=3
					oplot,iframe[1:99],L_r[0,0,2*det,1,0:99],color=lcol[1],thick=3
					oplot,iframe[0:99],L_r[0,0,2*det+1,0,0:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[0:99],L_r[0,0,2*det+1,1,0:99],color=lcol[1],linestyle=2,thick=3
					oplot,iframe[22:99],L_r[1,0,det,0,0:99],color=lcol[2],thick=3
					oplot,iframe[16:99],L_r[2,0,det,0,0:99],color=lcol[3],thick=3
					oplot,iframe[4:99],L_r[3,0,det,0,0:99],color=lcol[4],thick=3
					oplot,iframe[10:99],L_r[4,0,det,0,0:99],color=lcol[5],thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,iframe[1:99],L_r[0,0,2*det,0,0:99],color=lcol[0],thick=3
					oplot,iframe[1:99],L_r[0,0,2*det,1,0:99],color=lcol[1],thick=3
					oplot,iframe[0:99],L_r[0,0,2*det+1,0,0:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[0:99],L_r[0,0,2*det+1,1,0:99],color=lcol[1],linestyle=2,thick=3
					oplot,iframe[25:99],L_r[1,0,det,0,0:99],color=lcol[2],thick=3
					oplot,iframe[19:99],L_r[2,0,det,0,0:99],color=lcol[3],thick=3
					oplot,iframe[7:99],L_r[3,0,det,0,0:99],color=lcol[4],thick=3
					oplot,iframe[13:99],L_r[4,0,det,0,0:99],color=lcol[5],thick=3
				ENDIF

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': L vs frame'
				subtitle='Detectors '+strtrim(string(det+1),1)+' (M), '+strtrim(string(2*det+1),1)+ $
					' and '+strtrim(string(2*det+2),1)+' (I)'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.5,0.975,subtitle,/normal,alignment=0.5,charsize=1.6,charthick=5
				IF k EQ 0 THEN BEGIN
					XYOUTS,0.68,0.15,m14,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.615,0.15,m15,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.545,0.15,m16b,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.485,0.15,m16a,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.46,0.18,i5e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.445,0.15,i5o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				IF k EQ 1 THEN BEGIN
					XYOUTS,0.71,0.15,m14,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.65,0.15,m15,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.58,0.15,m16b,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.52,0.15,m16a,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.46,0.15,i5e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.45,0.18,i5o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF

				legend,name,linestyle=[0,0,2,2,0,0,0,0],colors=[0,1,0,1,2,3,5,6],thick=2,charthick=5
			ENDFOR
		ENDIF

		;UAID 3102160
		IF uaid EQ 4 THEN BEGIN
			!p.multi=[0,1,1]
			!p.position=0

			FOR j=0, 1 DO BEGIN
				plot,iframe[0:99],L_r[0,0,0,0,0:99],xrange=[20,80],yrange=[-0.5+j*(-10),0.5+j*18], $
					ytit='L',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name1,/nodata
				oplot,[59,59],[-2000,3000],linestyle=2,thick=3
				oplot,[53,53],[-2000,3000],linestyle=2,thick=3
				oplot,[47,47],[-2000,3000],linestyle=2,thick=3
				oplot,[41,41],[-2000,3000],linestyle=2,thick=3
				IF k EQ 0 THEN BEGIN
					oplot,[38,38],[-2000,3000],linestyle=2,thick=3
					oplot,[37,37],[-2000,3000],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,[35,35],[-2000,3000],linestyle=2,thick=3
					oplot,[34,34],[-2000,3000],linestyle=2,thick=3
				ENDIF

				IF k EQ 0 THEN BEGIN
					oplot,iframe[0:99],L_r[0,0,2*det,0,15:99],color=lcol[0],thick=3
					oplot,iframe[0:99],L_r[0,0,2*det,1,15:99],color=lcol[1],thick=3
					oplot,iframe[0:99],L_r[0,0,2*det+1,0,16:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[0:99],L_r[0,0,2*det+1,1,16:99],color=lcol[1],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,iframe[0:99],L_r[0,0,2*det,0,18:99],color=lcol[0],thick=3
					oplot,iframe[0:99],L_r[0,0,2*det,1,18:99],color=lcol[1],thick=3
					oplot,iframe[0:99],L_r[0,0,2*det+1,0,19:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[0:99],L_r[0,0,2*det+1,1,19:99],color=lcol[1],linestyle=2,thick=3
				ENDIF
				oplot,iframe[6:99],L_r[1,0,det,0,0:99],color=lcol[2],thick=3
				oplot,iframe[0:99],L_r[2,0,det,0,0:99],color=lcol[3],thick=3
				oplot,iframe[0:99],L_r[3,0,det,0,12:99],color=lcol[4],thick=3
				oplot,iframe[0:99],L_r[4,0,det,0,6:99],color=lcol[5],thick=3

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': L vs frame'
				subtitle='Detectors '+strtrim(string(det+1),1)+' (M), '+strtrim(string(2*det+1),1)+ $
					' and '+strtrim(string(2*det+2),1)+' (I)'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.5,0.975,subtitle,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.65,0.15,m14,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.56,0.15,m15,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.47,0.15,m16b,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.39,0.15,m16a,/normal,alignment=0.5,charsize=1,charthick=5
				IF k EQ 0 THEN BEGIN
					XYOUTS,0.35,0.18,i5e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.34,0.15,i5o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				IF k EQ 1 THEN BEGIN
					XYOUTS,0.31,0.15,i5e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.30,0.18,i5o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF

				legend,name,linestyle=[0,0,2,2,0,0,0,0],colors=[0,1,0,1,2,3,5,6], $
					thick=2,charthick=5,/right_legend
			ENDFOR
		ENDIF
	ENDFOR
	!p.multi=[0,3,2]
	!p.position=0

	i=0
	FOR b=0, 4 DO BEGIN
		IF b GT 0 THEN i=1
		plot,iframe[*],d_dn_r[b,0,0,0,*],xrange=[0,100],yrange=[-20,20],title=band_name[b+i], $
			ytit='d(dn)/d(frame)',xtit='frame',charsize=1.2,charthick=5,/nodata
		IF b EQ 0 THEN BEGIN
			FOR det=0, ndet_I-1 DO BEGIN
				oplot,iframe[*],d_dn_r[b,0,det,0,*],color=lcol[det]
			ENDFOR
			plot,iframe[*],d_dn_r[b,0,0,1,*],xrange=[0,100],yrange=[-20,20],title=band_name[1], $
				ytit='d(dn)/d(frame)',xtit='frame',charsize=1.2,charthick=5,/nodata
			FOR det=0, ndet_I-1 DO BEGIN
				oplot,iframe[*],d_dn_r[b,0,det,1,*],color=lcol[det]
			ENDFOR
		ENDIF
		IF b NE 0 THEN BEGIN
			FOR det=0, ndet_M-1 DO BEGIN
				oplot,iframe[*],d_dn_r[b,0,det,0,*],color=lcol[det]
			ENDFOR
		ENDIF
	ENDFOR
	title='UAID '+uaidname[uaid]+': d(dn)/d(frame) vs frame'
	XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5

	i=0
	FOR b=0, 4 DO BEGIN
		!p.multi=[0,4,4]
		!p.position=0

		IF b GT 0 THEN i=1
		IF b EQ 0 THEN BEGIN
			FOR det=0, ndet_I-1 DO BEGIN
				plot,iframe[*],d_dn_r[b,0,0,0,*],xrange=[0,100],yrange=[-20,20], $
					title=band_name[b+i]+' det='+strtrim(string(det+1),1), $
					ytit='d(dn)/d(frame)',xtit='frame',charsize=1.2,charthick=5,/nodata
				oplot,iframe[*],d_dn_r[b,0,det,0,*],color=lcol[det]

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': d(dn)/d(frame) vs frame'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
			ENDFOR
			FOR det=0, ndet_I-1 DO BEGIN
				plot,iframe[*],d_dn_r[b,0,0,1,*],xrange=[0,100],yrange=[-20,20], $
					title=band_name[1]+' det='+strtrim(string(det+1),1), $
					ytit='d(dn)/d(frame)',xtit='frame',charsize=1.2,charthick=5,/nodata
				oplot,iframe[*],d_dn_r[b,0,det,1,*],color=lcol[det]

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': d(dn)/d(frame) vs frame'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
			ENDFOR
		ENDIF
		IF b NE 0 THEN BEGIN
			FOR det=0, ndet_M-1 DO BEGIN
				plot,iframe[*],d_dn_r[b,0,det,0,*],xrange=[0,100],yrange=[-20,20], $
					title=band_name[b+i]+' det='+strtrim(string(det+1),1), $
					ytit='d(dn)/d(frame)',xtit='frame',charsize=1.2,charthick=5,/nodata
				oplot,iframe[*],d_dn_r[b,0,det,0,*],color=lcol[det]
			ENDFOR
		ENDIF
		title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': d(dn)/d(frame) vs frame'
		XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
	ENDFOR
	!p.multi=[0,3,2]
	!p.position=0

	i=0
	FOR b=0, 4 DO BEGIN
		IF b GT 0 THEN i=1
		plot,iframe[*],d_L_r[b,0,0,0,*],xrange=[0,100],yrange=[-.2,.2],title=band_name[b+i], $
			ytit='d(L)/d(frame)',xtit='frame',charsize=1.2,charthick=5,/nodata
		IF b EQ 0 THEN BEGIN
			FOR det=0, ndet_I-1 DO BEGIN
				oplot,iframe[*],d_L_r[b,0,det,0,*],color=lcol[det]
			ENDFOR
			plot,iframe[*],d_L_r[b,0,0,1,*],xrange=[0,100],yrange=[-.2,.2],title=band_name[1], $
				ytit='d(L)/d(frame)',xtit='frame',charsize=1.2,charthick=5,/nodata
			FOR det=0, ndet_I-1 DO BEGIN
				oplot,iframe[*],d_L_r[b,0,det,1,*],color=lcol[det]
			ENDFOR
		ENDIF
		IF b NE 0 THEN BEGIN
			FOR det=0, ndet_M-1 DO BEGIN
				oplot,iframe[*],d_L_r[b,0,det,0,*],color=lcol[det]
			ENDFOR
		ENDIF
	ENDFOR
	title='UAID '+uaidname[uaid]+': d(L)/d(frame) vs frame'
	XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5

	i=0
	FOR b=0, 4 DO BEGIN
		!p.multi=[0,4,4]
		!p.position=0

		IF b GT 0 THEN i=1
		IF b EQ 0 THEN BEGIN
			FOR det=0, ndet_I-1 DO BEGIN
				plot,iframe[*],d_L_r[b,0,0,0,*],xrange=[0,100],yrange=[-0.2,0.2], $
					title=band_name[b+i]+' det='+strtrim(string(det+1),1), $
					ytit='d(L)/d(frame)',xtit='frame',charsize=1.2,charthick=5,/nodata
				oplot,iframe[*],d_L_r[b,0,det,0,*],color=lcol[det]

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': d(L)/d(frame) vs frame'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
			ENDFOR
			FOR det=0, ndet_I-1 DO BEGIN
				plot,iframe[*],d_L_r[b,0,0,1,*],xrange=[0,100],yrange=[-0.2,0.2], $
					title=band_name[1]+' det='+strtrim(string(det+1),1), $
					ytit='d(L)/d(frame)',xtit='frame',charsize=1.2,charthick=5,/nodata
				oplot,iframe[*],d_L_r[b,0,det,1,*],color=lcol[det]

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': d(L)/d(frame) vs frame'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
			ENDFOR
		ENDIF
		IF b NE 0 THEN BEGIN
			FOR det=0, ndet_M-1 DO BEGIN
				plot,iframe[*],d_L_r[b,0,det,0,*],xrange=[0,100],yrange=[-0.2,0.2], $
					title=band_name[b+i]+' det='+strtrim(string(det+1),1), $
					ytit='d(L)/d(frame)',xtit='frame',charsize=1.2,charthick=5,/nodata
				oplot,iframe[*],d_L_r[b,0,det,0,*],color=lcol[det]
			ENDFOR
		ENDIF
		title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': d(L)/d(frame) vs frame'
		XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
	ENDFOR
	!p.multi=[0,3,2]
	!p.position=0

	skip_loop:
ENDFOR

device,/close

!p.multi=0
!p.position=0

END
