;*****************************************************************************
;  FP-13 Dynamic vertical slit LWIR Xtalk test. This is version 2 which graphs
;  the dn and radiance per frame per band. in addition, de-registered graphs
;  are created for both dn and radiance. The first derivative is also plotted
;  in dn and radiance space. 
;  
;  v1.0 - 02/21/2008 - Jeff McIntire
;*****************************************************************************

PRO view_sf_dyn_SMWIR_2

close,/all

band_name=['I3 SS1','I3 SS2','I4 SS1','I4 SS2','M10','M11','M12','M13','M8','M9']
nband=n_elements(band_name)
nham=2
ndet=32
nsub=2
nframe=100
ndet_I=32
ndet_M=16
det_I=findgen(ndet_I)
det_M=findgen(ndet_M)
iframe=findgen(2*nframe)

t_name1=['970','990','1010','1030','1050','1070']
t_name2=['990','1010','1030','1050','1070']
t_name3=['970','990','1010','1030','1050']

uaidname=['3102099','3102103','3102105','3102117','3102121','3102149','3102162','3102166','3102167']
bandname=['M8','M10','I3','M9','M12','I4','M13','M13','M13']
n_uaid=N_ELEMENTS(uaidname)

m8='M8'
m9='M9'
m10='M10'
m11='M11'
m12='M12'
m13='M13'
i3_o='I3o'
i3_e='I3e'
i4_o='I4o'
i4_e='I4e'

FOR uaid=0, n_uaid-1 DO BEGIN
	set_multicolor,xsave,ysave,psave,chname,lcol,symbol,red,green,blue
	set_plot,'ps'
	outfname='/home/jmcintire/VIIRS_Data/FP_13_Data/SMWIR/Dynamic/U'+uaidname[uaid]+'.2.ps'
	device,/landscape,filename=outfname,/color
	!p.multi=[0,3,2]

	infname1='/home/jmcintire/VIIRS_Data/FP_13_Data/SMWIR/Dynamic/U'+uaidname[uaid]+'.sav'
	check=FILE_SEARCH(infname1)
	IF check EQ '' THEN BEGIN
		print,'No file is found.',infname1
		goto,skip_loop
	ENDIF
	print,'Processing file:',infname1
	restore,infname1

	dn_r=fltarr(nband,nham,ndet,nsub,nframe)
	dn_lg=fltarr(nband,nham,ndet,nsub,nframe)
	L_r=fltarr(nband,nham,ndet,nsub,nframe)
	L_lg=fltarr(nband,nham,ndet,nsub,nframe)
	d_dn_r=fltarr(nband,nham,ndet,nsub,nframe)
	d_dn_lg=fltarr(nband,nham,ndet,nsub,nframe)
	d_L_r=fltarr(nband,nham,ndet,nsub,nframe)
	d_L_lg=fltarr(nband,nham,ndet,nsub,nframe)
	FOR b=0, 7 DO BEGIN
		IF b LE 3 OR b GT 5 THEN BEGIN
			dn_r[b,*,*,*,*]=(dn[0,b,*,*,*,*]+dn[1,b,*,*,*,*])/2
			L_r[b,*,*,*,*]=(L[0,b,*,*,*,*]+L[1,b,*,*,*,*])/2
			d_dn_r[b,*,*,*,*]=(d_dn[0,b,*,*,*,*]+d_dn[1,b,*,*,*,*])/2
			d_L_r[b,*,*,*,*]=(d_L[0,b,*,*,*,*]+d_L[1,b,*,*,*,*])/2
		ENDIF
		IF b EQ 4 OR b EQ 5 THEN BEGIN
			dn_r[b,*,*,*,*]=dn[0,b,*,*,*,*]
			L_r[b,*,*,*,*]=L[0,b,*,*,*,*]
			d_dn_r[b,*,*,*,*]=d_dn[0,b,*,*,*,*]
			d_L_r[b,*,*,*,*]=d_L[0,b,*,*,*,*]

			IF uaid EQ 7 THEN BEGIN
				dn_r[b,*,*,*,*]=dn[1,b,*,*,*,*]
				L_r[b,*,*,*,*]=L[1,b,*,*,*,*]
				d_dn_r[b,*,*,*,*]=d_dn[1,b,*,*,*,*]
				d_L_r[b,*,*,*,*]=d_L[1,b,*,*,*,*]
			ENDIF
		ENDIF
		IF uaid EQ 7 OR uaid EQ 8 THEN BEGIN
			dn_lg[b,*,*,*,*]=dn[2,b,*,*,*,*]
			L_lg[b,*,*,*,*]=L[2,b,*,*,*,*]
			d_dn_lg[b,*,*,*,*]=d_dn[2,b,*,*,*,*]
			d_L_lg[b,*,*,*,*]=d_L[2,b,*,*,*,*]
		ENDIF
	ENDFOR

	i=0
	FOR b=0, 7 DO BEGIN
		IF b EQ 1 THEN i=2
		IF b LE 1 THEN BEGIN
			plot,iframe[*],dn_r[b,0,0,0,*],xrange=[0,100],yrange=[-20,20],title=band_name[0+i], $
				ytit='dn',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name1,/nodata
			FOR det=0, ndet_I-1 DO BEGIN
				oplot,iframe[*],dn_r[b,0,det,0,*],color=lcol[det]
			ENDFOR
			plot,iframe[*],dn_r[b,0,0,1,*],xrange=[0,100],yrange=[-20,20],title=band_name[1+i], $
				ytit='dn',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name1,/nodata
			FOR det=0, ndet_I-1 DO BEGIN
				oplot,iframe[*],dn_r[b,0,det,1,*],color=lcol[det]
			ENDFOR
		ENDIF
		IF b GT 1 THEN BEGIN
			plot,iframe[*],dn_r[b,0,0,0,*],xrange=[0,100],yrange=[-20,20],title=band_name[b+2], $
				ytit='dn',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name1,/nodata
			FOR det=0, ndet_M-1 DO BEGIN
				oplot,iframe[*],dn_r[b,0,det,0,*],color=lcol[det]
			ENDFOR
		ENDIF
		title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': DN vs frame'
		XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
	ENDFOR

	i=0
	FOR b=0, 7 DO BEGIN
		!p.multi=[0,4,4]
		!p.position=0

		IF b GT 0 THEN i=1
		IF b LE 1 THEN BEGIN
			FOR det=0, ndet_I-1 DO BEGIN
				plot,iframe[*],dn_r[b,0,0,0,*],xrange=[0,100],yrange=[-20,20], $
					title=band_name[b+i]+' det='+strtrim(string(det+1),1), $
					ytit='dn',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name1,/nodata
				oplot,iframe[*],dn_r[b,0,det,0,*],color=lcol[det]

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': DN vs frame'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
			ENDFOR
			FOR det=0, ndet_I-1 DO BEGIN
				plot,iframe[*],dn_r[b,0,0,1,*],xrange=[0,100],yrange=[-20,20], $
					title=band_name[b+i+1]+' det='+strtrim(string(det+1),1), $
					ytit='dn',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name1,/nodata
				oplot,iframe[*],dn_r[b,0,det,1,*],color=lcol[det]

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': DN vs frame'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
			ENDFOR
		ENDIF
		IF b GT 1 THEN BEGIN
			FOR det=0, ndet_M-1 DO BEGIN
				plot,iframe[*],dn_r[b,0,det,0,*],xrange=[0,100],yrange=[-20,20], $
					title=band_name[b+2]+' det='+strtrim(string(det+1),1), $
					ytit='dn',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name1,/nodata
				oplot,iframe[*],dn_r[b,0,det,0,*],color=lcol[det]
			ENDFOR
		ENDIF
		title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': DN vs frame'
		XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
	ENDFOR

	IF uaid GE 7 THEN BEGIN
		!p.multi=[0,3,2]
		!p.position=0

		i=0
		FOR b=0, 7 DO BEGIN
			IF b EQ 1 THEN i=2
			IF b LE 1 THEN BEGIN
				plot,iframe[*],dn_lg[b,0,0,0,*],xrange=[0,100],yrange=[-20,20],title=band_name[0+i], $
					ytit='dn',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name1,/nodata
				FOR det=0, ndet_I-1 DO BEGIN
					oplot,iframe[*],dn_lg[b,0,det,0,*],color=lcol[det]
				ENDFOR
				plot,iframe[*],dn_lg[b,0,0,1,*],xrange=[0,100],yrange=[-20,20],title=band_name[1+i], $
					ytit='dn',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name1,/nodata
				FOR det=0, ndet_I-1 DO BEGIN
					oplot,iframe[*],dn_lg[b,0,det,1,*],color=lcol[det]
				ENDFOR
			ENDIF
			IF b GT 1 THEN BEGIN
				plot,iframe[*],dn_lg[b,0,0,0,*],xrange=[0,100],yrange=[-20,20],title=band_name[b+2], $
					ytit='dn',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name1,/nodata
				FOR det=0, ndet_M-1 DO BEGIN
					oplot,iframe[*],dn_lg[b,0,det,0,*],color=lcol[det]
				ENDFOR
			ENDIF
			title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+' Fixed Low Gain: DN vs frame'
			XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
		ENDFOR

		i=0
		FOR b=0, 7 DO BEGIN
			!p.multi=[0,4,4]
			!p.position=0

			IF b GT 0 THEN i=1
			IF b LE 1 THEN BEGIN
				FOR det=0, ndet_I-1 DO BEGIN
					plot,iframe[*],dn_lg[b,0,0,0,*],xrange=[0,100],yrange=[-20,20], $
						title=band_name[b+i]+' det='+strtrim(string(det+1),1), $
						ytit='dn',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name1,/nodata
					oplot,iframe[*],dn_lg[b,0,det,0,*],color=lcol[det]

					title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+' Fixed Low Gain: DN vs frame'
					XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
				ENDFOR
				FOR det=0, ndet_I-1 DO BEGIN
					plot,iframe[*],dn_lg[b,0,0,1,*],xrange=[0,100],yrange=[-20,20], $
						title=band_name[b+i+1]+' det='+strtrim(string(det+1),1), $
						ytit='dn',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name1,/nodata
					oplot,iframe[*],dn_lg[b,0,det,1,*],color=lcol[det]

					title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+' Fixed Low Gain: DN vs frame'
					XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
				ENDFOR
			ENDIF
			IF b GT 1 THEN BEGIN
				FOR det=0, ndet_M-1 DO BEGIN
					plot,iframe[*],dn_lg[b,0,det,0,*],xrange=[0,100],yrange=[-20,20], $
						title=band_name[b+2]+' det='+strtrim(string(det+1),1), $
						ytit='dn',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name1,/nodata
					oplot,iframe[*],dn_lg[b,0,det,0,*],color=lcol[det]
				ENDFOR
			ENDIF
			title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+' Fixed Low Gain: DN vs frame'
			XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
		ENDFOR
	ENDIF

	k=1
	FOR det=0, ndet_M-1 DO BEGIN

		IF k EQ 1 THEN BEGIN 
			k=0
			goto,skip_k
		ENDIF
		IF k EQ 0 THEN k=1
		skip_k:

		name=['I3 SS1, det '+strtrim(string(2*det+1),1),'I3 SS2, det '+strtrim(string(2*det+1),1), $
			'I3 SS1, det '+strtrim(string(2*det+2),1),'I3 SS2, det '+strtrim(string(2*det+2),1), $
			'I4 SS1, det '+strtrim(string(2*det+1),1),'I4 SS2, det '+strtrim(string(2*det+1),1), $
			'I4 SS1, det '+strtrim(string(2*det+2),1),'I4 SS2, det '+strtrim(string(2*det+2),1), $
			'M10, det '+strtrim(string(det+1),1),'M11, det '+strtrim(string(det+1),1), $
			'M12, det '+strtrim(string(det+1),1),'M13, det '+strtrim(string(det+1),1), $
			'M8, det '+strtrim(string(det+1),1),'M9, det '+strtrim(string(det+1),1)]

		;UAID 3102099
		IF uaid EQ 0 THEN BEGIN
			!p.multi=[0,1,1]
			!p.position=0

			FOR j=0, 1 DO BEGIN
				plot,iframe[0:99],dn_r[0,0,0,0,0:99],xrange=[0,100],yrange=[-20,20+j*2500],ytit='dn', $
					xtit='frame',charsize=1.2,charthick=5,xtickname=t_name1,/nodata
				oplot,[59,59],[-2000,3000],linestyle=2,thick=3
				oplot,[53,53],[-2000,3000],linestyle=2,thick=3
				oplot,[47,47],[-2000,3000],linestyle=2,thick=3
				oplot,[41,41],[-2000,3000],linestyle=2,thick=3
				IF k EQ 0 THEN BEGIN
					oplot,[39,39],[-2000,3000],linestyle=2,thick=3
					oplot,[37,37],[-2000,3000],linestyle=2,thick=3
					oplot,[34,34],[-2000,3000],linestyle=2,thick=3
					oplot,[33,33],[-2000,3000],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,[36,36],[-2000,3000],linestyle=2,thick=3
					oplot,[34,34],[-2000,3000],linestyle=2,thick=3
					oplot,[31,31],[-2000,3000],linestyle=2,thick=3
					oplot,[30,30],[-2000,3000],linestyle=2,thick=3
				ENDIF
				oplot,[27,27],[-2000,3000],linestyle=2,thick=3
				oplot,[21,21],[-2000,3000],linestyle=2,thick=3

				IF k EQ 0 THEN BEGIN
					oplot,iframe[0:99],dn_r[0,0,2*det,0,14:99],color=lcol[0],thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det,1,14:99],color=lcol[1],thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det+1,0,16:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det+1,1,16:99],color=lcol[1],linestyle=2,thick=3
					oplot,iframe[0:99],dn_r[1,0,2*det,0,19:99],color=lcol[2],thick=3
					oplot,iframe[0:99],dn_r[1,0,2*det,1,19:99],color=lcol[3],thick=3
					oplot,iframe[0:99],dn_r[1,0,2*det+1,0,20:99],color=lcol[2],linestyle=2,thick=3
					oplot,iframe[0:99],dn_r[1,0,2*det+1,1,20:99],color=lcol[3],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,iframe[0:99],dn_r[0,0,2*det,0,17:99],color=lcol[0],thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det,1,17:99],color=lcol[1],thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det+1,0,19:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det+1,1,19:99],color=lcol[1],linestyle=2,thick=3
					oplot,iframe[0:99],dn_r[1,0,2*det,0,22:99],color=lcol[2],thick=3
					oplot,iframe[0:99],dn_r[1,0,2*det,1,22:99],color=lcol[3],thick=3
					oplot,iframe[0:99],dn_r[1,0,2*det+1,0,23:99],color=lcol[2],linestyle=2,thick=3
					oplot,iframe[0:99],dn_r[1,0,2*det+1,1,23:99],color=lcol[3],linestyle=2,thick=3
				ENDIF
				oplot,iframe[0:99],dn_r[2,0,det,0,6:99],color=4,thick=3
				oplot,iframe[0:99],dn_r[3,0,det,0,12:99],color=4,linestyle=2,thick=3
				oplot,iframe[0:99],dn_r[4,0,det,0,26:99],color=5,thick=3
				oplot,iframe[0:99],dn_r[5,0,det,0,32:99],color=5,linestyle=2,thick=3
				oplot,iframe[0:99],dn_r[6,0,det,0,0:99],color=6,thick=3
				oplot,iframe[6:99],dn_r[7,0,det,0,0:99],color=6,linestyle=2,thick=3

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': DN vs frame'
				subtitle='Detectors '+strtrim(string(det+1),1)+' (M), '+strtrim(string(2*det+1),1)+ $
					' and '+strtrim(string(2*det+2),1)+' (I)'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.5,0.975,subtitle,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.60,0.15,m9,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.55,0.15,m8,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.495,0.15,m11,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.445,0.15,m10,/normal,alignment=0.5,charsize=1,charthick=5
				IF k EQ 0 THEN BEGIN
					XYOUTS,0.43,0.18,i3_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.415,0.15,i3_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.39,0.18,i4_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.38,0.15,i4_o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				IF k EQ 1 THEN BEGIN
					XYOUTS,0.405,0.15,i3_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.39,0.18,i3_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.365,0.15,i4_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.355,0.18,i4_o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				XYOUTS,0.325,0.15,m12,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.27,0.15,m13,/normal,alignment=0.5,charsize=1,charthick=5

				legend,name,linestyle=[0,0,2,2,0,0,2,2,0,2,0,2,0,2], $
					colors=[0,1,0,1,2,3,2,3,4,4,5,5,6,6],thick=2,charthick=5,/right_legend
			ENDFOR
		ENDIF

		;UAID 3102103
		IF uaid EQ 1 THEN BEGIN
			!p.multi=[0,1,1]
			!p.position=0

			FOR j=0, 1 DO BEGIN
				plot,iframe[0:99],dn_r[0,0,0,0,0:99],xrange=[20,100],yrange=[-20,20+j*2500], $
					ytit='dn',xtit='frame',charsize=1.2,xtickname=t_name2,charthick=5,/nodata
				oplot,[71,71],[-2000,3000],linestyle=2,thick=3
				oplot,[65,65],[-2000,3000],linestyle=2,thick=3
				oplot,[59,59],[-2000,3000],linestyle=2,thick=3
				oplot,[53,53],[-2000,3000],linestyle=2,thick=3
				IF k EQ 0 THEN BEGIN
					oplot,[51,51],[-2000,3000],linestyle=2,thick=3
					oplot,[49,49],[-2000,3000],linestyle=2,thick=3
					oplot,[46,46],[-2000,3000],linestyle=2,thick=3
					oplot,[45,45],[-2000,3000],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,[48,48],[-2000,3000],linestyle=2,thick=3
					oplot,[46,46],[-2000,3000],linestyle=2,thick=3
					oplot,[43,43],[-2000,3000],linestyle=2,thick=3
					oplot,[42,42],[-2000,3000],linestyle=2,thick=3
				ENDIF
				oplot,[39,39],[-2000,3000],linestyle=2,thick=3
				oplot,[33,33],[-2000,3000],linestyle=2,thick=3

				IF k EQ 0 THEN BEGIN
					oplot,iframe[0:99],dn_r[0,0,2*det,0,2:99],color=lcol[0],thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det,1,2:99],color=lcol[1],thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det+1,0,4:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det+1,1,4:99],color=lcol[1],linestyle=2,thick=3
					oplot,iframe[0:99],dn_r[1,0,2*det,0,7:99],color=lcol[2],thick=3
					oplot,iframe[0:99],dn_r[1,0,2*det,1,7:99],color=lcol[3],thick=3
					oplot,iframe[0:99],dn_r[1,0,2*det+1,0,8:99],color=lcol[2],linestyle=2,thick=3
					oplot,iframe[0:99],dn_r[1,0,2*det+1,1,8:99],color=lcol[3],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,iframe[0:99],dn_r[0,0,2*det,0,5:99],color=lcol[0],thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det,1,5:99],color=lcol[1],thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det+1,0,7:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det+1,1,7:99],color=lcol[1],linestyle=2,thick=3
					oplot,iframe[0:99],dn_r[1,0,2*det,0,10:99],color=lcol[2],thick=3
					oplot,iframe[0:99],dn_r[1,0,2*det,1,10:99],color=lcol[3],thick=3
					oplot,iframe[0:99],dn_r[1,0,2*det+1,0,11:99],color=lcol[2],linestyle=2,thick=3
					oplot,iframe[0:99],dn_r[1,0,2*det+1,1,11:99],color=lcol[3],linestyle=2,thick=3
				ENDIF
				oplot,iframe[0:99],dn_r[2,0,det,0,0:99],color=4,thick=3
				oplot,iframe[6:99],dn_r[3,0,det,0,0:99],color=4,linestyle=2,thick=3
				oplot,iframe[0:99],dn_r[4,0,det,0,14:99],color=5,thick=3
				oplot,iframe[0:99],dn_r[5,0,det,0,20:99],color=5,linestyle=2,thick=3
				oplot,iframe[12:99],dn_r[6,0,det,0,0:99],color=6,thick=3
				oplot,iframe[18:99],dn_r[7,0,det,0,0:99],color=6,linestyle=2,thick=3

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': dn vs frame'
				subtitle='Detectors '+strtrim(string(det+1),1)+' (M), '+strtrim(string(2*det+1),1)+ $
					' and '+strtrim(string(2*det+2),1)+' (I)'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.5,0.975,subtitle,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.645,0.15,m9,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.58,0.15,m8,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.51,0.15,m11,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.445,0.15,m10,/normal,alignment=0.5,charsize=1,charthick=5
				IF k EQ 0 THEN BEGIN
					XYOUTS,0.425,0.18,i3_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.41,0.15,i3_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.38,0.18,i4_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.365,0.15,i4_o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				IF k EQ 1 THEN BEGIN
					XYOUTS,0.40,0.15,i3_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.38,0.18,i3_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.34,0.15,i4_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.33,0.18,i4_o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				XYOUTS,0.29,0.15,m12,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.23,0.15,m13,/normal,alignment=0.5,charsize=1,charthick=5

				legend,name,linestyle=[0,0,2,2,0,0,2,2,0,2,0,2,0,2], $
					colors=[0,1,0,1,2,3,2,3,4,4,5,5,6,6],thick=2,charthick=5,/right_legend
			ENDFOR
		ENDIF

		;UAID 3102105
		IF uaid EQ 2 THEN BEGIN
			!p.multi=[0,1,1]
			!p.position=0

			FOR j=0, 1 DO BEGIN
				plot,iframe[0:99],dn_r[0,0,0,0,0:99],xrange=[0,80],yrange=[-20,20+j*2000], $
					ytit='dn',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name3,/nodata
				IF k EQ 0 THEN BEGIN
					oplot,[75,75],[-2000,3000],linestyle=2,thick=3
					oplot,[69,69],[-2000,3000],linestyle=2,thick=3
					oplot,[63,63],[-2000,3000],linestyle=2,thick=3
					oplot,[57,57],[-2000,3000],linestyle=2,thick=3
					oplot,[55,55],[-2000,3000],linestyle=2,thick=3
					oplot,[53,53],[-2000,3000],linestyle=2,thick=3
					oplot,[50,50],[-2000,3000],linestyle=2,thick=3
					oplot,[49,49],[-2000,3000],linestyle=2,thick=3
					oplot,[43,43],[-2000,3000],linestyle=2,thick=3
					oplot,[37,37],[-2000,3000],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,[78,78],[-2000,3000],linestyle=2,thick=3
					oplot,[72,72],[-2000,3000],linestyle=2,thick=3
					oplot,[66,66],[-2000,3000],linestyle=2,thick=3
					oplot,[60,60],[-2000,3000],linestyle=2,thick=3
					oplot,[55,55],[-2000,3000],linestyle=2,thick=3
					oplot,[53,53],[-2000,3000],linestyle=2,thick=3
					oplot,[50,50],[-2000,3000],linestyle=2,thick=3
					oplot,[49,49],[-2000,3000],linestyle=2,thick=3
					oplot,[46,46],[-2000,3000],linestyle=2,thick=3
					oplot,[40,40],[-2000,3000],linestyle=2,thick=3
				ENDIF

				IF k EQ 0 THEN BEGIN
					oplot,iframe[2:99],dn_r[0,0,2*det,0,0:99],color=lcol[0],thick=3
					oplot,iframe[2:99],dn_r[0,0,2*det,1,0:99],color=lcol[1],thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det+1,0,0:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det+1,1,0:99],color=lcol[1],linestyle=2,thick=3
					oplot,iframe[0:99],dn_r[1,0,2*det,0,3:99],color=lcol[2],thick=3
					oplot,iframe[0:99],dn_r[1,0,2*det,1,3:99],color=lcol[3],thick=3
					oplot,iframe[0:99],dn_r[1,0,2*det+1,0,4:99],color=lcol[2],linestyle=2,thick=3
					oplot,iframe[0:99],dn_r[1,0,2*det+1,1,4:99],color=lcol[3],linestyle=2,thick=3
					oplot,iframe[4:99],dn_r[2,0,det,0,0:99],color=4,thick=3
					oplot,iframe[10:99],dn_r[3,0,det,0,0:99],color=4,linestyle=2,thick=3
					oplot,iframe[0:99],dn_r[4,0,det,0,10:99],color=5,thick=3
					oplot,iframe[0:99],dn_r[5,0,det,0,16:99],color=5,linestyle=2,thick=3
					oplot,iframe[16:99],dn_r[6,0,det,0,0:99],color=6,thick=3
					oplot,iframe[24:99],dn_r[7,0,det,0,0:99],color=6,linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,iframe[2:99],dn_r[0,0,2*det,0,0:99],color=lcol[0],thick=3
					oplot,iframe[2:99],dn_r[0,0,2*det,1,0:99],color=lcol[1],thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det+1,0,0:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det+1,1,0:99],color=lcol[1],linestyle=2,thick=3
					oplot,iframe[0:99],dn_r[1,0,2*det,0,3:99],color=lcol[2],thick=3
					oplot,iframe[0:99],dn_r[1,0,2*det,1,3:99],color=lcol[3],thick=3
					oplot,iframe[0:99],dn_r[1,0,2*det+1,0,4:99],color=lcol[2],linestyle=2,thick=3
					oplot,iframe[0:99],dn_r[1,0,2*det+1,1,4:99],color=lcol[3],linestyle=2,thick=3
					oplot,iframe[7:99],dn_r[2,0,det,0,0:99],color=4,thick=3
					oplot,iframe[13:99],dn_r[3,0,det,0,0:99],color=4,linestyle=2,thick=3
					oplot,iframe[0:99],dn_r[4,0,det,0,7:99],color=5,thick=3
					oplot,iframe[0:99],dn_r[5,0,det,0,13:99],color=5,linestyle=2,thick=3
					oplot,iframe[19:99],dn_r[6,0,det,0,0:99],color=6,thick=3
					oplot,iframe[25:99],dn_r[7,0,det,0,0:99],color=6,linestyle=2,thick=3
				ENDIF

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': DN vs frame'
				subtitle='Detectors '+strtrim(string(det+1),1)+' (M), '+strtrim(string(2*det+1),1)+ $
					' and '+strtrim(string(2*det+2),1)+' (I)'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.5,0.975,subtitle,/normal,alignment=0.5,charsize=1.6,charthick=5
				IF k EQ 0 THEN BEGIN
					XYOUTS,0.90,0.15,m9,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.835,0.15,m8,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.77,0.15,m11,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.705,0.15,m10,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.685,0.18,i3_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.665,0.15,i3_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.635,0.18,i4_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.625,0.15,i4_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.55,0.15,m12,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.485,0.15,m13,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				IF k EQ 1 THEN BEGIN
					XYOUTS,0.93,0.15,m9,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.865,0.15,m8,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.80,0.15,m11,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.735,0.15,m10,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.685,0.18,i3_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.665,0.15,i3_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.635,0.18,i4_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.625,0.15,i4_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.58,0.15,m12,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.515,0.15,m13,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF

				legend,name,linestyle=[0,0,2,2,0,0,2,2,0,2,0,2,0,2], $
					colors=[0,1,0,1,2,3,2,3,4,4,5,5,6,6],thick=2,charthick=5
			ENDFOR
		ENDIF

		;UAID 3102117
		IF uaid EQ 3 THEN BEGIN
			!p.multi=[0,1,1]
			!p.position=0

			FOR j=0, 1 DO BEGIN
				plot,iframe[0:99],dn_r[0,0,0,0,0:99],xrange=[0,80],yrange=[-20,20+j*2000], $
					ytit='dn',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name3,/nodata
				oplot,[53,53],[-2000,3000],linestyle=2,thick=3
				oplot,[47,47],[-2000,3000],linestyle=2,thick=3
				oplot,[41,41],[-2000,3000],linestyle=2,thick=3
				oplot,[35,35],[-2000,3000],linestyle=2,thick=3
				IF k EQ 0 THEN BEGIN
					oplot,[33,33],[-2000,3000],linestyle=2,thick=3
					oplot,[31,31],[-2000,3000],linestyle=2,thick=3
					oplot,[28,28],[-2000,3000],linestyle=2,thick=3
					oplot,[27,27],[-2000,3000],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,[30,30],[-2000,3000],linestyle=2,thick=3
					oplot,[28,28],[-2000,3000],linestyle=2,thick=3
					oplot,[25,25],[-2000,3000],linestyle=2,thick=3
					oplot,[24,24],[-2000,3000],linestyle=2,thick=3
				ENDIF
				oplot,[21,21],[-2000,3000],linestyle=2,thick=3
				oplot,[15,15],[-2000,3000],linestyle=2,thick=3

				IF k EQ 0 THEN BEGIN
					oplot,iframe[0:99],dn_r[0,0,2*det,0,20:99],color=lcol[0],thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det,1,20:99],color=lcol[1],thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det+1,0,22:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det+1,1,22:99],color=lcol[1],linestyle=2,thick=3
					oplot,iframe[0:99],dn_r[1,0,2*det,0,25:99],color=lcol[2],thick=3
					oplot,iframe[0:99],dn_r[1,0,2*det,1,25:99],color=lcol[3],thick=3
					oplot,iframe[0:99],dn_r[1,0,2*det+1,0,26:99],color=lcol[2],linestyle=2,thick=3
					oplot,iframe[0:99],dn_r[1,0,2*det+1,1,26:99],color=lcol[3],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,iframe[0:99],dn_r[0,0,2*det,0,23:99],color=lcol[0],thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det,1,23:99],color=lcol[1],thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det+1,0,25:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[0:99],dn_r[0,0,2*det+1,1,25:99],color=lcol[1],linestyle=2,thick=3
					oplot,iframe[0:99],dn_r[1,0,2*det,0,28:99],color=lcol[2],thick=3
					oplot,iframe[0:99],dn_r[1,0,2*det,1,28:99],color=lcol[3],thick=3
					oplot,iframe[0:99],dn_r[1,0,2*det+1,0,29:99],color=lcol[2],linestyle=2,thick=3
					oplot,iframe[0:99],dn_r[1,0,2*det+1,1,29:99],color=lcol[3],linestyle=2,thick=3
				ENDIF
				oplot,iframe[0:99],dn_r[2,0,det,0,12:99],color=4,thick=3
				oplot,iframe[0:99],dn_r[3,0,det,0,18:99],color=4,linestyle=2,thick=3
				oplot,iframe[0:99],dn_r[4,0,det,0,32:99],color=5,thick=3
				oplot,iframe[0:99],dn_r[5,0,det,0,38:99],color=5,linestyle=2,thick=3
				oplot,iframe[0:99],dn_r[6,0,det,0,6:99],color=6,thick=3
				oplot,iframe[0:99],dn_r[7,0,det,0,0:99],color=6,linestyle=2,thick=3

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': DN vs frame'
				subtitle='Detectors '+strtrim(string(det+1),1)+' (M), '+strtrim(string(2*det+1),1)+ $
					' and '+strtrim(string(2*det+2),1)+' (I)'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.5,0.975,subtitle,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.665,0.15,m9,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.60,0.15,m8,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.53,0.15,m11,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.47,0.15,m10,/normal,alignment=0.5,charsize=1,charthick=5
				IF k EQ 0 THEN BEGIN
					XYOUTS,0.45,0.18,i3_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.43,0.15,i3_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.40,0.18,i4_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.39,0.15,i4_o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				IF k EQ 1 THEN BEGIN
					XYOUTS,0.42,0.15,i3_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.40,0.18,i3_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.365,0.15,i4_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.355,0.18,i4_o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				XYOUTS,0.315,0.15,m12,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.25,0.15,m13,/normal,alignment=0.5,charsize=1,charthick=5

				legend,name,linestyle=[0,0,2,2,0,0,2,2,0,2,0,2,0,2], $
					colors=[0,1,0,1,2,3,2,3,4,4,5,5,6,6],thick=2,charthick=5,/right_legend
			ENDFOR
		ENDIF

		;UAID 3102121
		IF uaid EQ 4 THEN BEGIN
			!p.multi=[0,1,1]
			!p.position=0

			FOR j=0, 1 DO BEGIN
				plot,iframe[0:99],dn_r[0,0,0,0,0:99],xrange=[20,100],yrange=[-20,20+j*2500], $
					ytit='dn',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name2,/nodata
				oplot,[85,85],[-2000,3000],linestyle=2,thick=3
				oplot,[79,79],[-2000,3000],linestyle=2,thick=3
				oplot,[73,73],[-2000,3000],linestyle=2,thick=3
				oplot,[67,67],[-2000,3000],linestyle=2,thick=3
				IF k EQ 0 THEN BEGIN
					oplot,[65,65],[-2000,3000],linestyle=2,thick=3
					oplot,[63,63],[-2000,3000],linestyle=2,thick=3
					oplot,[60,60],[-2000,3000],linestyle=2,thick=3
					oplot,[59,59],[-2000,3000],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,[62,62],[-2000,3000],linestyle=2,thick=3
					oplot,[60,60],[-2000,3000],linestyle=2,thick=3
					oplot,[57,57],[-2000,3000],linestyle=2,thick=3
					oplot,[56,56],[-2000,3000],linestyle=2,thick=3
				ENDIF
				oplot,[53,53],[-2000,3000],linestyle=2,thick=3
				oplot,[47,47],[-2000,3000],linestyle=2,thick=3

				IF k EQ 0 THEN BEGIN
					oplot,iframe[12:99],dn_r[0,0,2*det,0,0:99],color=lcol[0],thick=3
					oplot,iframe[12:99],dn_r[0,0,2*det,1,0:99],color=lcol[1],thick=3
					oplot,iframe[10:99],dn_r[0,0,2*det+1,0,0:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[10:99],dn_r[0,0,2*det+1,1,0:99],color=lcol[1],linestyle=2,thick=3
					oplot,iframe[7:99],dn_r[1,0,2*det,0,0:99],color=lcol[2],thick=3
					oplot,iframe[7:99],dn_r[1,0,2*det,1,0:99],color=lcol[3],thick=3
					oplot,iframe[6:99],dn_r[1,0,2*det+1,0,0:99],color=lcol[2],linestyle=2,thick=3
					oplot,iframe[6:99],dn_r[1,0,2*det+1,1,0:99],color=lcol[3],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,iframe[9:99],dn_r[0,0,2*det,0,0:99],color=lcol[0],thick=3
					oplot,iframe[9:99],dn_r[0,0,2*det,1,0:99],color=lcol[1],thick=3
					oplot,iframe[7:99],dn_r[0,0,2*det+1,0,0:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[7:99],dn_r[0,0,2*det+1,1,0:99],color=lcol[1],linestyle=2,thick=3
					oplot,iframe[4:99],dn_r[1,0,2*det,0,0:99],color=lcol[2],thick=3
					oplot,iframe[4:99],dn_r[1,0,2*det,1,0:99],color=lcol[3],thick=3
					oplot,iframe[3:99],dn_r[1,0,2*det+1,0,0:99],color=lcol[2],linestyle=2,thick=3
					oplot,iframe[3:99],dn_r[1,0,2*det+1,1,0:99],color=lcol[3],linestyle=2,thick=3
				ENDIF
				oplot,iframe[14:99],dn_r[2,0,det,0,0:99],color=4,thick=3
				oplot,iframe[20:99],dn_r[3,0,det,0,0:99],color=4,linestyle=2,thick=3
				oplot,iframe[0:99],dn_r[4,0,det,0,0:99],color=5,thick=3
				oplot,iframe[0:99],dn_r[5,0,det,0,6:99],color=5,linestyle=2,thick=3
				oplot,iframe[26:99],dn_r[6,0,det,0,0:99],color=6,thick=3
				oplot,iframe[32:99],dn_r[7,0,det,0,0:99],color=6,linestyle=2,thick=3

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': DN vs frame'
				subtitle='Detectors '+strtrim(string(det+1),1)+' (M), '+strtrim(string(2*det+1),1)+ $
					' and '+strtrim(string(2*det+2),1)+' (I)'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.5,0.975,subtitle,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.795,0.15,m9,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.725,0.15,m8,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.66,0.15,m11,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.595,0.15,m10,/normal,alignment=0.5,charsize=1,charthick=5
				IF k EQ 0 THEN BEGIN
					XYOUTS,0.575,0.18,i3_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.555,0.15,i3_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.525,0.18,i4_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.51,0.15,i4_o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				IF k EQ 1 THEN BEGIN
					XYOUTS,0.545,0.15,i3_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.53,0.18,i3_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.49,0.15,i4_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.485,0.18,i4_o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				XYOUTS,0.44,0.15,m12,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.38,0.15,m13,/normal,alignment=0.5,charsize=1,charthick=5

				legend,name,linestyle=[0,0,2,2,0,0,2,2,0,2,0,2,0,2], $
					colors=[0,1,0,1,2,3,2,3,4,4,5,5,6,6],thick=2,charthick=5
			ENDFOR
		ENDIF

		;UAID 3102149
		IF uaid EQ 5 THEN BEGIN
			!p.multi=[0,1,1]
			!p.position=0

			FOR j=0, 1 DO BEGIN
				plot,iframe[0:99],dn_r[0,0,0,0,0:99],xrange=[0,100],yrange=[-20,20+j*2000], $
					ytit='dn',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name1,/nodata
				IF k EQ 0 THEN BEGIN
					oplot,[79,79],[-2000,3000],linestyle=2,thick=3
					oplot,[73,73],[-2000,3000],linestyle=2,thick=3
					oplot,[67,67],[-2000,3000],linestyle=2,thick=3
					oplot,[61,61],[-2000,3000],linestyle=2,thick=3
					oplot,[59,59],[-2000,3000],linestyle=2,thick=3
					oplot,[57,57],[-2000,3000],linestyle=2,thick=3
					oplot,[54,54],[-2000,3000],linestyle=2,thick=3
					oplot,[53,53],[-2000,3000],linestyle=2,thick=3
					oplot,[47,47],[-2000,3000],linestyle=2,thick=3
					oplot,[41,41],[-2000,3000],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,[82,82],[-2000,3000],linestyle=2,thick=3
					oplot,[76,76],[-2000,3000],linestyle=2,thick=3
					oplot,[70,70],[-2000,3000],linestyle=2,thick=3
					oplot,[64,64],[-2000,3000],linestyle=2,thick=3
					oplot,[59,59],[-2000,3000],linestyle=2,thick=3
					oplot,[57,57],[-2000,3000],linestyle=2,thick=3
					oplot,[54,54],[-2000,3000],linestyle=2,thick=3
					oplot,[53,53],[-2000,3000],linestyle=2,thick=3
					oplot,[50,50],[-2000,3000],linestyle=2,thick=3
					oplot,[44,44],[-2000,3000],linestyle=2,thick=3
				ENDIF

				IF k EQ 0 THEN BEGIN
					oplot,iframe[6:99],dn_r[0,0,2*det,0,0:99],color=lcol[0],thick=3
					oplot,iframe[6:99],dn_r[0,0,2*det,1,0:99],color=lcol[1],thick=3
					oplot,iframe[4:99],dn_r[0,0,2*det+1,0,0:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[4:99],dn_r[0,0,2*det+1,1,0:99],color=lcol[1],linestyle=2,thick=3
					oplot,iframe[1:99],dn_r[1,0,2*det,0,0:99],color=lcol[2],thick=3
					oplot,iframe[1:99],dn_r[1,0,2*det,1,0:99],color=lcol[3],thick=3
					oplot,iframe[0:99],dn_r[1,0,2*det+1,0,0:99],color=lcol[2],linestyle=2,thick=3
					oplot,iframe[0:99],dn_r[1,0,2*det+1,1,0:99],color=lcol[3],linestyle=2,thick=3
					oplot,iframe[8:99],dn_r[2,0,det,0,0:99],color=4,thick=3
					oplot,iframe[14:99],dn_r[3,0,det,0,0:99],color=4,linestyle=2,thick=3
					oplot,iframe[0:99],dn_r[4,0,det,0,6:99],color=5,thick=3
					oplot,iframe[0:99],dn_r[5,0,det,0,12:99],color=5,linestyle=2,thick=3
					oplot,iframe[20:99],dn_r[6,0,det,0,0:99],color=6,thick=3
					oplot,iframe[26:99],dn_r[7,0,det,0,0:99],color=6,linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,iframe[6:99],dn_r[0,0,2*det,0,0:99],color=lcol[0],thick=3
					oplot,iframe[6:99],dn_r[0,0,2*det,1,0:99],color=lcol[1],thick=3
					oplot,iframe[4:99],dn_r[0,0,2*det+1,0,0:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[4:99],dn_r[0,0,2*det+1,1,0:99],color=lcol[1],linestyle=2,thick=3
					oplot,iframe[1:99],dn_r[1,0,2*det,0,0:99],color=lcol[2],thick=3
					oplot,iframe[1:99],dn_r[1,0,2*det,1,0:99],color=lcol[3],thick=3
					oplot,iframe[0:99],dn_r[1,0,2*det+1,0,0:99],color=lcol[2],linestyle=2,thick=3
					oplot,iframe[0:99],dn_r[1,0,2*det+1,1,0:99],color=lcol[3],linestyle=2,thick=3
					oplot,iframe[11:99],dn_r[2,0,det,0,0:99],color=4,thick=3
					oplot,iframe[17:99],dn_r[3,0,det,0,0:99],color=4,linestyle=2,thick=3
					oplot,iframe[0:99],dn_r[4,0,det,0,3:99],color=5,thick=3
					oplot,iframe[0:99],dn_r[5,0,det,0,9:99],color=5,linestyle=2,thick=3
					oplot,iframe[23:99],dn_r[6,0,det,0,0:99],color=6,thick=3
					oplot,iframe[29:99],dn_r[7,0,det,0,0:99],color=6,linestyle=2,thick=3
				ENDIF

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': DN vs frame'
				subtitle='Detectors '+strtrim(string(det+1),1)+' (M), '+strtrim(string(2*det+1),1)+ $
					' and '+strtrim(string(2*det+2),1)+' (I)'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.5,0.975,subtitle,/normal,alignment=0.5,charsize=1.6,charthick=5
				IF k EQ 0 THEN BEGIN
					XYOUTS,0.775,0.15,m9,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.72,0.15,m8,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.665,0.15,m11,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.615,0.15,m10,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.605,0.18,i3_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.585,0.15,i3_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.56,0.18,i4_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.55,0.15,i4_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.495,0.15,m12,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.445,0.15,m13,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				IF k EQ 1 THEN BEGIN
					XYOUTS,0.80,0.15,m9,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.745,0.15,m8,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.695,0.15,m11,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.64,0.15,m10,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.60,0.18,i3_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.59,0.15,i3_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.56,0.18,i4_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.555,0.15,i4_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.52,0.15,m12,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.465,0.15,m13,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF

				legend,name,linestyle=[0,0,2,2,0,0,2,2,0,2,0,2,0,2], $
					colors=[0,1,0,1,2,3,2,3,4,4,5,5,6,6],thick=2,charthick=5
			ENDFOR
		ENDIF

		;UAID 3102162
		IF uaid EQ 6 THEN BEGIN
			!p.multi=[0,1,1]
			!p.position=0

			FOR j=0, 1 DO BEGIN
				plot,iframe[0:99],dn_r[0,0,0,0,0:99],xrange=[20,100],yrange=[-20,20+j*2000], $
					ytit='dn',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name2,/nodata
				oplot,[91,91],[-2000,3000],linestyle=2,thick=3
				oplot,[85,85],[-2000,3000],linestyle=2,thick=3
				oplot,[79,79],[-2000,3000],linestyle=2,thick=3
				oplot,[73,73],[-2000,3000],linestyle=2,thick=3
				IF k EQ 0 THEN BEGIN
					oplot,[71,71],[-2000,3000],linestyle=2,thick=3
					oplot,[69,69],[-2000,3000],linestyle=2,thick=3
					oplot,[66,66],[-2000,3000],linestyle=2,thick=3
					oplot,[65,65],[-2000,3000],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,[68,68],[-2000,3000],linestyle=2,thick=3
					oplot,[66,66],[-2000,3000],linestyle=2,thick=3
					oplot,[63,63],[-2000,3000],linestyle=2,thick=3
					oplot,[62,62],[-2000,3000],linestyle=2,thick=3
				ENDIF
				oplot,[59,59],[-2000,3000],linestyle=2,thick=3
				oplot,[53,53],[-2000,3000],linestyle=2,thick=3

				IF k EQ 0 THEN BEGIN
					oplot,iframe[18:99],dn_r[0,0,2*det,0,0:99],color=lcol[0],thick=3
					oplot,iframe[18:99],dn_r[0,0,2*det,1,0:99],color=lcol[1],thick=3
					oplot,iframe[16:99],dn_r[0,0,2*det+1,0,0:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[16:99],dn_r[0,0,2*det+1,1,0:99],color=lcol[1],linestyle=2,thick=3
					oplot,iframe[13:99],dn_r[1,0,2*det,0,0:99],color=lcol[2],thick=3
					oplot,iframe[13:99],dn_r[1,0,2*det,1,0:99],color=lcol[3],thick=3
					oplot,iframe[12:99],dn_r[1,0,2*det+1,0,0:99],color=lcol[2],linestyle=2,thick=3
					oplot,iframe[12:99],dn_r[1,0,2*det+1,1,0:99],color=lcol[3],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,iframe[15:99],dn_r[0,0,2*det,0,0:99],color=lcol[0],thick=3
					oplot,iframe[15:99],dn_r[0,0,2*det,1,0:99],color=lcol[1],thick=3
					oplot,iframe[13:99],dn_r[0,0,2*det+1,0,0:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[13:99],dn_r[0,0,2*det+1,1,0:99],color=lcol[1],linestyle=2,thick=3
					oplot,iframe[10:99],dn_r[1,0,2*det,0,0:99],color=lcol[2],thick=3
					oplot,iframe[10:99],dn_r[1,0,2*det,1,0:99],color=lcol[3],thick=3
					oplot,iframe[9:99],dn_r[1,0,2*det+1,0,0:99],color=lcol[2],linestyle=2,thick=3
					oplot,iframe[9:99],dn_r[1,0,2*det+1,1,0:99],color=lcol[3],linestyle=2,thick=3
				ENDIF
				oplot,iframe[20:99],dn_r[2,0,det,0,0:99],color=4,thick=3
				oplot,iframe[26:99],dn_r[3,0,det,0,0:99],color=4,linestyle=2,thick=3
				oplot,iframe[6:99],dn_r[4,0,det,0,0:99],color=5,thick=3
				oplot,iframe[0:99],dn_r[5,0,det,0,0:99],color=5,linestyle=2,thick=3
				oplot,iframe[32:99],dn_r[6,0,det,0,0:99],color=6,thick=3
				oplot,iframe[38:99],dn_r[7,0,det,0,0:99],color=6,linestyle=2,thick=3

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': DN vs frame'
				subtitle='Detectors '+strtrim(string(det+1),1)+' (M), '+strtrim(string(2*det+1),1)+ $
					' and '+strtrim(string(2*det+2),1)+' (I)'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.5,0.975,subtitle,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.86,0.15,m9,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.79,0.15,m8,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.725,0.15,m11,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.66,0.15,m10,/normal,alignment=0.5,charsize=1,charthick=5
				IF k EQ 0 THEN BEGIN
					XYOUTS,0.64,0.18,i3_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.62,0.15,i3_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.59,0.18,i4_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.58,0.15,i4_o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				IF k EQ 1 THEN BEGIN
					XYOUTS,0.61,0.15,i3_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.59,0.18,i3_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.555,0.15,i4_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.545,0.18,i4_o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				XYOUTS,0.51,0.15,m12,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.445,0.15,m13,/normal,alignment=0.5,charsize=1,charthick=5

				legend,name,linestyle=[0,0,2,2,0,0,2,2,0,2,0,2,0,2], $
					colors=[0,1,0,1,2,3,2,3,4,4,5,5,6,6],thick=2,charthick=5
			ENDFOR
		ENDIF

		;UAID 3102166 and 3102167
		IF uaid EQ 7 OR uaid EQ 8 THEN BEGIN
			!p.multi=[0,1,1]
			!p.position=0

			FOR j=0, 1 DO BEGIN
				plot,iframe[0:99],dn_r[0,0,0,0,0:99],xrange=[0,100],yrange=[-20,100+j*2500], $
					ytit='dn',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name1,/nodata
				oplot,[91,91],[-2000,3000],linestyle=2,thick=3
				oplot,[85,85],[-2000,3000],linestyle=2,thick=3
				oplot,[79,79],[-2000,3000],linestyle=2,thick=3
				oplot,[73,73],[-2000,3000],linestyle=2,thick=3
				IF k EQ 0 THEN BEGIN
					oplot,[71,71],[-2000,3000],linestyle=2,thick=3
					oplot,[69,69],[-2000,3000],linestyle=2,thick=3
					oplot,[66,66],[-2000,3000],linestyle=2,thick=3
					oplot,[65,65],[-2000,3000],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,[68,68],[-2000,3000],linestyle=2,thick=3
					oplot,[66,66],[-2000,3000],linestyle=2,thick=3
					oplot,[63,63],[-2000,3000],linestyle=2,thick=3
					oplot,[62,62],[-2000,3000],linestyle=2,thick=3
				ENDIF
				oplot,[59,59],[-2000,3000],linestyle=2,thick=3
				oplot,[53,53],[-2000,3000],linestyle=2,thick=3

				IF k EQ 0 THEN BEGIN
					oplot,iframe[18:99],dn_r[0,0,2*det,0,0:99],color=lcol[0],thick=3
					oplot,iframe[18:99],dn_r[0,0,2*det,1,0:99],color=lcol[1],thick=3
					oplot,iframe[16:99],dn_r[0,0,2*det+1,0,0:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[16:99],dn_r[0,0,2*det+1,1,0:99],color=lcol[1],linestyle=2,thick=3
					oplot,iframe[13:99],dn_r[1,0,2*det,0,0:99],color=lcol[2],thick=3
					oplot,iframe[13:99],dn_r[1,0,2*det,1,0:99],color=lcol[3],thick=3
					oplot,iframe[12:99],dn_r[1,0,2*det+1,0,0:99],color=lcol[2],linestyle=2,thick=3
					oplot,iframe[12:99],dn_r[1,0,2*det+1,1,0:99],color=lcol[3],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,iframe[15:99],dn_r[0,0,2*det,0,0:99],color=lcol[0],thick=3
					oplot,iframe[15:99],dn_r[0,0,2*det,1,0:99],color=lcol[1],thick=3
					oplot,iframe[13:99],dn_r[0,0,2*det+1,0,0:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[13:99],dn_r[0,0,2*det+1,1,0:99],color=lcol[1],linestyle=2,thick=3
					oplot,iframe[10:99],dn_r[1,0,2*det,0,0:99],color=lcol[2],thick=3
					oplot,iframe[10:99],dn_r[1,0,2*det,1,0:99],color=lcol[3],thick=3
					oplot,iframe[9:99],dn_r[1,0,2*det+1,0,0:99],color=lcol[2],linestyle=2,thick=3
					oplot,iframe[9:99],dn_r[1,0,2*det+1,1,0:99],color=lcol[3],linestyle=2,thick=3
				ENDIF
				oplot,iframe[20:99],dn_r[2,0,det,0,0:99],color=4,thick=3
				oplot,iframe[26:99],dn_r[3,0,det,0,0:99],color=4,linestyle=2,thick=3
				oplot,iframe[6:99],dn_r[4,0,det,0,0:99],color=5,thick=3
				oplot,iframe[0:99],dn_r[5,0,det,0,0:99],color=5,linestyle=2,thick=3
				oplot,iframe[32:99],dn_r[6,0,det,0,0:99],color=6,thick=3
				oplot,iframe[38:99],dn_r[7,0,det,0,0:99],color=6,linestyle=2,thick=3

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': DN vs frame'
				subtitle='Detectors '+strtrim(string(det+1),1)+' (M), '+strtrim(string(2*det+1),1)+ $
					' and '+strtrim(string(2*det+2),1)+' (I)'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.5,0.975,subtitle,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.875,0.15,m9,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.825,0.15,m8,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.77,0.15,m11,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.72,0.15,m10,/normal,alignment=0.5,charsize=1,charthick=5

				IF k EQ 0 THEN BEGIN
					XYOUTS,0.70,0.18,i3_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.69,0.15,i3_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.665,0.18,i4_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.655,0.15,i4_o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				IF k EQ 1 THEN BEGIN
					XYOUTS,0.68,0.18,i3_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.665,0.15,i3_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.64,0.18,i4_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.63,0.15,i4_o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				XYOUTS,0.595,0.15,m12,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.545,0.15,m13,/normal,alignment=0.5,charsize=1,charthick=5

				legend,name,linestyle=[0,0,2,2,0,0,2,2,0,2,0,2,0,2], $
					colors=[0,1,0,1,2,3,2,3,4,4,5,5,6,6],thick=2,charthick=5
			ENDFOR
			!p.multi=[0,1,1]
			!p.position=0

			FOR j=0, 1 DO BEGIN
				plot,iframe[0:99],dn_lg[0,0,0,0,0:99],xrange=[0,100],yrange=[-20,100+j*2500], $
					ytit='dn',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name1,/nodata
				oplot,[91,91],[-2000,3000],linestyle=2,thick=3
				oplot,[85,85],[-2000,3000],linestyle=2,thick=3
				oplot,[79,79],[-2000,3000],linestyle=2,thick=3
				oplot,[73,73],[-2000,3000],linestyle=2,thick=3
				IF k EQ 0 THEN BEGIN
					oplot,[71,71],[-2000,3000],linestyle=2,thick=3
					oplot,[69,69],[-2000,3000],linestyle=2,thick=3
					oplot,[66,66],[-2000,3000],linestyle=2,thick=3
					oplot,[65,65],[-2000,3000],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,[68,68],[-2000,3000],linestyle=2,thick=3
					oplot,[66,66],[-2000,3000],linestyle=2,thick=3
					oplot,[63,63],[-2000,3000],linestyle=2,thick=3
					oplot,[62,62],[-2000,3000],linestyle=2,thick=3
				ENDIF
				oplot,[59,59],[-2000,3000],linestyle=2,thick=3
				oplot,[53,53],[-2000,3000],linestyle=2,thick=3

				IF k EQ 0 THEN BEGIN
					oplot,iframe[18:99],dn_lg[0,0,2*det,0,0:99],color=lcol[0],thick=3
					oplot,iframe[18:99],dn_lg[0,0,2*det,1,0:99],color=lcol[1],thick=3
					oplot,iframe[16:99],dn_lg[0,0,2*det+1,0,0:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[16:99],dn_lg[0,0,2*det+1,1,0:99],color=lcol[1],linestyle=2,thick=3
					oplot,iframe[13:99],dn_lg[1,0,2*det,0,0:99],color=lcol[2],thick=3
					oplot,iframe[13:99],dn_lg[1,0,2*det,1,0:99],color=lcol[3],thick=3
					oplot,iframe[12:99],dn_lg[1,0,2*det+1,0,0:99],color=lcol[2],linestyle=2,thick=3
					oplot,iframe[12:99],dn_lg[1,0,2*det+1,1,0:99],color=lcol[3],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,iframe[15:99],dn_lg[0,0,2*det,0,0:99],color=lcol[0],thick=3
					oplot,iframe[15:99],dn_lg[0,0,2*det,1,0:99],color=lcol[1],thick=3
					oplot,iframe[13:99],dn_lg[0,0,2*det+1,0,0:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[13:99],dn_lg[0,0,2*det+1,1,0:99],color=lcol[1],linestyle=2,thick=3
					oplot,iframe[10:99],dn_lg[1,0,2*det,0,0:99],color=lcol[2],thick=3
					oplot,iframe[10:99],dn_lg[1,0,2*det,1,0:99],color=lcol[3],thick=3
					oplot,iframe[9:99],dn_lg[1,0,2*det+1,0,0:99],color=lcol[2],linestyle=2,thick=3
					oplot,iframe[9:99],dn_lg[1,0,2*det+1,1,0:99],color=lcol[3],linestyle=2,thick=3
				ENDIF
				oplot,iframe[20:99],dn_lg[2,0,det,0,0:99],color=4,thick=3
				oplot,iframe[26:99],dn_lg[3,0,det,0,0:99],color=4,linestyle=2,thick=3
				oplot,iframe[6:99],dn_lg[4,0,det,0,0:99],color=5,thick=3
				oplot,iframe[0:99],dn_lg[5,0,det,0,0:99],color=5,linestyle=2,thick=3
				oplot,iframe[32:99],dn_lg[6,0,det,0,0:99],color=6,thick=3
				oplot,iframe[38:99],dn_lg[7,0,det,0,0:99],color=6,linestyle=2,thick=3

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+' Fixed Low Gain: DN vs frame'
				subtitle='Detectors '+strtrim(string(det+1),1)+' (M), '+strtrim(string(2*det+1),1)+ $
					' and '+strtrim(string(2*det+2),1)+' (I)'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.5,0.975,subtitle,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.875,0.15,m9,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.825,0.15,m8,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.77,0.15,m11,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.72,0.15,m10,/normal,alignment=0.5,charsize=1,charthick=5

				IF k EQ 0 THEN BEGIN
					XYOUTS,0.70,0.18,i3_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.69,0.15,i3_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.665,0.18,i4_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.655,0.15,i4_o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				IF k EQ 1 THEN BEGIN
					XYOUTS,0.68,0.18,i3_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.665,0.15,i3_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.64,0.18,i4_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.63,0.15,i4_o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				XYOUTS,0.595,0.15,m12,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.545,0.15,m13,/normal,alignment=0.5,charsize=1,charthick=5

				legend,name,linestyle=[0,0,2,2,0,0,2,2,0,2,0,2,0,2], $
					colors=[0,1,0,1,2,3,2,3,4,4,5,5,6,6],thick=2,charthick=5
			ENDFOR
		ENDIF
	ENDFOR
	!p.multi=[0,3,2]
	!p.position=0

	i=0
	FOR b=0, 7 DO BEGIN
		IF b EQ 1 THEN i=2
		IF b LE 1 THEN BEGIN
			plot,iframe[*],L_r[b,0,0,0,*],xrange=[0,100],yrange=[-0.5,0.5],title=band_name[0+i], $
				ytit='L',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name1,/nodata
			FOR det=0, ndet_I-1 DO BEGIN
				oplot,iframe[*],L_r[b,0,det,0,*],color=lcol[det]
			ENDFOR
			plot,iframe[*],L_r[b,0,0,1,*],xrange=[0,100],yrange=[-0.5,0.5],title=band_name[1+i], $
				ytit='L',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name1,/nodata
			FOR det=0, ndet_I-1 DO BEGIN
				oplot,iframe[*],L_r[b,0,det,1,*],color=lcol[det]
			ENDFOR
		ENDIF
		IF b GT 1 THEN BEGIN
			plot,iframe[*],L_r[b,0,0,0,*],xrange=[0,100],yrange=[-20,20],title=band_name[b+2], $
				ytit='L',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name1,/nodata
			FOR det=0, ndet_M-1 DO BEGIN
				oplot,iframe[*],L_r[b,0,det,0,*],color=lcol[det]
			ENDFOR
		ENDIF
		title='UAID '+uaidname[uaid]+': L vs frame'
		XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
	ENDFOR

	i=0
	FOR b=0, 7 DO BEGIN
		!p.multi=[0,4,4]
		!p.position=0

		IF b GT 0 THEN i=1
		IF b LE 1 THEN BEGIN
			FOR det=0, ndet_I-1 DO BEGIN
				plot,iframe[*],L_r[b,0,0,0,*],xrange=[0,100],yrange=[-0.5,0.5], $
					title=band_name[b+i]+' det='+strtrim(string(det+1),1), $
					ytit='L',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name1,/nodata
				oplot,iframe[*],L_r[b,0,det,0,*],color=lcol[det]

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': L vs frame'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
			ENDFOR
			FOR det=0, ndet_I-1 DO BEGIN
				plot,iframe[*],L_r[b,0,0,1,*],xrange=[0,100],yrange=[-0.5,0.5], $
					title=band_name[b+i+1]+' det='+strtrim(string(det+1),1), $
					ytit='L',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name1,/nodata
				oplot,iframe[*],L_r[b,0,det,1,*],color=lcol[det]

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': L vs frame'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
			ENDFOR
		ENDIF
		IF b GT 1 THEN BEGIN
			FOR det=0, ndet_M-1 DO BEGIN
				plot,iframe[*],L_r[b,0,det,0,*],xrange=[0,100],yrange=[-20,20], $
					title=band_name[b+2]+' det='+strtrim(string(det+1),1), $
					ytit='L',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name1,/nodata
				oplot,iframe[*],L_r[b,0,det,0,*],color=lcol[det]
			ENDFOR
		ENDIF
		title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': L vs frame'
		XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
	ENDFOR

	IF uaid GE 7 THEN BEGIN
		!p.multi=[0,3,2]
		!p.position=0

		i=0
		FOR b=0, 7 DO BEGIN
			IF b EQ 1 THEN i=2
			IF b LE 1 THEN BEGIN
				plot,iframe[*],L_lg[b,0,0,0,*],xrange=[0,100],yrange=[-0.5,0.5],title=band_name[0+i], $
					ytit='L',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name1,/nodata
				FOR det=0, ndet_I-1 DO BEGIN
					oplot,iframe[*],L_lg[b,0,det,0,*],color=lcol[det]
				ENDFOR
				plot,iframe[*],L_lg[b,0,0,1,*],xrange=[0,100],yrange=[-0.5,0.5],title=band_name[1+i], $
					ytit='L',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name1,/nodata
				FOR det=0, ndet_I-1 DO BEGIN
					oplot,iframe[*],L_lg[b,0,det,1,*],color=lcol[det]
				ENDFOR
			ENDIF
			IF b GT 1 THEN BEGIN
				plot,iframe[*],L_lg[b,0,0,0,*],xrange=[0,100],yrange=[-0.5,0.5],title=band_name[b+2], $
					ytit='L',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name1,/nodata
				FOR det=0, ndet_M-1 DO BEGIN
					oplot,iframe[*],L_lg[b,0,det,0,*],color=lcol[det]
				ENDFOR
			ENDIF
			title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+' Fixed Low Gain: L vs frame'
			XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
		ENDFOR

		i=0
		FOR b=0, 7 DO BEGIN
			!p.multi=[0,4,4]
			!p.position=0

			IF b GT 0 THEN i=1
			IF b LE 1 THEN BEGIN
				FOR det=0, ndet_I-1 DO BEGIN
					plot,iframe[*],L_lg[b,0,0,0,*],xrange=[0,100],yrange=[-0.5,0.5], $
						title=band_name[b+i]+' det='+strtrim(string(det+1),1), $
						ytit='L',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name1,/nodata
					oplot,iframe[*],L_lg[b,0,det,0,*],color=lcol[det]

					title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+' Fixed Low Gain: L vs frame'
					XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
				ENDFOR
				FOR det=0, ndet_I-1 DO BEGIN
					plot,iframe[*],L_lg[b,0,0,1,*],xrange=[0,100],yrange=[-0.5,0.5], $
						title=band_name[b+i+1]+' det='+strtrim(string(det+1),1), $
						ytit='L',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name1,/nodata
					oplot,iframe[*],L_lg[b,0,det,1,*],color=lcol[det]

					title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+' Fixed Low Gain: L vs frame'
					XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
				ENDFOR
			ENDIF
			IF b GT 1 THEN BEGIN
				FOR det=0, ndet_M-1 DO BEGIN
					plot,iframe[*],L_lg[b,0,det,0,*],xrange=[0,100],yrange=[-0.5,0.5], $
						title=band_name[b+2]+' det='+strtrim(string(det+1),1), $
						ytit='L',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name1,/nodata
					oplot,iframe[*],L_lg[b,0,det,0,*],color=lcol[det]
				ENDFOR
			ENDIF
			title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+' Fixed Low Gain: L vs frame'
			XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
		ENDFOR
	ENDIF

	k=1
	FOR det=0, ndet_M-1 DO BEGIN

		IF k EQ 1 THEN BEGIN 
			k=0
			goto,skip_kk
		ENDIF
		IF k EQ 0 THEN k=1
		skip_kk:

		name=['I3 SS1, det '+strtrim(string(2*det+1),1),'I3 SS2, det '+strtrim(string(2*det+1),1), $
			'I3 SS1, det '+strtrim(string(2*det+2),1),'I3 SS2, det '+strtrim(string(2*det+2),1), $
			'I4 SS1, det '+strtrim(string(2*det+1),1),'I4 SS2, det '+strtrim(string(2*det+1),1), $
			'I4 SS1, det '+strtrim(string(2*det+2),1),'I4 SS2, det '+strtrim(string(2*det+2),1), $
			'M10, det '+strtrim(string(det+1),1),'M11, det '+strtrim(string(det+1),1), $
			'M12, det '+strtrim(string(det+1),1),'M13, det '+strtrim(string(det+1),1), $
			'M8, det '+strtrim(string(det+1),1),'M9, det '+strtrim(string(det+1),1)]

		;UAID 3102099
		IF uaid EQ 0 THEN BEGIN
			!p.multi=[0,1,1]
			!p.position=0

			FOR j=0, 1 DO BEGIN
				plot,iframe[0:99],L_r[0,0,0,0,0:99],xrange=[0,100],yrange=[-0.5+j*(-10),0.5+j*18],ytit='L', $
					xtit='frame',charsize=1.2,charthick=5,xtickname=t_name1,/nodata
				oplot,[59,59],[-2000,3000],linestyle=2,thick=3
				oplot,[53,53],[-2000,3000],linestyle=2,thick=3
				oplot,[47,47],[-2000,3000],linestyle=2,thick=3
				oplot,[41,41],[-2000,3000],linestyle=2,thick=3
				IF k EQ 0 THEN BEGIN
					oplot,[39,39],[-2000,3000],linestyle=2,thick=3
					oplot,[37,37],[-2000,3000],linestyle=2,thick=3
					oplot,[34,34],[-2000,3000],linestyle=2,thick=3
					oplot,[33,33],[-2000,3000],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,[36,36],[-2000,3000],linestyle=2,thick=3
					oplot,[34,34],[-2000,3000],linestyle=2,thick=3
					oplot,[31,31],[-2000,3000],linestyle=2,thick=3
					oplot,[30,30],[-2000,3000],linestyle=2,thick=3
				ENDIF
				oplot,[27,27],[-2000,3000],linestyle=2,thick=3
				oplot,[21,21],[-2000,3000],linestyle=2,thick=3

				IF k EQ 0 THEN BEGIN
					oplot,iframe[0:99],L_r[0,0,2*det,0,14:99],color=lcol[0],thick=3
					oplot,iframe[0:99],L_r[0,0,2*det,1,14:99],color=lcol[1],thick=3
					oplot,iframe[0:99],L_r[0,0,2*det+1,0,16:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[0:99],L_r[0,0,2*det+1,1,16:99],color=lcol[1],linestyle=2,thick=3
					oplot,iframe[0:99],L_r[1,0,2*det,0,19:99],color=lcol[2],thick=3
					oplot,iframe[0:99],L_r[1,0,2*det,1,19:99],color=lcol[3],thick=3
					oplot,iframe[0:99],L_r[1,0,2*det+1,0,20:99],color=lcol[2],linestyle=2,thick=3
					oplot,iframe[0:99],L_r[1,0,2*det+1,1,20:99],color=lcol[3],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,iframe[0:99],L_r[0,0,2*det,0,17:99],color=lcol[0],thick=3
					oplot,iframe[0:99],L_r[0,0,2*det,1,17:99],color=lcol[1],thick=3
					oplot,iframe[0:99],L_r[0,0,2*det+1,0,19:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[0:99],L_r[0,0,2*det+1,1,19:99],color=lcol[1],linestyle=2,thick=3
					oplot,iframe[0:99],L_r[1,0,2*det,0,22:99],color=lcol[2],thick=3
					oplot,iframe[0:99],L_r[1,0,2*det,1,22:99],color=lcol[3],thick=3
					oplot,iframe[0:99],L_r[1,0,2*det+1,0,23:99],color=lcol[2],linestyle=2,thick=3
					oplot,iframe[0:99],L_r[1,0,2*det+1,1,23:99],color=lcol[3],linestyle=2,thick=3
				ENDIF
				oplot,iframe[0:99],L_r[2,0,det,0,6:99],color=4,thick=3
				oplot,iframe[0:99],L_r[3,0,det,0,12:99],color=4,linestyle=2,thick=3
				oplot,iframe[0:99],L_r[4,0,det,0,26:99],color=5,thick=3
				oplot,iframe[0:99],L_r[5,0,det,0,32:99],color=5,linestyle=2,thick=3
				oplot,iframe[0:99],L_r[6,0,det,0,0:99],color=6,thick=3
				oplot,iframe[6:99],L_r[7,0,det,0,0:99],color=6,linestyle=2,thick=3

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': L vs frame'
				subtitle='Detectors '+strtrim(string(det+1),1)+' (M), '+strtrim(string(2*det+1),1)+ $
					' and '+strtrim(string(2*det+2),1)+' (I)'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.5,0.975,subtitle,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.60,0.15,m9,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.55,0.15,m8,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.495,0.15,m11,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.445,0.15,m10,/normal,alignment=0.5,charsize=1,charthick=5
				IF k EQ 0 THEN BEGIN
					XYOUTS,0.43,0.18,i3_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.415,0.15,i3_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.39,0.18,i4_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.38,0.15,i4_o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				IF k EQ 1 THEN BEGIN
					XYOUTS,0.405,0.15,i3_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.39,0.18,i3_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.365,0.15,i4_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.355,0.18,i4_o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				XYOUTS,0.325,0.15,m12,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.27,0.15,m13,/normal,alignment=0.5,charsize=1,charthick=5

				legend,name,linestyle=[0,0,2,2,0,0,2,2,0,2,0,2,0,2], $
					colors=[0,1,0,1,2,3,2,3,4,4,5,5,6,6],thick=2,charthick=5,/right_legend
			ENDFOR
		ENDIF

		;UAID 3102103
		IF uaid EQ 1 THEN BEGIN
			!p.multi=[0,1,1]
			!p.position=0

			FOR j=0, 1 DO BEGIN
				plot,iframe[0:99],L_r[0,0,0,0,0:99],xrange=[20,100],yrange=[-0.5+j*(-10),0.5+j*18], $
					ytit='L',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name2,/nodata
				oplot,[71,71],[-2000,3000],linestyle=2,thick=3
				oplot,[65,65],[-2000,3000],linestyle=2,thick=3
				oplot,[59,59],[-2000,3000],linestyle=2,thick=3
				oplot,[53,53],[-2000,3000],linestyle=2,thick=3
				IF k EQ 0 THEN BEGIN
					oplot,[51,51],[-2000,3000],linestyle=2,thick=3
					oplot,[49,49],[-2000,3000],linestyle=2,thick=3
					oplot,[46,46],[-2000,3000],linestyle=2,thick=3
					oplot,[45,45],[-2000,3000],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,[48,48],[-2000,3000],linestyle=2,thick=3
					oplot,[46,46],[-2000,3000],linestyle=2,thick=3
					oplot,[43,43],[-2000,3000],linestyle=2,thick=3
					oplot,[42,42],[-2000,3000],linestyle=2,thick=3
				ENDIF
				oplot,[39,39],[-2000,3000],linestyle=2,thick=3
				oplot,[33,33],[-2000,3000],linestyle=2,thick=3

				IF k EQ 0 THEN BEGIN
					oplot,iframe[0:99],L_r[0,0,2*det,0,2:99],color=lcol[0],thick=3
					oplot,iframe[0:99],L_r[0,0,2*det,1,2:99],color=lcol[1],thick=3
					oplot,iframe[0:99],L_r[0,0,2*det+1,0,4:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[0:99],L_r[0,0,2*det+1,1,4:99],color=lcol[1],linestyle=2,thick=3
					oplot,iframe[0:99],L_r[1,0,2*det,0,7:99],color=lcol[2],thick=3
					oplot,iframe[0:99],L_r[1,0,2*det,1,7:99],color=lcol[3],thick=3
					oplot,iframe[0:99],L_r[1,0,2*det+1,0,8:99],color=lcol[2],linestyle=2,thick=3
					oplot,iframe[0:99],L_r[1,0,2*det+1,1,8:99],color=lcol[3],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,iframe[0:99],L_r[0,0,2*det,0,5:99],color=lcol[0],thick=3
					oplot,iframe[0:99],L_r[0,0,2*det,1,5:99],color=lcol[1],thick=3
					oplot,iframe[0:99],L_r[0,0,2*det+1,0,7:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[0:99],L_r[0,0,2*det+1,1,7:99],color=lcol[1],linestyle=2,thick=3
					oplot,iframe[0:99],L_r[1,0,2*det,0,10:99],color=lcol[2],thick=3
					oplot,iframe[0:99],L_r[1,0,2*det,1,10:99],color=lcol[3],thick=3
					oplot,iframe[0:99],L_r[1,0,2*det+1,0,11:99],color=lcol[2],linestyle=2,thick=3
					oplot,iframe[0:99],L_r[1,0,2*det+1,1,11:99],color=lcol[3],linestyle=2,thick=3
				ENDIF
				oplot,iframe[0:99],L_r[2,0,det,0,0:99],color=4,thick=3
				oplot,iframe[6:99],L_r[3,0,det,0,0:99],color=4,linestyle=2,thick=3
				oplot,iframe[0:99],L_r[4,0,det,0,14:99],color=5,thick=3
				oplot,iframe[0:99],L_r[5,0,det,0,20:99],color=5,linestyle=2,thick=3
				oplot,iframe[12:99],L_r[6,0,det,0,0:99],color=6,thick=3
				oplot,iframe[18:99],L_r[7,0,det,0,0:99],color=6,linestyle=2,thick=3

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': L vs frame'
				subtitle='Detectors '+strtrim(string(det+1),1)+' (M), '+strtrim(string(2*det+1),1)+ $
					' and '+strtrim(string(2*det+2),1)+' (I)'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.5,0.975,subtitle,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.645,0.15,m9,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.58,0.15,m8,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.51,0.15,m11,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.445,0.15,m10,/normal,alignment=0.5,charsize=1,charthick=5
				IF k EQ 0 THEN BEGIN
					XYOUTS,0.425,0.18,i3_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.41,0.15,i3_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.38,0.18,i4_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.365,0.15,i4_o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				IF k EQ 1 THEN BEGIN
					XYOUTS,0.40,0.15,i3_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.38,0.18,i3_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.34,0.15,i4_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.33,0.18,i4_o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				XYOUTS,0.29,0.15,m12,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.23,0.15,m13,/normal,alignment=0.5,charsize=1,charthick=5

				legend,name,linestyle=[0,0,2,2,0,0,2,2,0,2,0,2,0,2], $
					colors=[0,1,0,1,2,3,2,3,4,4,5,5,6,6],thick=2,charthick=5,/right_legend
			ENDFOR
		ENDIF

		;UAID 3102105
		IF uaid EQ 2 THEN BEGIN
			!p.multi=[0,1,1]
			!p.position=0

			FOR j=0, 1 DO BEGIN
				plot,iframe[0:99],L_r[0,0,0,0,0:99],xrange=[0,80],yrange=[-0.5+j*(-10),0.5+j*18], $
					ytit='L',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name3,/nodata
				IF k EQ 0 THEN BEGIN
					oplot,[75,75],[-2000,3000],linestyle=2,thick=3
					oplot,[69,69],[-2000,3000],linestyle=2,thick=3
					oplot,[63,63],[-2000,3000],linestyle=2,thick=3
					oplot,[57,57],[-2000,3000],linestyle=2,thick=3
					oplot,[55,55],[-2000,3000],linestyle=2,thick=3
					oplot,[53,53],[-2000,3000],linestyle=2,thick=3
					oplot,[50,50],[-2000,3000],linestyle=2,thick=3
					oplot,[49,49],[-2000,3000],linestyle=2,thick=3
					oplot,[43,43],[-2000,3000],linestyle=2,thick=3
					oplot,[37,37],[-2000,3000],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,[78,78],[-2000,3000],linestyle=2,thick=3
					oplot,[72,72],[-2000,3000],linestyle=2,thick=3
					oplot,[66,66],[-2000,3000],linestyle=2,thick=3
					oplot,[60,60],[-2000,3000],linestyle=2,thick=3
					oplot,[55,55],[-2000,3000],linestyle=2,thick=3
					oplot,[53,53],[-2000,3000],linestyle=2,thick=3
					oplot,[50,50],[-2000,3000],linestyle=2,thick=3
					oplot,[49,49],[-2000,3000],linestyle=2,thick=3
					oplot,[46,46],[-2000,3000],linestyle=2,thick=3
					oplot,[40,40],[-2000,3000],linestyle=2,thick=3
				ENDIF

				IF k EQ 0 THEN BEGIN
					oplot,iframe[2:99],L_r[0,0,2*det,0,0:99],color=lcol[0],thick=3
					oplot,iframe[2:99],L_r[0,0,2*det,1,0:99],color=lcol[1],thick=3
					oplot,iframe[0:99],L_r[0,0,2*det+1,0,0:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[0:99],L_r[0,0,2*det+1,1,0:99],color=lcol[1],linestyle=2,thick=3
					oplot,iframe[0:99],L_r[1,0,2*det,0,3:99],color=lcol[2],thick=3
					oplot,iframe[0:99],L_r[1,0,2*det,1,3:99],color=lcol[3],thick=3
					oplot,iframe[0:99],L_r[1,0,2*det+1,0,4:99],color=lcol[2],linestyle=2,thick=3
					oplot,iframe[0:99],L_r[1,0,2*det+1,1,4:99],color=lcol[3],linestyle=2,thick=3
					oplot,iframe[4:99],L_r[2,0,det,0,0:99],color=4,thick=3
					oplot,iframe[10:99],L_r[3,0,det,0,0:99],color=4,linestyle=2,thick=3
					oplot,iframe[0:99],L_r[4,0,det,0,10:99],color=5,thick=3
					oplot,iframe[0:99],L_r[5,0,det,0,16:99],color=5,linestyle=2,thick=3
					oplot,iframe[16:99],L_r[6,0,det,0,0:99],color=6,thick=3
					oplot,iframe[24:99],L_r[7,0,det,0,0:99],color=6,linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,iframe[2:99],L_r[0,0,2*det,0,0:99],color=lcol[0],thick=3
					oplot,iframe[2:99],L_r[0,0,2*det,1,0:99],color=lcol[1],thick=3
					oplot,iframe[0:99],L_r[0,0,2*det+1,0,0:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[0:99],L_r[0,0,2*det+1,1,0:99],color=lcol[1],linestyle=2,thick=3
					oplot,iframe[0:99],L_r[1,0,2*det,0,3:99],color=lcol[2],thick=3
					oplot,iframe[0:99],L_r[1,0,2*det,1,3:99],color=lcol[3],thick=3
					oplot,iframe[0:99],L_r[1,0,2*det+1,0,4:99],color=lcol[2],linestyle=2,thick=3
					oplot,iframe[0:99],L_r[1,0,2*det+1,1,4:99],color=lcol[3],linestyle=2,thick=3
					oplot,iframe[7:99],L_r[2,0,det,0,0:99],color=4,thick=3
					oplot,iframe[13:99],L_r[3,0,det,0,0:99],color=4,linestyle=2,thick=3
					oplot,iframe[0:99],L_r[4,0,det,0,7:99],color=5,thick=3
					oplot,iframe[0:99],L_r[5,0,det,0,13:99],color=5,linestyle=2,thick=3
					oplot,iframe[19:99],L_r[6,0,det,0,0:99],color=6,thick=3
					oplot,iframe[25:99],L_r[7,0,det,0,0:99],color=6,linestyle=2,thick=3
				ENDIF

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': L vs frame'
				subtitle='Detectors '+strtrim(string(det+1),1)+' (M), '+strtrim(string(2*det+1),1)+ $
					' and '+strtrim(string(2*det+2),1)+' (I)'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.5,0.975,subtitle,/normal,alignment=0.5,charsize=1.6,charthick=5
				IF k EQ 0 THEN BEGIN
					XYOUTS,0.90,0.15,m9,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.835,0.15,m8,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.77,0.15,m11,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.705,0.15,m10,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.685,0.18,i3_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.665,0.15,i3_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.635,0.18,i4_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.625,0.15,i4_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.55,0.15,m12,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.485,0.15,m13,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				IF k EQ 1 THEN BEGIN
					XYOUTS,0.93,0.15,m9,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.865,0.15,m8,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.80,0.15,m11,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.735,0.15,m10,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.685,0.18,i3_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.665,0.15,i3_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.635,0.18,i4_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.625,0.15,i4_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.58,0.15,m12,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.515,0.15,m13,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF

				legend,name,linestyle=[0,0,2,2,0,0,2,2,0,2,0,2,0,2], $
					colors=[0,1,0,1,2,3,2,3,4,4,5,5,6,6],thick=2,charthick=5
			ENDFOR
		ENDIF

		;UAID 3102117
		IF uaid EQ 3 THEN BEGIN
			!p.multi=[0,1,1]
			!p.position=0

			FOR j=0, 1 DO BEGIN
				plot,iframe[0:99],L_r[0,0,0,0,0:99],xrange=[0,80],yrange=[-0.5+j*(-10),0.5+j*18], $
					ytit='L',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name3,/nodata
				oplot,[53,53],[-2000,3000],linestyle=2,thick=3
				oplot,[47,47],[-2000,3000],linestyle=2,thick=3
				oplot,[41,41],[-2000,3000],linestyle=2,thick=3
				oplot,[35,35],[-2000,3000],linestyle=2,thick=3
				IF k EQ 0 THEN BEGIN
					oplot,[33,33],[-2000,3000],linestyle=2,thick=3
					oplot,[31,31],[-2000,3000],linestyle=2,thick=3
					oplot,[28,28],[-2000,3000],linestyle=2,thick=3
					oplot,[27,27],[-2000,3000],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,[30,30],[-2000,3000],linestyle=2,thick=3
					oplot,[28,28],[-2000,3000],linestyle=2,thick=3
					oplot,[25,25],[-2000,3000],linestyle=2,thick=3
					oplot,[24,24],[-2000,3000],linestyle=2,thick=3
				ENDIF
				oplot,[21,21],[-2000,3000],linestyle=2,thick=3
				oplot,[15,15],[-2000,3000],linestyle=2,thick=3

				IF k EQ 0 THEN BEGIN
					oplot,iframe[0:99],L_r[0,0,2*det,0,20:99],color=lcol[0],thick=3
					oplot,iframe[0:99],L_r[0,0,2*det,1,20:99],color=lcol[1],thick=3
					oplot,iframe[0:99],L_r[0,0,2*det+1,0,22:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[0:99],L_r[0,0,2*det+1,1,22:99],color=lcol[1],linestyle=2,thick=3
					oplot,iframe[0:99],L_r[1,0,2*det,0,25:99],color=lcol[2],thick=3
					oplot,iframe[0:99],L_r[1,0,2*det,1,25:99],color=lcol[3],thick=3
					oplot,iframe[0:99],L_r[1,0,2*det+1,0,26:99],color=lcol[2],linestyle=2,thick=3
					oplot,iframe[0:99],L_r[1,0,2*det+1,1,26:99],color=lcol[3],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,iframe[0:99],L_r[0,0,2*det,0,23:99],color=lcol[0],thick=3
					oplot,iframe[0:99],L_r[0,0,2*det,1,23:99],color=lcol[1],thick=3
					oplot,iframe[0:99],L_r[0,0,2*det+1,0,25:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[0:99],L_r[0,0,2*det+1,1,25:99],color=lcol[1],linestyle=2,thick=3
					oplot,iframe[0:99],L_r[1,0,2*det,0,28:99],color=lcol[2],thick=3
					oplot,iframe[0:99],L_r[1,0,2*det,1,28:99],color=lcol[3],thick=3
					oplot,iframe[0:99],L_r[1,0,2*det+1,0,29:99],color=lcol[2],linestyle=2,thick=3
					oplot,iframe[0:99],L_r[1,0,2*det+1,1,29:99],color=lcol[3],linestyle=2,thick=3
				ENDIF
				oplot,iframe[0:99],L_r[2,0,det,0,12:99],color=4,thick=3
				oplot,iframe[0:99],L_r[3,0,det,0,18:99],color=4,linestyle=2,thick=3
				oplot,iframe[0:99],L_r[4,0,det,0,32:99],color=5,thick=3
				oplot,iframe[0:99],L_r[5,0,det,0,38:99],color=5,linestyle=2,thick=3
				oplot,iframe[0:99],L_r[6,0,det,0,6:99],color=6,thick=3
				oplot,iframe[0:99],L_r[7,0,det,0,0:99],color=6,linestyle=2,thick=3

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': L vs frame'
				subtitle='Detectors '+strtrim(string(det+1),1)+' (M), '+strtrim(string(2*det+1),1)+ $
					' and '+strtrim(string(2*det+2),1)+' (I)'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.5,0.975,subtitle,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.665,0.15,m9,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.60,0.15,m8,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.53,0.15,m11,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.47,0.15,m10,/normal,alignment=0.5,charsize=1,charthick=5
				IF k EQ 0 THEN BEGIN
					XYOUTS,0.45,0.18,i3_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.43,0.15,i3_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.40,0.18,i4_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.39,0.15,i4_o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				IF k EQ 1 THEN BEGIN
					XYOUTS,0.42,0.15,i3_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.40,0.18,i3_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.365,0.15,i4_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.355,0.18,i4_o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				XYOUTS,0.315,0.15,m12,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.25,0.15,m13,/normal,alignment=0.5,charsize=1,charthick=5

				legend,name,linestyle=[0,0,2,2,0,0,2,2,0,2,0,2,0,2], $
					colors=[0,1,0,1,2,3,2,3,4,4,5,5,6,6],thick=2,charthick=5,/right_legend
			ENDFOR
		ENDIF

		;UAID 3102121
		IF uaid EQ 4 THEN BEGIN
			!p.multi=[0,1,1]
			!p.position=0

			FOR j=0, 1 DO BEGIN
				plot,iframe[0:99],L_r[0,0,0,0,0:99],xrange=[20,100],yrange=[-0.5+j*(-10),0.5+j*18], $
					ytit='L',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name2,/nodata
				oplot,[85,85],[-2000,3000],linestyle=2,thick=3
				oplot,[79,79],[-2000,3000],linestyle=2,thick=3
				oplot,[73,73],[-2000,3000],linestyle=2,thick=3
				oplot,[67,67],[-2000,3000],linestyle=2,thick=3
				IF k EQ 0 THEN BEGIN
					oplot,[65,65],[-2000,3000],linestyle=2,thick=3
					oplot,[63,63],[-2000,3000],linestyle=2,thick=3
					oplot,[60,60],[-2000,3000],linestyle=2,thick=3
					oplot,[59,59],[-2000,3000],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,[62,62],[-2000,3000],linestyle=2,thick=3
					oplot,[60,60],[-2000,3000],linestyle=2,thick=3
					oplot,[57,57],[-2000,3000],linestyle=2,thick=3
					oplot,[56,56],[-2000,3000],linestyle=2,thick=3
				ENDIF
				oplot,[53,53],[-2000,3000],linestyle=2,thick=3
				oplot,[47,47],[-2000,3000],linestyle=2,thick=3

				IF k EQ 0 THEN BEGIN
					oplot,iframe[12:99],L_r[0,0,2*det,0,0:99],color=lcol[0],thick=3
					oplot,iframe[12:99],L_r[0,0,2*det,1,0:99],color=lcol[1],thick=3
					oplot,iframe[10:99],L_r[0,0,2*det+1,0,0:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[10:99],L_r[0,0,2*det+1,1,0:99],color=lcol[1],linestyle=2,thick=3
					oplot,iframe[7:99],L_r[1,0,2*det,0,0:99],color=lcol[2],thick=3
					oplot,iframe[7:99],L_r[1,0,2*det,1,0:99],color=lcol[3],thick=3
					oplot,iframe[6:99],L_r[1,0,2*det+1,0,0:99],color=lcol[2],linestyle=2,thick=3
					oplot,iframe[6:99],L_r[1,0,2*det+1,1,0:99],color=lcol[3],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,iframe[9:99],L_r[0,0,2*det,0,0:99],color=lcol[0],thick=3
					oplot,iframe[9:99],L_r[0,0,2*det,1,0:99],color=lcol[1],thick=3
					oplot,iframe[7:99],L_r[0,0,2*det+1,0,0:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[7:99],L_r[0,0,2*det+1,1,0:99],color=lcol[1],linestyle=2,thick=3
					oplot,iframe[4:99],L_r[1,0,2*det,0,0:99],color=lcol[2],thick=3
					oplot,iframe[4:99],L_r[1,0,2*det,1,0:99],color=lcol[3],thick=3
					oplot,iframe[3:99],L_r[1,0,2*det+1,0,0:99],color=lcol[2],linestyle=2,thick=3
					oplot,iframe[3:99],L_r[1,0,2*det+1,1,0:99],color=lcol[3],linestyle=2,thick=3
				ENDIF
				oplot,iframe[14:99],L_r[2,0,det,0,0:99],color=4,thick=3
				oplot,iframe[20:99],L_r[3,0,det,0,0:99],color=4,linestyle=2,thick=3
				oplot,iframe[0:99],L_r[4,0,det,0,0:99],color=5,thick=3
				oplot,iframe[0:99],L_r[5,0,det,0,6:99],color=5,linestyle=2,thick=3
				oplot,iframe[26:99],L_r[6,0,det,0,0:99],color=6,thick=3
				oplot,iframe[32:99],L_r[7,0,det,0,0:99],color=6,linestyle=2,thick=3

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': L vs frame'
				subtitle='Detectors '+strtrim(string(det+1),1)+' (M), '+strtrim(string(2*det+1),1)+ $
					' and '+strtrim(string(2*det+2),1)+' (I)'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.5,0.975,subtitle,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.795,0.15,m9,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.725,0.15,m8,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.66,0.15,m11,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.595,0.15,m10,/normal,alignment=0.5,charsize=1,charthick=5
				IF k EQ 0 THEN BEGIN
					XYOUTS,0.575,0.18,i3_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.555,0.15,i3_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.525,0.18,i4_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.51,0.15,i4_o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				IF k EQ 1 THEN BEGIN
					XYOUTS,0.545,0.15,i3_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.53,0.18,i3_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.49,0.15,i4_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.485,0.18,i4_o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				XYOUTS,0.44,0.15,m12,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.38,0.15,m13,/normal,alignment=0.5,charsize=1,charthick=5

				legend,name,linestyle=[0,0,2,2,0,0,2,2,0,2,0,2,0,2], $
					colors=[0,1,0,1,2,3,2,3,4,4,5,5,6,6],thick=2,charthick=5
			ENDFOR
		ENDIF

		;UAID 3102149
		IF uaid EQ 5 THEN BEGIN
			!p.multi=[0,1,1]
			!p.position=0

			FOR j=0, 1 DO BEGIN
				plot,iframe[0:99],L_r[0,0,0,0,0:99],xrange=[0,100],yrange=[-0.5+j*(-10),0.5+j*18], $
					ytit='L',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name1,/nodata
				IF k EQ 0 THEN BEGIN
					oplot,[79,79],[-2000,3000],linestyle=2,thick=3
					oplot,[73,73],[-2000,3000],linestyle=2,thick=3
					oplot,[67,67],[-2000,3000],linestyle=2,thick=3
					oplot,[61,61],[-2000,3000],linestyle=2,thick=3
					oplot,[59,59],[-2000,3000],linestyle=2,thick=3
					oplot,[57,57],[-2000,3000],linestyle=2,thick=3
					oplot,[54,54],[-2000,3000],linestyle=2,thick=3
					oplot,[53,53],[-2000,3000],linestyle=2,thick=3
					oplot,[47,47],[-2000,3000],linestyle=2,thick=3
					oplot,[41,41],[-2000,3000],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,[82,82],[-2000,3000],linestyle=2,thick=3
					oplot,[76,76],[-2000,3000],linestyle=2,thick=3
					oplot,[70,70],[-2000,3000],linestyle=2,thick=3
					oplot,[64,64],[-2000,3000],linestyle=2,thick=3
					oplot,[59,59],[-2000,3000],linestyle=2,thick=3
					oplot,[57,57],[-2000,3000],linestyle=2,thick=3
					oplot,[54,54],[-2000,3000],linestyle=2,thick=3
					oplot,[53,53],[-2000,3000],linestyle=2,thick=3
					oplot,[50,50],[-2000,3000],linestyle=2,thick=3
					oplot,[44,44],[-2000,3000],linestyle=2,thick=3
				ENDIF

				IF k EQ 0 THEN BEGIN
					oplot,iframe[6:99],L_r[0,0,2*det,0,0:99],color=lcol[0],thick=3
					oplot,iframe[6:99],L_r[0,0,2*det,1,0:99],color=lcol[1],thick=3
					oplot,iframe[4:99],L_r[0,0,2*det+1,0,0:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[4:99],L_r[0,0,2*det+1,1,0:99],color=lcol[1],linestyle=2,thick=3
					oplot,iframe[1:99],L_r[1,0,2*det,0,0:99],color=lcol[2],thick=3
					oplot,iframe[1:99],L_r[1,0,2*det,1,0:99],color=lcol[3],thick=3
					oplot,iframe[0:99],L_r[1,0,2*det+1,0,0:99],color=lcol[2],linestyle=2,thick=3
					oplot,iframe[0:99],L_r[1,0,2*det+1,1,0:99],color=lcol[3],linestyle=2,thick=3
					oplot,iframe[8:99],L_r[2,0,det,0,0:99],color=4,thick=3
					oplot,iframe[14:99],L_r[3,0,det,0,0:99],color=4,linestyle=2,thick=3
					oplot,iframe[0:99],L_r[4,0,det,0,6:99],color=5,thick=3
					oplot,iframe[0:99],L_r[5,0,det,0,12:99],color=5,linestyle=2,thick=3
					oplot,iframe[20:99],L_r[6,0,det,0,0:99],color=6,thick=3
					oplot,iframe[26:99],L_r[7,0,det,0,0:99],color=6,linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,iframe[6:99],L_r[0,0,2*det,0,0:99],color=lcol[0],thick=3
					oplot,iframe[6:99],L_r[0,0,2*det,1,0:99],color=lcol[1],thick=3
					oplot,iframe[4:99],L_r[0,0,2*det+1,0,0:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[4:99],L_r[0,0,2*det+1,1,0:99],color=lcol[1],linestyle=2,thick=3
					oplot,iframe[1:99],L_r[1,0,2*det,0,0:99],color=lcol[2],thick=3
					oplot,iframe[1:99],L_r[1,0,2*det,1,0:99],color=lcol[3],thick=3
					oplot,iframe[0:99],L_r[1,0,2*det+1,0,0:99],color=lcol[2],linestyle=2,thick=3
					oplot,iframe[0:99],L_r[1,0,2*det+1,1,0:99],color=lcol[3],linestyle=2,thick=3
					oplot,iframe[11:99],L_r[2,0,det,0,0:99],color=4,thick=3
					oplot,iframe[17:99],L_r[3,0,det,0,0:99],color=4,linestyle=2,thick=3
					oplot,iframe[0:99],L_r[4,0,det,0,3:99],color=5,thick=3
					oplot,iframe[0:99],L_r[5,0,det,0,9:99],color=5,linestyle=2,thick=3
					oplot,iframe[23:99],L_r[6,0,det,0,0:99],color=6,thick=3
					oplot,iframe[29:99],L_r[7,0,det,0,0:99],color=6,linestyle=2,thick=3
				ENDIF

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': L vs frame'
				subtitle='Detectors '+strtrim(string(det+1),1)+' (M), '+strtrim(string(2*det+1),1)+ $
					' and '+strtrim(string(2*det+2),1)+' (I)'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.5,0.975,subtitle,/normal,alignment=0.5,charsize=1.6,charthick=5
				IF k EQ 0 THEN BEGIN
					XYOUTS,0.775,0.15,m9,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.72,0.15,m8,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.665,0.15,m11,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.615,0.15,m10,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.605,0.18,i3_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.585,0.15,i3_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.56,0.18,i4_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.55,0.15,i4_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.495,0.15,m12,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.445,0.15,m13,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				IF k EQ 1 THEN BEGIN
					XYOUTS,0.80,0.15,m9,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.745,0.15,m8,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.695,0.15,m11,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.64,0.15,m10,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.60,0.18,i3_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.59,0.15,i3_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.56,0.18,i4_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.555,0.15,i4_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.52,0.15,m12,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.465,0.15,m13,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF

				legend,name,linestyle=[0,0,2,2,0,0,2,2,0,2,0,2,0,2], $
					colors=[0,1,0,1,2,3,2,3,4,4,5,5,6,6],thick=2,charthick=5
			ENDFOR
		ENDIF

		;UAID 3102162
		IF uaid EQ 6 THEN BEGIN
			!p.multi=[0,1,1]
			!p.position=0

			FOR j=0, 1 DO BEGIN
				plot,iframe[0:99],L_r[0,0,0,0,0:99],xrange=[20,100],yrange=[-0.5+j*(-10),0.5+j*18], $
					ytit='L',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name2,/nodata
				oplot,[91,91],[-2000,3000],linestyle=2,thick=3
				oplot,[85,85],[-2000,3000],linestyle=2,thick=3
				oplot,[79,79],[-2000,3000],linestyle=2,thick=3
				oplot,[73,73],[-2000,3000],linestyle=2,thick=3
				IF k EQ 0 THEN BEGIN
					oplot,[71,71],[-2000,3000],linestyle=2,thick=3
					oplot,[69,69],[-2000,3000],linestyle=2,thick=3
					oplot,[66,66],[-2000,3000],linestyle=2,thick=3
					oplot,[65,65],[-2000,3000],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,[68,68],[-2000,3000],linestyle=2,thick=3
					oplot,[66,66],[-2000,3000],linestyle=2,thick=3
					oplot,[63,63],[-2000,3000],linestyle=2,thick=3
					oplot,[62,62],[-2000,3000],linestyle=2,thick=3
				ENDIF
				oplot,[59,59],[-2000,3000],linestyle=2,thick=3
				oplot,[53,53],[-2000,3000],linestyle=2,thick=3

				IF k EQ 0 THEN BEGIN
					oplot,iframe[18:99],L_r[0,0,2*det,0,0:99],color=lcol[0],thick=3
					oplot,iframe[18:99],L_r[0,0,2*det,1,0:99],color=lcol[1],thick=3
					oplot,iframe[16:99],L_r[0,0,2*det+1,0,0:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[16:99],L_r[0,0,2*det+1,1,0:99],color=lcol[1],linestyle=2,thick=3
					oplot,iframe[13:99],L_r[1,0,2*det,0,0:99],color=lcol[2],thick=3
					oplot,iframe[13:99],L_r[1,0,2*det,1,0:99],color=lcol[3],thick=3
					oplot,iframe[12:99],L_r[1,0,2*det+1,0,0:99],color=lcol[2],linestyle=2,thick=3
					oplot,iframe[12:99],L_r[1,0,2*det+1,1,0:99],color=lcol[3],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,iframe[15:99],L_r[0,0,2*det,0,0:99],color=lcol[0],thick=3
					oplot,iframe[15:99],L_r[0,0,2*det,1,0:99],color=lcol[1],thick=3
					oplot,iframe[13:99],L_r[0,0,2*det+1,0,0:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[13:99],L_r[0,0,2*det+1,1,0:99],color=lcol[1],linestyle=2,thick=3
					oplot,iframe[10:99],L_r[1,0,2*det,0,0:99],color=lcol[2],thick=3
					oplot,iframe[10:99],L_r[1,0,2*det,1,0:99],color=lcol[3],thick=3
					oplot,iframe[9:99],L_r[1,0,2*det+1,0,0:99],color=lcol[2],linestyle=2,thick=3
					oplot,iframe[9:99],L_r[1,0,2*det+1,1,0:99],color=lcol[3],linestyle=2,thick=3
				ENDIF
				oplot,iframe[20:99],L_r[2,0,det,0,0:99],color=4,thick=3
				oplot,iframe[26:99],L_r[3,0,det,0,0:99],color=4,linestyle=2,thick=3
				oplot,iframe[6:99],L_r[4,0,det,0,0:99],color=5,thick=3
				oplot,iframe[0:99],L_r[5,0,det,0,0:99],color=5,linestyle=2,thick=3
				oplot,iframe[32:99],L_r[6,0,det,0,0:99],color=6,thick=3
				oplot,iframe[38:99],L_r[7,0,det,0,0:99],color=6,linestyle=2,thick=3

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': L vs frame'
				subtitle='Detectors '+strtrim(string(det+1),1)+' (M), '+strtrim(string(2*det+1),1)+ $
					' and '+strtrim(string(2*det+2),1)+' (I)'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.5,0.975,subtitle,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.86,0.15,m9,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.79,0.15,m8,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.725,0.15,m11,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.66,0.15,m10,/normal,alignment=0.5,charsize=1,charthick=5
				IF k EQ 0 THEN BEGIN
					XYOUTS,0.64,0.18,i3_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.62,0.15,i3_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.59,0.18,i4_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.58,0.15,i4_o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				IF k EQ 1 THEN BEGIN
					XYOUTS,0.61,0.15,i3_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.59,0.18,i3_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.555,0.15,i4_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.545,0.18,i4_o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				XYOUTS,0.51,0.15,m12,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.445,0.15,m13,/normal,alignment=0.5,charsize=1,charthick=5

				legend,name,linestyle=[0,0,2,2,0,0,2,2,0,2,0,2,0,2], $
					colors=[0,1,0,1,2,3,2,3,4,4,5,5,6,6],thick=2,charthick=5
			ENDFOR
		ENDIF

		;UAID 3102166 and 3102167
		IF uaid EQ 7 OR uaid EQ 8 THEN BEGIN
			!p.multi=[0,1,1]
			!p.position=0

			FOR j=0, 1 DO BEGIN
				plot,iframe[0:99],L_r[0,0,0,0,0:99],xrange=[0,100],yrange=[-0.5+j*(-10),0.5+j*18], $
					ytit='L',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name1,/nodata
				oplot,[91,91],[-2000,3000],linestyle=2,thick=3
				oplot,[85,85],[-2000,3000],linestyle=2,thick=3
				oplot,[79,79],[-2000,3000],linestyle=2,thick=3
				oplot,[73,73],[-2000,3000],linestyle=2,thick=3
				IF k EQ 0 THEN BEGIN
					oplot,[71,71],[-2000,3000],linestyle=2,thick=3
					oplot,[69,69],[-2000,3000],linestyle=2,thick=3
					oplot,[66,66],[-2000,3000],linestyle=2,thick=3
					oplot,[65,65],[-2000,3000],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,[68,68],[-2000,3000],linestyle=2,thick=3
					oplot,[66,66],[-2000,3000],linestyle=2,thick=3
					oplot,[63,63],[-2000,3000],linestyle=2,thick=3
					oplot,[62,62],[-2000,3000],linestyle=2,thick=3
				ENDIF
				oplot,[59,59],[-2000,3000],linestyle=2,thick=3
				oplot,[53,53],[-2000,3000],linestyle=2,thick=3

				IF k EQ 0 THEN BEGIN
					oplot,iframe[18:99],L_r[0,0,2*det,0,0:99],color=lcol[0],thick=3
					oplot,iframe[18:99],L_r[0,0,2*det,1,0:99],color=lcol[1],thick=3
					oplot,iframe[16:99],L_r[0,0,2*det+1,0,0:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[16:99],L_r[0,0,2*det+1,1,0:99],color=lcol[1],linestyle=2,thick=3
					oplot,iframe[13:99],L_r[1,0,2*det,0,0:99],color=lcol[2],thick=3
					oplot,iframe[13:99],L_r[1,0,2*det,1,0:99],color=lcol[3],thick=3
					oplot,iframe[12:99],L_r[1,0,2*det+1,0,0:99],color=lcol[2],linestyle=2,thick=3
					oplot,iframe[12:99],L_r[1,0,2*det+1,1,0:99],color=lcol[3],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,iframe[15:99],L_r[0,0,2*det,0,0:99],color=lcol[0],thick=3
					oplot,iframe[15:99],L_r[0,0,2*det,1,0:99],color=lcol[1],thick=3
					oplot,iframe[13:99],L_r[0,0,2*det+1,0,0:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[13:99],L_r[0,0,2*det+1,1,0:99],color=lcol[1],linestyle=2,thick=3
					oplot,iframe[10:99],L_r[1,0,2*det,0,0:99],color=lcol[2],thick=3
					oplot,iframe[10:99],L_r[1,0,2*det,1,0:99],color=lcol[3],thick=3
					oplot,iframe[9:99],L_r[1,0,2*det+1,0,0:99],color=lcol[2],linestyle=2,thick=3
					oplot,iframe[9:99],L_r[1,0,2*det+1,1,0:99],color=lcol[3],linestyle=2,thick=3
				ENDIF
				oplot,iframe[20:99],L_r[2,0,det,0,0:99],color=4,thick=3
				oplot,iframe[26:99],L_r[3,0,det,0,0:99],color=4,linestyle=2,thick=3
				oplot,iframe[6:99],L_r[4,0,det,0,0:99],color=5,thick=3
				oplot,iframe[0:99],L_r[5,0,det,0,0:99],color=5,linestyle=2,thick=3
				oplot,iframe[32:99],L_r[6,0,det,0,0:99],color=6,thick=3
				oplot,iframe[38:99],L_r[7,0,det,0,0:99],color=6,linestyle=2,thick=3

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': L vs frame'
				subtitle='Detectors '+strtrim(string(det+1),1)+' (M), '+strtrim(string(2*det+1),1)+ $
					' and '+strtrim(string(2*det+2),1)+' (I)'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.5,0.975,subtitle,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.875,0.15,m9,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.825,0.15,m8,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.77,0.15,m11,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.72,0.15,m10,/normal,alignment=0.5,charsize=1,charthick=5

				IF k EQ 0 THEN BEGIN
					XYOUTS,0.70,0.18,i3_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.69,0.15,i3_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.665,0.18,i4_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.655,0.15,i4_o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				IF k EQ 1 THEN BEGIN
					XYOUTS,0.68,0.18,i3_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.665,0.15,i3_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.64,0.18,i4_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.63,0.15,i4_o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				XYOUTS,0.595,0.15,m12,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.545,0.15,m13,/normal,alignment=0.5,charsize=1,charthick=5

				legend,name,linestyle=[0,0,2,2,0,0,2,2,0,2,0,2,0,2], $
					colors=[0,1,0,1,2,3,2,3,4,4,5,5,6,6],thick=2,charthick=5
			ENDFOR
			!p.multi=[0,1,1]
			!p.position=0

			FOR j=0, 1 DO BEGIN
				plot,iframe[0:99],L_lg[0,0,0,0,0:99],xrange=[0,100],yrange=[-0.5+j*(-10),0.5+j*18], $
					ytit='L',xtit='frame',charsize=1.2,charthick=5,xtickname=t_name1,/nodata
				oplot,[91,91],[-2000,3000],linestyle=2,thick=3
				oplot,[85,85],[-2000,3000],linestyle=2,thick=3
				oplot,[79,79],[-2000,3000],linestyle=2,thick=3
				oplot,[73,73],[-2000,3000],linestyle=2,thick=3
				IF k EQ 0 THEN BEGIN
					oplot,[71,71],[-2000,3000],linestyle=2,thick=3
					oplot,[69,69],[-2000,3000],linestyle=2,thick=3
					oplot,[66,66],[-2000,3000],linestyle=2,thick=3
					oplot,[65,65],[-2000,3000],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,[68,68],[-2000,3000],linestyle=2,thick=3
					oplot,[66,66],[-2000,3000],linestyle=2,thick=3
					oplot,[63,63],[-2000,3000],linestyle=2,thick=3
					oplot,[62,62],[-2000,3000],linestyle=2,thick=3
				ENDIF
				oplot,[59,59],[-2000,3000],linestyle=2,thick=3
				oplot,[53,53],[-2000,3000],linestyle=2,thick=3

				IF k EQ 0 THEN BEGIN
					oplot,iframe[18:99],L_lg[0,0,2*det,0,0:99],color=lcol[0],thick=3
					oplot,iframe[18:99],L_lg[0,0,2*det,1,0:99],color=lcol[1],thick=3
					oplot,iframe[16:99],L_lg[0,0,2*det+1,0,0:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[16:99],L_lg[0,0,2*det+1,1,0:99],color=lcol[1],linestyle=2,thick=3
					oplot,iframe[13:99],L_lg[1,0,2*det,0,0:99],color=lcol[2],thick=3
					oplot,iframe[13:99],L_lg[1,0,2*det,1,0:99],color=lcol[3],thick=3
					oplot,iframe[12:99],L_lg[1,0,2*det+1,0,0:99],color=lcol[2],linestyle=2,thick=3
					oplot,iframe[12:99],L_lg[1,0,2*det+1,1,0:99],color=lcol[3],linestyle=2,thick=3
				ENDIF
				IF k EQ 1 THEN BEGIN
					oplot,iframe[15:99],L_lg[0,0,2*det,0,0:99],color=lcol[0],thick=3
					oplot,iframe[15:99],L_lg[0,0,2*det,1,0:99],color=lcol[1],thick=3
					oplot,iframe[13:99],L_lg[0,0,2*det+1,0,0:99],color=lcol[0],linestyle=2,thick=3
					oplot,iframe[13:99],L_lg[0,0,2*det+1,1,0:99],color=lcol[1],linestyle=2,thick=3
					oplot,iframe[10:99],L_lg[1,0,2*det,0,0:99],color=lcol[2],thick=3
					oplot,iframe[10:99],L_lg[1,0,2*det,1,0:99],color=lcol[3],thick=3
					oplot,iframe[9:99],L_lg[1,0,2*det+1,0,0:99],color=lcol[2],linestyle=2,thick=3
					oplot,iframe[9:99],L_lg[1,0,2*det+1,1,0:99],color=lcol[3],linestyle=2,thick=3
				ENDIF
				oplot,iframe[20:99],L_lg[2,0,det,0,0:99],color=4,thick=3
				oplot,iframe[26:99],L_lg[3,0,det,0,0:99],color=4,linestyle=2,thick=3
				oplot,iframe[6:99],L_lg[4,0,det,0,0:99],color=5,thick=3
				oplot,iframe[0:99],L_lg[5,0,det,0,0:99],color=5,linestyle=2,thick=3
				oplot,iframe[32:99],L_lg[6,0,det,0,0:99],color=6,thick=3
				oplot,iframe[38:99],L_lg[7,0,det,0,0:99],color=6,linestyle=2,thick=3

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+' Fixed Low Gain: L vs frame'
				subtitle='Detectors '+strtrim(string(det+1),1)+' (M), '+strtrim(string(2*det+1),1)+ $
					' and '+strtrim(string(2*det+2),1)+' (I)'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.5,0.975,subtitle,/normal,alignment=0.5,charsize=1.6,charthick=5
				XYOUTS,0.875,0.15,m9,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.825,0.15,m8,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.77,0.15,m11,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.72,0.15,m10,/normal,alignment=0.5,charsize=1,charthick=5

				IF k EQ 0 THEN BEGIN
					XYOUTS,0.70,0.18,i3_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.69,0.15,i3_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.665,0.18,i4_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.655,0.15,i4_o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				IF k EQ 1 THEN BEGIN
					XYOUTS,0.68,0.18,i3_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.665,0.15,i3_o,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.64,0.18,i4_e,/normal,alignment=0.5,charsize=1,charthick=5
					XYOUTS,0.63,0.15,i4_o,/normal,alignment=0.5,charsize=1,charthick=5
				ENDIF
				XYOUTS,0.595,0.15,m12,/normal,alignment=0.5,charsize=1,charthick=5
				XYOUTS,0.545,0.15,m13,/normal,alignment=0.5,charsize=1,charthick=5

				legend,name,linestyle=[0,0,2,2,0,0,2,2,0,2,0,2,0,2], $
					colors=[0,1,0,1,2,3,2,3,4,4,5,5,6,6],thick=2,charthick=5
			ENDFOR
		ENDIF
	ENDFOR
	!p.multi=[0,3,2]
	!p.position=0

	i=0
	FOR b=0, 7 DO BEGIN
		IF b GT 0 THEN i=2
		IF b LE 1 THEN BEGIN
			plot,iframe[*],d_dn_r[b,0,0,0,*],xrange=[0,100],yrange=[-20,20],title=band_name[0+i], $
				ytit='d(dn)/d(frame)',xtit='frame',charsize=1.2,charthick=5,/nodata
			FOR det=0, ndet_I-1 DO BEGIN
				oplot,iframe[*],d_dn_r[b,0,det,0,*],color=lcol[det]
			ENDFOR
			plot,iframe[*],d_dn_r[b,0,0,1,*],xrange=[0,100],yrange=[-20,20],title=band_name[1+i], $
				ytit='d(dn)/d(frame)',xtit='frame',charsize=1.2,charthick=5,/nodata
			FOR det=0, ndet_I-1 DO BEGIN
				oplot,iframe[*],d_dn_r[b,0,det,1,*],color=lcol[det]
			ENDFOR
		ENDIF
		IF b GT 1 THEN BEGIN
			plot,iframe[*],d_dn_r[b,0,0,0,*],xrange=[0,100],yrange=[-20,20],title=band_name[b+2], $
				ytit='d(dn)/d(frame)',xtit='frame',charsize=1.2,charthick=5,/nodata
			FOR det=0, ndet_M-1 DO BEGIN
				oplot,iframe[*],d_dn_r[b,0,det,0,*],color=lcol[det]
			ENDFOR
			title='UAID '+uaidname[uaid]+': d(dn)/d(frame) vs frame'
			XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
		ENDIF
	ENDFOR

	i=0
	FOR b=0, 7 DO BEGIN
		!p.multi=[0,4,4]
		!p.position=0

		IF b GT 0 THEN i=1
		IF b LE 1 THEN BEGIN
			FOR det=0, ndet_I-1 DO BEGIN
				plot,iframe[*],d_dn_r[b,0,0,0,*],xrange=[0,100],yrange=[-20,20], $
					title=band_name[b+i]+' det='+strtrim(string(det+1),1), $
					ytit='d(dn)/d(frame)',xtit='frame',charsize=1.2,charthick=5,/nodata
				oplot,iframe[*],d_dn_r[b,0,det,0,*],color=lcol[det]

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': d(dn)/d(frame) vs frame'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
			ENDFOR
			FOR det=0, ndet_I-1 DO BEGIN
				plot,iframe[*],d_dn_r[b,0,0,1,*],xrange=[0,100],yrange=[-20,20], $
					title=band_name[b+i+1]+' det='+strtrim(string(det+1),1), $
					ytit='d(dn)/d(frame)',xtit='frame',charsize=1.2,charthick=5,/nodata
				oplot,iframe[*],d_dn_r[b,0,det,1,*],color=lcol[det]

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': d(dn)/d(frame) vs frame'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
			ENDFOR
		ENDIF
		IF b GT 1 THEN BEGIN
			FOR det=0, ndet_M-1 DO BEGIN
				plot,iframe[*],d_dn_r[b,0,det,0,*],xrange=[0,100],yrange=[-20,20], $
					title=band_name[b+2]+' det='+strtrim(string(det+1),1), $
					ytit='d(dn)/d(frame)',xtit='frame',charsize=1.2,charthick=5,/nodata
				oplot,iframe[*],d_dn_r[b,0,det,0,*],color=lcol[det]
			ENDFOR
		title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': d(dn)/d(frame) vs frame'
		XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
		ENDIF
	ENDFOR
	!p.multi=[0,3,2]	
	!p.position=0

	i=0
	FOR b=0, 7 DO BEGIN
		IF b GT 0 THEN i=2
		IF b LE 1 THEN BEGIN
			plot,iframe[*],d_L_r[b,0,0,0,*],xrange=[0,100],yrange=[-20,20],title=band_name[0+i], $
				ytit='d(L)/d(frame)',xtit='frame',charsize=1.2,charthick=5,/nodata
			FOR det=0, ndet_I-1 DO BEGIN
				oplot,iframe[*],d_L_r[b,0,det,0,*],color=lcol[det]
			ENDFOR
			plot,iframe[*],d_L_r[b,0,0,1,*],xrange=[0,100],yrange=[-20,20],title=band_name[1+i], $
				ytit='d(L)/d(frame)',xtit='frame',charsize=1.2,charthick=5,/nodata
			FOR det=0, ndet_I-1 DO BEGIN
				oplot,iframe[*],d_L_r[b,0,det,1,*],color=lcol[det]
			ENDFOR
		ENDIF
		IF b GT 1 THEN BEGIN
			plot,iframe[*],d_L_r[b,0,0,0,*],xrange=[0,100],yrange=[-20,20],title=band_name[b+2], $
				ytit='d(L)/d(frame)',xtit='frame',charsize=1.2,charthick=5,/nodata
			FOR det=0, ndet_M-1 DO BEGIN
				oplot,iframe[*],d_L_r[b,0,det,0,*],color=lcol[det]
			ENDFOR
			title='UAID '+uaidname[uaid]+': d(L)/d(frame) vs frame'
			XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
		ENDIF
	ENDFOR

	i=0
	FOR b=0, 7 DO BEGIN
		!p.multi=[0,4,4]
		!p.position=0

		IF b GT 0 THEN i=1
		IF b LE 1 THEN BEGIN
			FOR det=0, ndet_I-1 DO BEGIN
				plot,iframe[*],d_L_r[b,0,0,0,*],xrange=[0,100],yrange=[-0.2,0.2], $
					title=band_name[b+i]+' det='+strtrim(string(det+1),1), $
					ytit='d(L)/d(frame)',xtit='frame',charsize=1.2,charthick=5,/nodata
				oplot,iframe[*],d_L_r[b,0,det,0,*],color=lcol[det]

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': d(L)/d(frame) vs frame'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
			ENDFOR
			FOR det=0, ndet_I-1 DO BEGIN
				plot,iframe[*],d_L_r[b,0,0,1,*],xrange=[0,100],yrange=[-0.2,0.2], $
					title=band_name[b+i+1]+' det='+strtrim(string(det+1),1), $
					ytit='d(L)/d(frame)',xtit='frame',charsize=1.2,charthick=5,/nodata
				oplot,iframe[*],d_L_r[b,0,det,1,*],color=lcol[det]

				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+': d(L)/d(frame) vs frame'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
			ENDFOR
		ENDIF
		IF b GT 1 THEN BEGIN
			FOR det=0, ndet_M-1 DO BEGIN
				plot,iframe[*],d_L_r[b,0,det,0,*],xrange=[0,100],yrange=[-0.2,0.2], $
					title=band_name[b+2]+' det='+strtrim(string(det+1),1), $
					ytit='d(L)/d(frame)',xtit='frame',charsize=1.2,charthick=5,/nodata
				oplot,iframe[*],d_L_r[b,0,det,0,*],color=lcol[det]
			ENDFOR
		title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+' Fixed Low Gain: d(L)/d(frame) vs frame'
		XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
		ENDIF
	ENDFOR

	IF uaid GE 7 THEN BEGIN
		!p.multi=[0,3,2]
		!p.position=0

		i=0
		FOR b=0, 7 DO BEGIN
			IF b GT 0 THEN i=2
			IF b LE 1 THEN BEGIN
				plot,iframe[*],d_dn_lg[b,0,0,0,*],xrange=[0,100],yrange=[-20,20],title=band_name[0+i], $
					ytit='d(dn)/d(frame)',xtit='frame',charsize=1.2,charthick=5,/nodata
				FOR det=0, ndet_I-1 DO BEGIN
					oplot,iframe[*],d_dn_lg[b,0,det,0,*],color=lcol[det]
				ENDFOR
				plot,iframe[*],d_dn_lg[b,0,0,1,*],xrange=[0,100],yrange=[-20,20],title=band_name[1+i], $
					ytit='d(dn)/d(frame)',xtit='frame',charsize=1.2,charthick=5,/nodata
				FOR det=0, ndet_I-1 DO BEGIN
					oplot,iframe[*],d_dn_lg[b,0,det,1,*],color=lcol[det]
				ENDFOR
			ENDIF
			IF b GT 1 THEN BEGIN
				plot,iframe[*],d_dn_lg[b,0,0,0,*],xrange=[0,100],yrange=[-20,20],title=band_name[b+2], $
					ytit='d(dn)/d(frame)',xtit='frame',charsize=1.2,charthick=5,/nodata
				FOR det=0, ndet_M-1 DO BEGIN
					oplot,iframe[*],d_dn_lg[b,0,det,0,*],color=lcol[det]
				ENDFOR
				title='UAID '+uaidname[uaid]+' Fixed Low Gain: d(dn)/d(frame) vs frame'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
			ENDIF
		ENDFOR

		i=0
		FOR b=0, 7 DO BEGIN
			!p.multi=[0,4,4]
			!p.position=0

			IF b GT 0 THEN i=1
			IF b LE 1 THEN BEGIN
				FOR det=0, ndet_I-1 DO BEGIN
					plot,iframe[*],d_dn_lg[b,0,0,0,*],xrange=[0,100],yrange=[-20,20], $
						title=band_name[b+i]+' det='+strtrim(string(det+1),1), $
						ytit='d(dn)/d(frame)',xtit='frame',charsize=1.2,charthick=5,/nodata
					oplot,iframe[*],d_dn_lg[b,0,det,0,*],color=lcol[det]
	
					title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+ $
						' Fixed Low Gain: d(dn)/d(frame) vs frame'
					XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
				ENDFOR
				FOR det=0, ndet_I-1 DO BEGIN
					plot,iframe[*],d_dn_lg[b,0,0,1,*],xrange=[0,100],yrange=[-20,20], $
						title=band_name[b+i+1]+' det='+strtrim(string(det+1),1), $
						ytit='d(dn)/d(frame)',xtit='frame',charsize=1.2,charthick=5,/nodata
					oplot,iframe[*],d_dn_r[b,0,det,1,*],color=lcol[det]

					title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+ $
						' Fixed Low Gain: d(dn)/d(frame) vs frame'
					XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
				ENDFOR
			ENDIF
			IF b GT 1 THEN BEGIN
				FOR det=0, ndet_M-1 DO BEGIN
					plot,iframe[*],d_dn_lg[b,0,det,0,*],xrange=[0,100],yrange=[-20,20], $
						title=band_name[b+2]+' det='+strtrim(string(det+1),1), $
						ytit='d(dn)/d(frame)',xtit='frame',charsize=1.2,charthick=5,/nodata
					oplot,iframe[*],d_dn_lg[b,0,det,0,*],color=lcol[det]
				ENDFOR
			title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+' Fixed Low Gain: d(dn)/d(frame) vs frame'
			XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
			ENDIF
		ENDFOR
		!p.multi=[0,3,2]	
		!p.position=0

		i=0
		FOR b=0, 7 DO BEGIN
			IF b GT 0 THEN i=2
			IF b LE 1 THEN BEGIN
				plot,iframe[*],d_L_lg[b,0,0,0,*],xrange=[0,100],yrange=[-20,20],title=band_name[0+i], $
					ytit='d(L)/d(frame)',xtit='frame',charsize=1.2,charthick=5,/nodata
				FOR det=0, ndet_I-1 DO BEGIN
					oplot,iframe[*],d_L_lg[b,0,det,0,*],color=lcol[det]
				ENDFOR
				plot,iframe[*],d_L_lg[b,0,0,1,*],xrange=[0,100],yrange=[-20,20],title=band_name[1+i], $
					ytit='d(L)/d(frame)',xtit='frame',charsize=1.2,charthick=5,/nodata
				FOR det=0, ndet_I-1 DO BEGIN
					oplot,iframe[*],d_L_lg[b,0,det,1,*],color=lcol[det]
				ENDFOR
			ENDIF
			IF b GT 1 THEN BEGIN
				plot,iframe[*],d_L_lg[b,0,0,0,*],xrange=[0,100],yrange=[-20,20],title=band_name[b+2], $
					ytit='d(L)/d(frame)',xtit='frame',charsize=1.2,charthick=5,/nodata
				FOR det=0, ndet_M-1 DO BEGIN
					oplot,iframe[*],d_L_lg[b,0,det,0,*],color=lcol[det]
				ENDFOR
				title='UAID '+uaidname[uaid]+' Fixed Low Gain: d(L)/d(frame) vs frame'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
			ENDIF
		ENDFOR

		i=0
		FOR b=0, 7 DO BEGIN
			!p.multi=[0,4,4]
			!p.position=0

			IF b GT 0 THEN i=1
			IF b LE 1 THEN BEGIN
				FOR det=0, ndet_I-1 DO BEGIN
					plot,iframe[*],d_L_lg[b,0,0,0,*],xrange=[0,100],yrange=[-0.2,0.2], $
						title=band_name[b+i]+' det='+strtrim(string(det+1),1), $
						ytit='d(L)/d(frame)',xtit='frame',charsize=1.2,charthick=5,/nodata
					oplot,iframe[*],d_L_lg[b,0,det,0,*],color=lcol[det]

					title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+ $
						' Fixed Low Gain: d(L)/d(frame) vs frame'
					XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
				ENDFOR
				FOR det=0, ndet_I-1 DO BEGIN
					plot,iframe[*],d_L_lg[b,0,0,1,*],xrange=[0,100],yrange=[-0.2,0.2], $
						title=band_name[b+i+1]+' det='+strtrim(string(det+1),1), $
						ytit='d(L)/d(frame)',xtit='frame',charsize=1.2,charthick=5,/nodata
					oplot,iframe[*],d_L_lg[b,0,det,1,*],color=lcol[det]

					title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+ $
						' Fixed Low Gain: d(L)/d(frame) vs frame'
					XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
				ENDFOR
			ENDIF
			IF b GT 1 THEN BEGIN
				FOR det=0, ndet_M-1 DO BEGIN
					plot,iframe[*],d_L_lg[b,0,det,0,*],xrange=[0,100],yrange=[-0.2,0.2], $
						title=band_name[b+2]+' det='+strtrim(string(det+1),1), $
						ytit='d(L)/d(frame)',xtit='frame',charsize=1.2,charthick=5,/nodata
					oplot,iframe[*],d_L_lg[b,0,det,0,*],color=lcol[det]
				ENDFOR
				title='UAID '+uaidname[uaid]+', BPF '+bandname[uaid]+' Fixed Low Gain: d(L)/d(frame) vs frame'
				XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
			ENDIF
		ENDFOR
	ENDIF
	!p.multi=[0,3,2]
	!p.position=0

	skip_loop:
ENDFOR

device,/close

!p.multi=0
!p.position=0

END
